@@ -18,7 +18,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: AutoComp.py 6898 2006-06-16 03:32:51Z dallingham $
+# $Id:AutoComp.py 9912 2008-01-22 09:17:46Z acraphae $
+
+"""
+Provide autocompletion functionality.
+"""
 
 #-------------------------------------------------------------------------
 #
@@ -27,28 +31,23 @@
 #-------------------------------------------------------------------------
 import locale
 
-#-------------------------------------------------------------------------
-#
-# set up logging
-#
-#-------------------------------------------------------------------------
-import logging
-log = logging.getLogger(".AutoComp")
-
 #-------------------------------------------------------------------------
 #
 # GNOME modules
 #
 #-------------------------------------------------------------------------
 import gtk
+import gobject
 
-def fill_combo(combo,data_list):
-    store = gtk.ListStore(str)
+def fill_combo(combo, data_list):
+    """
+    Fill a combo box with completion data
+    """
+    store = gtk.ListStore(gobject.TYPE_STRING)
 
-    for data in data_list:
-        if data:
-            store.append(row=[data])
-	    
+    for data in [ item for item in data_list if item ]:
+        store.append(row=[data])
+    
     combo.set_model(store)
     combo.set_text_column(0)
     completion = gtk.EntryCompletion()
@@ -57,12 +56,14 @@ def fill_combo(combo,data_list):
     completion.set_text_column(0)
     combo.child.set_completion(completion)
 
-def fill_entry(entry,data_list):
-    store = gtk.ListStore(str)
+def fill_entry(entry, data_list):
+    """
+    Fill a entry with completion data
+    """
+    store = gtk.ListStore(gobject.TYPE_STRING)
 
-    for data in data_list:
-        if data:
-            store.append(row=[data])
+    for data in [ item for item in data_list if item ]:
+        store.append(row=[data])
         
     completion = gtk.EntryCompletion()
     completion.set_model(store)
@@ -70,25 +71,12 @@ def fill_entry(entry,data_list):
     completion.set_text_column(0)
     entry.set_completion(completion)
     
-def fill_option_text(combobox,data):
-    store = gtk.ListStore(str)
-    for item in data:
-        if item:
-            store.append(row=[item])
-    combobox.set_model(store)
-    combobox.set_active(0)
-
-def get_option(combobox):
-    store = combobox.get_model()
-    return store.get_value(combobox.get_active_iter(),0)
-
-
 #-------------------------------------------------------------------------
 #
 # StandardCustomSelector class
 #
 #-------------------------------------------------------------------------
-class StandardCustomSelector:
+class StandardCustomSelector(object):
     """
     This class provides an interface to selecting from the predefined
     options or entering custom string.
@@ -102,7 +90,7 @@ class StandardCustomSelector:
 
     To set up the combo box, specify the active key at creation time,
     or later (or with custom text) use:
-       type_sel.set_values(i,s)
+        type_sel.set_values(i,s)
 
     and later, when or before the dialog is closed, do:
         (i,s) = type_sel.get_values()
@@ -118,7 +106,7 @@ class StandardCustomSelector:
     (active_key,mapping[active_key]) tuple.
         
     """
-    def __init__(self,mapping,cbe=None,custom_key=None,active_key=None,
+    def __init__(self, mapping, cbe=None, custom_key=None, active_key=None,
                  additional=None):
         """
         Constructor for the StandardCustomSelector class.
@@ -141,7 +129,7 @@ class StandardCustomSelector:
         self.additional = additional
         
         # make model
-        self.store = gtk.ListStore(int,str)
+        self.store = gtk.ListStore(gobject.TYPE_INT, gobject.TYPE_STRING)
 
         # fill it up using mapping
         self.fill()
@@ -152,8 +140,8 @@ class StandardCustomSelector:
             self.selector.set_model(self.store)
             self.selector.set_text_column(1)
         else:
-            self.selector = gtk.ComboBoxEntry(self.store,1)
-        if self.active_key != None:
+            self.selector = gtk.ComboBoxEntry(self.store, 1)
+        if self.active_key is not None:
             self.selector.set_active(self.active_index)
 
         # make autocompletion work
@@ -164,22 +152,25 @@ class StandardCustomSelector:
         self.selector.child.set_completion(completion)
 
     def fill(self):
+        """
+        Fill with data
+        """
         keys = self.mapping.keys()
         keys.sort(self.by_value)
         index = 0
         for key in keys:
             if key != self.custom_key:
-                self.store.append(row=[key,self.mapping[key]])
+                self.store.append(row=[key, self.mapping[key]])
                 if key == self.active_key:
                     self.active_index = index
                 index = index + 1
 
         if self.additional:
             for event_type in self.additional:
-                if type(event_type) == str or type(event_type) == unicode :
+                if isinstance(event_type, basestring):
                     if event_type:
                         self.store.append(row=[self.custom_key, event_type])
-                elif type(event_type) == tuple:
+                elif isinstance(event_type, tuple):
                     if event_type[1]:
                         self.store.append(row=[event_type[0], event_type[1]])
                 else:
@@ -188,13 +179,13 @@ class StandardCustomSelector:
                     self.active_index = index
                 index = index + 1
 
-    def by_value(self,f,s):
+    def by_value(self, first, second):
         """
         Method for sorting keys based on the values.
         """
-        fv = self.mapping[f]
-        sv = self.mapping[s]
-        return locale.strcoll(fv,sv)
+        fvalue = self.mapping[first]
+        svalue = self.mapping[second]
+        return locale.strcoll(fvalue, svalue)
 
     def get_values(self):
         """
@@ -203,60 +194,43 @@ class StandardCustomSelector:
         @return: Returns (int,str) tuple corresponding to the selection.
         @rtype: tuple
         """
-        ai = self.selector.get_active_iter()
-        if ai:
-            i = self.store.get_value(ai,0)
-            s = self.store.get_value(ai,1)
-            if s != self.mapping[i]:
-                s = self.selector.child.get_text().strip()
+        active_iter = self.selector.get_active_iter()
+        if active_iter:
+            int_val = self.store.get_value(active_iter, 0)
+            str_val = self.store.get_value(active_iter, 1)
+            if str_val != self.mapping[int_val]:
+                str_val = self.selector.child.get_text().strip()
         else:
-            i = self.custom_key
-            s = self.selector.child.get_text().strip()
-        if s in self.mapping.values():
+            int_val = self.custom_key
+            str_val = self.selector.child.get_text().strip()
+        if str_val in self.mapping.values():
             for key in self.mapping.keys():
-                if s == self.mapping[key]:
-                    i = key
+                if str_val == self.mapping[key]:
+                    int_val = key
                     break
         else:
-            i = self.custom_key
-        return (i,s)
+            int_val = self.custom_key
+        return (int_val, str_val)
 
-    def set_values(self,val):
+    def set_values(self, val):
         """
         Set values according to given tuple.
 
         @param val: (int,str) tuple with the values to set.
         @type val: tuple
         """
-        i,s = val
-        if i in self.mapping.keys() and i != self.custom_key:
-            self.store.foreach(self.set_int_value,i)
-        elif self.custom_key != None:
-            self.selector.child.set_text(s)
+        key, text = val
+        if key in self.mapping.keys() and key != self.custom_key:
+            self.store.foreach(self.set_int_value, key)
+        elif self.custom_key is not None:
+            self.selector.child.set_text(text)
         else:
             print "StandardCustomSelector.set(): Option not available:", val
 
-    def set_int_value(self,model,path,iter,val):
-        if model.get_value(iter,0) == val:
-            self.selector.set_active_iter(iter)
+    def set_int_value(self, model, path, node, val):
+        if model.get_value(node, 0) == val:
+            self.selector.set_active_iter(node)
             return True
         return False
 
 
-#-------------------------------------------------------------------------
-#
-# Testing code below this point
-#
-#-------------------------------------------------------------------------
-if __name__ == "__main__":
-    def here(obj,event):
-        print s.get_values()
-        gtk.main_quit()
-
-    s = StandardCustomSelector({0:'abc',1:'abd',2:'bbe'},None,0,1)
-    s.set_values((2,'bbe'))
-    w = gtk.Dialog()
-    w.child.add(s.selector)
-    w.connect('delete-event',here)
-    w.show_all()
-    gtk.main()
