@@ -4,6 +4,8 @@
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2002       Gary Shao
 # Copyright (C) 2007       Brian G. Matherly
+# Copyright (C) 2009       Benny Malengier
+# Copyright (C) 2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: BaseDoc.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: BaseDoc.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 Provide base interface to text based documents. Specific document
@@ -136,7 +138,7 @@ def cnv2color(text):
 # PaperSize
 #
 #------------------------------------------------------------------------
-class PaperSize:
+class PaperSize(object):
     """
     Defines the dimensions of a sheet of paper. All dimensions are in
     centimeters.
@@ -186,7 +188,7 @@ class PaperSize:
 # PaperStyle
 #
 #------------------------------------------------------------------------
-class PaperStyle:
+class PaperStyle(object):
     """
     Define the various options for a sheet of paper.
     """
@@ -299,7 +301,7 @@ class PaperStyle:
 # FontStyle
 #
 #------------------------------------------------------------------------
-class FontStyle:
+class FontStyle(object):
     """
     Defines a font style. Controls the font face, size, color, and
     attributes. In order to remain generic, the only font faces available
@@ -347,17 +349,17 @@ class FontStyle:
             in the range of 0-255 represeting the red, green, and blue
             components of a color.
         """
-        if face != None:
+        if face is not None:
             self.set_type_face(face)
-        if size != None:
+        if size is not None:
             self.set_size(size)
-        if italic != None:
+        if italic is not None:
             self.set_italic(italic)
-        if bold != None:
+        if bold is not None:
             self.set_bold(bold)
-        if underline != None:
+        if underline is not None:
             self.set_underline(underline)
-        if color != None:
+        if color is not None:
             self.set_color(color)
 
     def set_italic(self, val):
@@ -413,7 +415,7 @@ class FontStyle:
 # TableStyle
 #
 #------------------------------------------------------------------------
-class TableStyle:
+class TableStyle(object):
     """
     Specifies the style or format of a table. The TableStyle contains the
     characteristics of table width (in percentage of the full width), the
@@ -496,7 +498,7 @@ class TableStyle:
 # TableCellStyle
 #
 #------------------------------------------------------------------------
-class TableCellStyle:
+class TableCellStyle(object):
     """
     Defines the style of a particular table cell. Characteristics are:
     right border, left border, top border, bottom border, and padding.
@@ -590,7 +592,7 @@ class TableCellStyle:
 # ParagraphStyle
 #
 #------------------------------------------------------------------------
-class ParagraphStyle:
+class ParagraphStyle(object):
     """
     Defines the characteristics of a paragraph. The characteristics are:
     font (a FontStyle instance), right margin, left margin, first indent,
@@ -671,31 +673,31 @@ class ParagraphStyle:
         @param bgcolor: background color of the paragraph as an RGB tuple.
         @param font: FontStyle instance that defines the font
         """
-        if font != None:
+        if font is not None:
             self.font = FontStyle(font)
-        if pad != None:
+        if pad is not None:
             self.set_padding(pad)
-        if tborder != None:
+        if tborder is not None:
             self.set_top_border(tborder)
-        if bborder != None:
+        if bborder is not None:
             self.set_bottom_border(bborder)
-        if rborder != None:
+        if rborder is not None:
             self.set_right_border(rborder)
-        if lborder != None:
+        if lborder is not None:
             self.set_left_border(lborder)
-        if bgcolor != None:
+        if bgcolor is not None:
             self.set_background_color(bgcolor)
-        if align != None:
+        if align is not None:
             self.set_alignment(align)
-        if rmargin != None:
+        if rmargin is not None:
             self.set_right_margin(rmargin)
-        if lmargin != None:
+        if lmargin is not None:
             self.set_left_margin(lmargin)
-        if first_indent != None:
+        if first_indent is not None:
             self.set_first_indent(first_indent)
-        if tmargin != None:
+        if tmargin is not None:
             self.set_top_margin(tmargin)
-        if bmargin != None:
+        if bmargin is not None:
             self.set_bottom_margin(bmargin)
             
     def set_header_level(self, level):
@@ -872,7 +874,7 @@ class ParagraphStyle:
         return self.bmargin
 
     def set_tabs(self, tab_stops):
-        assert(type(tab_stops) == type([]))
+        assert isinstance(tab_stops, list)
         self.tabs = tab_stops
 
     def get_tabs(self):
@@ -883,7 +885,7 @@ class ParagraphStyle:
 # StyleSheetList
 #
 #------------------------------------------------------------------------
-class StyleSheetList:
+class StyleSheetList(object):
     """
     Interface into the user's defined style sheets. Each StyleSheetList
     has a predefined default style specified by the report. Additional
@@ -1011,7 +1013,7 @@ class StyleSheetList:
 # StyleSheet
 #
 #------------------------------------------------------------------------
-class StyleSheet:
+class StyleSheet(object):
     """
     A collection of named paragraph styles.
     """
@@ -1028,7 +1030,7 @@ class StyleSheet:
         self.table_styles = {}
         self.cell_styles = {}
         self.name = ""
-        if obj != None:
+        if obj is not None:
             for style_name in obj.para_styles.keys():
                 style = obj.para_styles[style_name]
                 self.para_styles[style_name] = ParagraphStyle(style)
@@ -1237,7 +1239,7 @@ class SheetParser(handler.ContentHandler):
 # GraphicsStyle
 #
 #------------------------------------------------------------------------
-class GraphicsStyle:
+class GraphicsStyle(object):
     """
     Defines the properties of graphics objects, such as line width,
     color, fill, ect.
@@ -1316,7 +1318,7 @@ class GraphicsStyle:
 # IndexMark
 #
 #------------------------------------------------------------------------
-class IndexMark:
+class IndexMark(object):
     """
     Defines a mark to be associated with text for indexing.
     """
@@ -1333,7 +1335,7 @@ class IndexMark:
 # BaseDoc
 #
 #------------------------------------------------------------------------
-class BaseDoc:
+class BaseDoc(object):
     """
     Base class for document generators. Different output formats,
     such as OpenOffice, AbiWord, and LaTeX are derived from this base
@@ -1356,15 +1358,15 @@ class BaseDoc:
         self.paper = paper_style
         self._style_sheet = styles
         self._creator = ""
-        self.print_req = 0
+        self.open_req = 0
         self.init_called = False
         self.type = "standard"
 
     def init(self):
         self.init_called = True
         
-    def print_requested(self):
-        self.print_req = 1
+    def open_requested(self):
+        self.open_req = 1
 
     def set_creator(self, name):
         "Set the owner name"
@@ -1401,17 +1403,47 @@ class BaseDoc:
         "Closes the document"
         raise NotImplementedError
 
+
 #------------------------------------------------------------------------
 #
 # TextDoc
 #
 #------------------------------------------------------------------------
-class TextDoc:
+def noescape(text):
+    return text
+    
+class TextDoc(object):
     """
     Abstract Interface for text document generators. Output formats for
     text reports must implment this interface to be used by the report 
     system.
-    """    
+    """
+    BOLD = 0
+    ITALIC = 1
+    UNDERLINE = 2
+    FONTFACE = 3
+    FONTSIZE = 4
+    FONTCOLOR = 5
+    HIGHLIGHT = 6
+    SUPERSCRIPT = 7
+    
+    SUPPORTED_MARKUP = []
+
+    ESCAPE_FUNC = lambda x: noescape
+    #Map between styletypes and internally used values. This map is needed
+    # to make TextDoc officially independant of gen.lib.styledtexttag
+    STYLETYPE_MAP = {
+        }
+    CLASSMAP = None
+    
+    #STYLETAGTABLE to store markup for write_markup associated with style tags
+    STYLETAG_MARKUP = {
+        BOLD        : ("", ""),
+        ITALIC      : ("", ""),
+        UNDERLINE   : ("", ""),
+        SUPERSCRIPT : ("", ""),
+        }
+
     def page_break(self):
         "Forces a page break, creating a new page"
         raise NotImplementedError
@@ -1477,6 +1509,29 @@ class TextDoc:
         "Ends the current table cell"
         raise NotImplementedError
 
+    def write_text(self, text, mark=None):
+        """
+        Writes the text in the current paragraph. Should only be used after a
+        start_paragraph and before an end_paragraph.
+
+        @param text: text to write.
+        @param mark:  IndexMark to use for indexing (if supported)
+        """
+        raise NotImplementedError
+    
+    def write_markup(self, text, s_tags):
+        """
+        Writes the text in the current paragraph.  Should only be used after a
+        start_paragraph and before an end_paragraph. Not all backends support
+        s_tags, then the same happens as with write_text. Backends supporting
+        write_markup will overwrite this method 
+        
+        @param text: text to write. The text is assumed to be _not_ escaped
+        @param s_tags:  assumed to be list of styledtexttags to apply to the
+                        text
+        """
+        self.write_text(text)
+
     def write_note(self, text, format, style_name):
         """
         Writes the note's text and take care of paragraphs, 
@@ -1488,16 +1543,48 @@ class TextDoc:
         """
         raise NotImplementedError
 
-    def write_text(self, text, mark=None):
+    def write_styled_note(self, styledtext, format, style_name):
         """
-        Writes the text in the current paragraph. Should only be used after a
-        start_paragraph and before an end_paragraph.
-
-        @param text: text to write.
-        @param mark:  IndexMark to use for indexing (if supported)
+        Convenience function to write a styledtext to the cairo doc. 
+        styledtext : assumed a StyledText object to write
+        format : = 0 : Flowed, = 1 : Preformatted
+        style_name : name of the style to use for default presentation
+        
+        overwrite this method if the backend supports styled notes
         """
-        raise NotImplementedError
+        text = str(styledtext)
+        self.write_note(text, format, style_name)
     
+    def write_text_citation(self, text, mark=None):
+        """Method to write text with GRAMPS <super> citation marks"""
+        if not text:
+            return
+        parts = text.split("<super>")
+        markset = False
+        for piece in parts:
+            if not piece:
+                # a text '<super>text ...' splits as '', 'text..'
+                continue
+            piecesplit = piece.split("</super>")
+            if len(piecesplit) == 2:
+                self.start_superscript()
+                self.write_text(piecesplit[0])
+                self.end_superscript()
+                if not piecesplit[1]:
+                    #text ended with ' ... </super>'
+                    continue
+                if not markset:
+                    self.write_text(piecesplit[1], mark)
+                    markset = True
+                else:
+                    self.write_text(piecesplit[1])
+            else:
+                if not markset:
+                    self.write_text(piece, mark)
+                    markset = True
+                else:
+                    self.write_text(piece)
+
     def add_media_object(self, name, align, w_cm, h_cm):
         """
         Add a photo of the specified width (in centimeters)
@@ -1509,13 +1596,171 @@ class TextDoc:
         @param h_cm: height in centimeters
         """
         raise NotImplementedError
+    
+    def find_tag_by_stag(self, s_tag):
+        """
+        @param s_tag: object: assumed styledtexttag
+        @param s_tagvalue: None/int/str: value associated with the tag
+        
+        A styled tag is type with a value. 
+        Every styled tag must be converted to the tags used in the corresponding
+            markup for the backend, eg <b>text</b> for bold in html.
+        These markups are stored in STYLETAG_MARKUP. They are tuples for begin
+            and end tag
+        If a markup is not present yet, it is created, using the 
+            _create_xmltag method you can overwrite
+        """
+        type = s_tag.name
+        
+        if not self.STYLETYPE_MAP or \
+        self.CLASSMAP <> type.__class__.__name__ :
+            self.CLASSMAP == type.__class__.__name__
+            self.STYLETYPE_MAP[type.__class__.BOLD]        = self.BOLD
+            self.STYLETYPE_MAP[type.ITALIC]      = self.ITALIC
+            self.STYLETYPE_MAP[type.UNDERLINE]   = self.UNDERLINE
+            self.STYLETYPE_MAP[type.FONTFACE]    = self.FONTFACE
+            self.STYLETYPE_MAP[type.FONTSIZE]    = self.FONTSIZE
+            self.STYLETYPE_MAP[type.FONTCOLOR]   = self.FONTCOLOR
+            self.STYLETYPE_MAP[type.HIGHLIGHT]   = self.HIGHLIGHT
+            self.STYLETYPE_MAP[type.SUPERSCRIPT] = self.SUPERSCRIPT
+
+        typeval = int(s_tag.name)
+        s_tagvalue = s_tag.value
+        tag_name = None
+        if type.STYLE_TYPE[typeval] == bool:
+            return self.STYLETAG_MARKUP[self.STYLETYPE_MAP[typeval]]
+        elif type.STYLE_TYPE[typeval] == str:
+            tag_name = "%d %s" % (typeval, s_tagvalue)
+        elif type.STYLE_TYPE[typeval] == int:
+            tag_name = "%d %d" % (typeval, s_tagvalue)
+        if not tag_name:
+            return None
+        
+        tags = self.STYLETAG_MARKUP.get(tag_name)
+        if tags is not None:
+            return tags
+        #no tag known yet, create the markup, add to lookup, and return
+        tags = self._create_xmltag(self.STYLETYPE_MAP[typeval], s_tagvalue)
+        self.STYLETAG_MARKUP[tag_name] = tags
+        return tags
+
+    def _create_xmltag(self, type, value):
+        """
+        Create the xmltags for the backend.
+        Overwrite this method to create functionality with a backend
+        """
+        if type not in self.SUPPORTED_MARKUP:
+            return None
+        return ('', '')
+    
+    def _add_markup_from_styled(self, text, s_tags, split=''):
+        """
+        Input is plain text, output is text with markup added according to the
+        s_tags which are assumed to be styledtexttags.
+        When split is given the text will be split over the value given, and 
+        tags applied in such a way that it the text can be safely splitted in
+        pieces along split
+        
+        @param text   : str, a piece of text
+        @param s_tags : styledtexttags that must be applied to the text
+        @param split  : str, optional. A string along which the output can 
+                    be safely split without breaking the styling.
+        As adding markup means original text must be escaped, ESCAPE_FUNC is 
+            used
+        This can be used to convert the text of a styledtext to the format 
+            needed for a document backend
+        Do not call this method in a report, use the write_markup method
+            
+        @note: the algorithm is complex as it assumes mixing of tags is not
+                allowed: eg <b>text<i> here</b> not</i> is assumed invalid
+                as markup. If the s_tags require such a setup, what is returned
+                is <b>text</b><i><b> here</b> not</i>
+               overwrite this method if this complexity is not needed. 
+        """
+        FIRST = 0
+        LAST = 1
+        tagspos = {}
+        for s_tag in s_tags:
+            tag = self.find_tag_by_stag(s_tag)
+            if tag is not None:
+                for (start, end) in s_tag.ranges:
+                    if start in tagspos:
+                        tagspos[start] += [(tag, FIRST)]
+                    else:
+                        tagspos[start] = [(tag, FIRST)]
+                    if end in tagspos:
+                        tagspos[end] = [(tag, LAST)] + tagspos[end]
+                    else:
+                        tagspos[end] = [(tag, LAST)]
+        start = 0
+        end = len(text)
+        keylist = tagspos.keys()
+        keylist.sort()
+        keylist = [x for x in keylist if x<=len(text)]
+        opentags = []
+        otext = u""  #the output, text with markup
+        lensplit = len(split)
+        for pos in keylist:
+            #write text up to tag
+            if pos > start:
+                if split:
+                    #make sure text can split
+                    splitpos = text[start:pos].find(split)
+                    while splitpos <> -1:
+                        otext += self.ESCAPE_FUNC()(text[start:start+splitpos])
+                        #close open tags
+                        opentags.reverse()
+                        for opentag in opentags:
+                            otext += opentag[1]
+                        opentags.reverse()
+                        #add split text
+                        otext += self.ESCAPE_FUNC()(split)
+                        #open the tags again
+                        for opentag in opentags:
+                            otext += opentag[0]
+                        #obtain new values
+                        start = start + splitpos + lensplit
+                        splitpos = text[start:pos].find(split)
+                    
+                otext += self.ESCAPE_FUNC()(text[start:pos])
+            #write out tags
+            for tag in tagspos[pos]:
+                #close open tags starting from last open
+                opentags.reverse()
+                for opentag in opentags:
+                    otext += opentag[1]
+                opentags.reverse()
+                #if start, add to opentag in beginning as first to open
+                if tag[1] == FIRST:
+                    opentags = [tag[0]] + opentags
+                else:
+                    #end tag, is closed already, remove from opentag
+                    opentags = [x for x in opentags if not x == tag[0] ]
+                #now all tags are closed, open the ones that should open
+                for opentag in opentags:
+                    otext += opentag[0]
+            start = pos
+        #add remainder of text, no markup present there
+        otext += self.ESCAPE_FUNC()(text[start:end])
+        
+        #opentags should be empty. If not, user gave tags on positions that 
+        # are over the end of the text. Just close the tags still open
+        if opentags:
+            print 'WARNING: TextDoc : More style tags in text than length '\
+                    'of text allows.\n', opentags
+            opentags.reverse()
+            for opentag in opentags:
+                otext += opentag[1]
+        
+        return otext
+    
 
 #------------------------------------------------------------------------
 #
 # DrawDoc
 #
 #------------------------------------------------------------------------
-class DrawDoc:
+class DrawDoc(object):
     """
     Abstract Interface for graphical document generators. Output formats
     for graphical reports must implment this interface to be used by the
@@ -1575,26 +1820,32 @@ class DrawDoc:
 # GVDoc
 #
 #-------------------------------------------------------------------------------
-class GVDoc:
+class GVDoc(object):
     """
     Abstract Interface for Graphviz document generators. Output formats
     for Graphviz reports must implment this interface to be used by the
     report system.
     """
-    def add_node(self, id, label, shape="box", fillcolor="white", url="", htmloutput=False):
+    def add_node(self, node_id, label, shape="", color="", 
+                 style="", fillcolor="", url="", htmloutput=False):
         """
         Add a node to this graph. Nodes can be different shapes like boxes and
         circles.
         
-        @param id: A unique identification value for this node.
+        @param node_id: A unique identification value for this node.
             Example: "p55"
-        @type id: string
+        @type node_id: string
         @param label: The text to be displayed in the node.
             Example: "John Smith"
         @type label: string
         @param shape: The shape for the node.
             Examples: "box", "ellipse", "circle"
         @type shape: string
+        @param color: The color of the node line.
+            Examples: "blue", "lightyellow"
+        @type color: string
+        @param style: The style of the node.
+        @type style: string
         @param fillcolor: The fill color for the node.
             Examples: "blue", "lightyellow"
         @type fillcolor: string
@@ -1634,7 +1885,7 @@ class GVDoc:
         """
         raise NotImplementedError
 
-    def start_subgraph(self,id):
+    def start_subgraph(self, graph_id):
         """
         Start a subgraph in this graph.
         
