@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,19 +18,16 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Bookmarks.py 9077 2007-10-05 09:03:59Z bmcage $
+# $Id: Bookmarks.py 12127 2009-02-26 09:23:40Z romjerome $
 
-"Handle bookmarks for the gramps interface"
-
-__author__ = "Donald N. Allingham"
-__version__ = "$Revision: 9077 $"
+"Handle bookmarks for the gramps interface."
 
 #-------------------------------------------------------------------------
 #
 # Standard python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+
 from cStringIO import StringIO
 
 #-------------------------------------------------------------------------
@@ -54,9 +51,19 @@ import gtk
 #
 #-------------------------------------------------------------------------
 import GrampsDisplay
-import NameDisplay
+from BasicUtils import name_displayer
 import ListModel
 import Utils
+import const
+from TransUtils import sgettext as _
+
+#-------------------------------------------------------------------------
+#
+# Constants
+#
+#-------------------------------------------------------------------------
+WIKI_HELP_PAGE = '%s_-_Navigation' % const.URL_MANUAL_PAGE
+WIKI_HELP_SEC = _('manual|Bookmarks')
 
 #-------------------------------------------------------------------------
 #
@@ -64,17 +71,17 @@ import Utils
 #
 #-------------------------------------------------------------------------
 
-_top = '''<ui><menubar name="MenuBar"><menu action="BookMenu">'''
-_btm = '''</menu></menubar></ui>'''
+TOP = '''<ui><menubar name="MenuBar"><menu action="BookMenu">'''
+BTM = '''</menu></menubar></ui>'''
 
 DISABLED = -1
 
 class Bookmarks :
-    "Handle the bookmarks interface for Gramps"
+    "Handle the bookmarks interface for Gramps."
     
     def __init__(self, dbstate, uistate, bookmarks, callback=None):
         """
-        Creates a the bookmark editor.
+        Create the bookmark editor.
 
         bookmarks - list of People
         menu - parent menu to attach users
@@ -89,31 +96,48 @@ class Bookmarks :
         self.dbstate.connect('database-changed', self.db_changed)
 
     def db_changed(self, data):
+        """
+        Reconnect the signals on a database changed.
+        """
         self.connect_signals()
 
     def connect_signals(self):
+        """
+        Connect the person-delete signal
+        """
         self.dbstate.db.connect('person-delete', self.remove_handles)
 
     def update_bookmarks(self, bookmarks):
+        """
+        Assign bookmarks 
+        """
         self.bookmarks = bookmarks
 
     def display(self):
+        """
+        Redraw the display.
+        """
         self.redraw()
 
     def undisplay(self):
+        """
+        Update the uimanager.
+        """
         if self.active != DISABLED:
             self.uistate.uimanager.remove_ui(self.active)
             self.uistate.uimanager.remove_action_group(self.action_group)
+            self.action_group = gtk.ActionGroup('Bookmarks')
             self.active = DISABLED
 
     def redraw_and_report_change(self):
+        """Create the pulldown menu and set bookmarks to changed."""
         self.dbstate.db.report_bm_change()
         self.redraw()
 
     def redraw(self):
-        """Create the pulldown menu"""
-        f = StringIO()
-        f.write(_top)
+        """Create the pulldown menu."""
+        text = StringIO()
+        text.write(TOP)
 
         self.undisplay()
         
@@ -121,47 +145,44 @@ class Bookmarks :
         count = 0
 
         if len(self.bookmarks.get()) > 0:
-            f.write('<placeholder name="GoToBook">')
+            text.write('<placeholder name="GoToBook">')
 
-            new_list = []
             for item in self.bookmarks.get():
                 try:
                     label, obj = self.make_label(item)
                     func = self.callback(item)
                     action_id = "BM:%s" % item
-                    actions.append((action_id,None,label,None,None,func))
-                    f.write('<menuitem action="%s"/>' % action_id)
-                    count +=1
-                    new_list.append(item)
+                    actions.append((action_id, None, label, None, None, func))
+                    text.write('<menuitem action="%s"/>' % action_id)
+                    count += 1
                 except AttributeError:
                     pass
-            f.write('</placeholder>')
-            self.bookmarks.set(new_list)
+            text.write('</placeholder>')
             
-        f.write(_btm)
+        text.write(BTM)
         self.action_group.add_actions(actions)
-        self.uistate.uimanager.insert_action_group(self.action_group,1)
-        self.active = self.uistate.uimanager.add_ui_from_string(f.getvalue())
+        self.uistate.uimanager.insert_action_group(self.action_group, 1)
+        self.active = self.uistate.uimanager.add_ui_from_string(text.getvalue())
         self.uistate.uimanager.ensure_update()
-        f.close()
+        text.close()
 
-    def make_label(self,handle):
+    def make_label(self, handle):
         person = self.dbstate.db.get_person_from_handle(handle)
-        name = NameDisplay.displayer.display(person)
-        return ("%s [%s]" % (name,person.gramps_id), person)
+        name = name_displayer.display(person)
+        return ("%s [%s]" % (name, person.gramps_id), person)
 
     def callback(self, handle):
         return make_callback(handle, self.dbstate.change_active_handle)
 
     def add(self, person_handle):
-        """appends the person to the bottom of the bookmarks"""
+        """Append the person to the bottom of the bookmarks."""
         if person_handle not in self.bookmarks.get():
             self.bookmarks.append(person_handle)
             self.redraw_and_report_change()
 
     def remove_handles(self, handle_list):
         """
-        Removes people from the list of bookmarked people.
+        Remove people from the list of bookmarked people.
 
         This function is for use *outside* the bookmark editor
         (removal when person is deleted or merged away).
@@ -176,28 +197,30 @@ class Bookmarks :
             self.redraw_and_report_change()
 
     def draw_window(self):
-        """Draws the bookmark dialog box"""
-        title = "%s - GRAMPS" % _("Edit Bookmarks")
+        """Draw the bookmark dialog box."""
+        title = _("%(title)s - GRAMPS") % {'title': _("Organize Bookmarks")}
         self.top = gtk.Dialog(title)
-        self.top.set_default_size(400,350)
+        self.top.set_default_size(400, 350)
+        self.top.set_modal(True)
+        self.top.set_transient_for(self.uistate.window)
         self.top.set_has_separator(False)
         self.top.vbox.set_spacing(5)
         label = gtk.Label('<span size="larger" weight="bold">%s</span>'
-                          % _("Edit Bookmarks"))
+                          % _("Organize Bookmarks"))
         label.set_use_markup(True)
-        self.top.vbox.pack_start(label,0,0,5)
+        self.top.vbox.pack_start(label, 0, 0, 5)
         box = gtk.HBox()
-        self.top.vbox.pack_start(box,1,1,5)
+        self.top.vbox.pack_start(box, 1, 1, 5)
         
-        name_titles = [(_('Name'),-1,200),(_('ID'),-1,50),('',-1,0)]
+        name_titles = [(_('Name'), -1, 200), (_('ID'), -1, 50), ('', -1, 0)]
         self.namelist = gtk.TreeView()
-        self.namemodel = ListModel.ListModel(self.namelist,name_titles)
+        self.namemodel = ListModel.ListModel(self.namelist, name_titles)
         self.namemodel_cols = len(name_titles)
 
         slist = gtk.ScrolledWindow()
         slist.add_with_viewport(self.namelist)
         slist.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        box.pack_start(slist,1,1,5)
+        box.pack_start(slist, 1, 1, 5)
         bbox = gtk.VButtonBox()
         bbox.set_layout(gtk.BUTTONBOX_START)
         bbox.set_spacing(6)
@@ -205,19 +228,24 @@ class Bookmarks :
         down = gtk.Button(stock=gtk.STOCK_GO_DOWN)
         delete = gtk.Button(stock=gtk.STOCK_REMOVE)
         up.connect('clicked', self.up_clicked)
-        down.connect('clicked',self.down_clicked)
-        delete.connect('clicked',self.delete_clicked)
-        self.top.add_button(gtk.STOCK_CLOSE,gtk.RESPONSE_CLOSE)
-        self.top.add_button(gtk.STOCK_HELP,gtk.RESPONSE_HELP)
+        down.connect('clicked', self.down_clicked)
+        delete.connect('clicked', self.delete_clicked)
+        self.top.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
+        self.top.add_button(gtk.STOCK_HELP, gtk.RESPONSE_HELP)
+        self.top.connect('delete-event', self.close)
         bbox.add(up)
         bbox.add(down)
         bbox.add(delete)
-        box.pack_start(bbox,0,0,5)
+        box.pack_start(bbox, 0, 0, 5)
         self.top.show_all()
-        
+    
+    def close(self, widget, event):
+        """Stop the bookmark organizer"""
+        self.top.response(gtk.RESPONSE_CLOSE)
+
     def edit(self):
         """
-        display the bookmark editor.
+        Display the bookmark editor.
 
         The current bookmarked people are inserted into the namelist,
         attaching the person object to the corresponding row. The currently
@@ -229,61 +257,66 @@ class Bookmarks :
             name, obj = self.make_label(handle)
             if obj:
                 gramps_id = obj.get_gramps_id()
-                self.namemodel.add([name,gramps_id,handle])
+                self.namemodel.add([name, gramps_id, handle])
         self.namemodel.connect_model()
 
         self.modified = False
-        self.response = self.top.run()
-        if self.response == gtk.RESPONSE_HELP:
-            self.help_clicked()
-        if self.modified:
-            self.redraw_and_report_change()
-        self.top.destroy()
+        while True:
+            self.response = self.top.run()
+            if self.response == gtk.RESPONSE_HELP:
+                self.help_clicked()
+            elif self.response == gtk.RESPONSE_CLOSE:
+                if self.modified:
+                    self.redraw_and_report_change()
+                self.top.destroy()
+                break
 
-    def delete_clicked(self,obj):
-        """Removes the current selection from the list"""
-        store,the_iter = self.namemodel.get_selected()
+    def delete_clicked(self, obj):
+        """Remove the current selection from the list."""
+        store, the_iter = self.namemodel.get_selected()
         if not the_iter:
             return
         row = self.namemodel.get_selected_row()
         self.bookmarks.pop(row)
         self.namemodel.remove(the_iter)
         self.modified = True
+        if row > 0:
+            row = row - 1
+        self.namemodel.select_row(row)
 
-    def up_clicked(self,obj):
-        """Moves the current selection up one row"""
+    def up_clicked(self, obj):
+        """Move the current selection up one row."""
         row = self.namemodel.get_selected_row()
         if not row or row == -1:
             return
-        store,the_iter = self.namemodel.get_selected()
-        data = self.namemodel.get_data(the_iter,range(self.namemodel_cols))
+        store, the_iter = self.namemodel.get_selected()
+        data = self.namemodel.get_data(the_iter, range(self.namemodel_cols))
         self.namemodel.remove(the_iter)
-        self.namemodel.insert(row-1,data,None,1)
+        self.namemodel.insert(row-1, data, None, 1)
         handle = self.bookmarks.pop(row)
-        self.bookmarks.insert(row-1,handle)
+        self.bookmarks.insert(row-1, handle)
         self.modified = True
 
-    def down_clicked(self,obj):
-        """Moves the current selection down one row"""
+    def down_clicked(self, obj):
+        """Move the current selection down one row."""
         row = self.namemodel.get_selected_row()
         if row + 1 >= self.namemodel.count or row == -1:
             return
-        store,the_iter = self.namemodel.get_selected()
-        data = self.namemodel.get_data(the_iter,range(self.namemodel_cols))
+        store, the_iter = self.namemodel.get_selected()
+        data = self.namemodel.get_data(the_iter, range(self.namemodel_cols))
         self.namemodel.remove(the_iter)
-        self.namemodel.insert(row+1,data,None,1)
+        self.namemodel.insert(row+1, data, None, 1)
         handle = self.bookmarks.pop(row)
-        self.bookmarks.insert(row+1,handle)
+        self.bookmarks.insert(row+1, handle)
         self.modified = True
 
     def help_clicked(self):
-        """Display the relevant portion of GRAMPS manual"""
-        GrampsDisplay.help('gramps-nav')
-        self.response = self.top.run()
+        """Display the relevant portion of GRAMPS manual."""
+        GrampsDisplay.help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
 class ListBookmarks(Bookmarks):
 
-    def __init__(self,dbstate,uistate,bookmarks, goto_handle):
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
         self.goto_handle = goto_handle
         Bookmarks.__init__(self, dbstate, uistate, bookmarks)
     
@@ -293,15 +326,14 @@ class ListBookmarks(Bookmarks):
     def do_callback(self, handle):
         self.goto_handle(handle)
 
-
 class FamilyBookmarks(ListBookmarks) :
-    "Handle the bookmarks interface for Gramps"
+    "Handle the bookmarks interface for Gramps."
     
-    def __init__(self,dbstate,uistate,bookmarks, goto_handle):
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
         ListBookmarks.__init__(self, dbstate, uistate, bookmarks,
                                goto_handle)
         
-    def make_label(self,handle):
+    def make_label(self, handle):
         obj = self.dbstate.db.get_family_from_handle(handle)
         name = Utils.family_name(obj, self.dbstate.db)
         return ("%s [%s]" % (name, obj.gramps_id), obj)
@@ -310,13 +342,13 @@ class FamilyBookmarks(ListBookmarks) :
         self.dbstate.db.connect('family-delete', self.remove_handles)
 
 class EventBookmarks(ListBookmarks) :
-    "Handle the bookmarks interface for Gramps"
+    "Handle the bookmarks interface for Gramps."
     
-    def __init__(self,dbstate,uistate,bookmarks, goto_handle):
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
         ListBookmarks.__init__(self, dbstate, uistate, bookmarks,
                                goto_handle)
         
-    def make_label(self,handle):
+    def make_label(self, handle):
         obj = self.dbstate.db.get_event_from_handle(handle)
         if obj.get_description() == "":
             name = str(obj.get_type())
@@ -328,12 +360,12 @@ class EventBookmarks(ListBookmarks) :
         self.dbstate.db.connect('event-delete', self.remove_handles)
 
 class SourceBookmarks(ListBookmarks) :
-    "Handle the bookmarks interface for Gramps"
-    def __init__(self,dbstate,uistate,bookmarks, goto_handle):
+    "Handle the bookmarks interface for Gramps."
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
         ListBookmarks.__init__(self, dbstate, uistate, bookmarks,
                                goto_handle)
         
-    def make_label(self,handle):
+    def make_label(self, handle):
         obj = self.dbstate.db.get_source_from_handle(handle)
         name = obj.get_title()
         return ("%s [%s]" % (name, obj.gramps_id), obj)
@@ -342,13 +374,13 @@ class SourceBookmarks(ListBookmarks) :
         self.dbstate.db.connect('source-delete', self.remove_handles)
 
 class MediaBookmarks(ListBookmarks) :
-    "Handle the bookmarks interface for Gramps"
+    "Handle the bookmarks interface for Gramps."
     
-    def __init__(self,dbstate,uistate,bookmarks, goto_handle):
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
         ListBookmarks.__init__(self, dbstate, uistate, bookmarks,
                                goto_handle)
         
-    def make_label(self,handle):
+    def make_label(self, handle):
         obj = self.dbstate.db.get_object_from_handle(handle)
         name = obj.get_description()
         return ("%s [%s]" % (name, obj.gramps_id), obj)
@@ -357,13 +389,13 @@ class MediaBookmarks(ListBookmarks) :
         self.dbstate.db.connect('media-delete', self.remove_handles)
 
 class RepoBookmarks(ListBookmarks) :
-    "Handle the bookmarks interface for Gramps"
+    "Handle the bookmarks interface for Gramps."
     
-    def __init__(self,dbstate,uistate,bookmarks, goto_handle):
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
         ListBookmarks.__init__(self, dbstate, uistate, bookmarks,
                                goto_handle)
         
-    def make_label(self,handle):
+    def make_label(self, handle):
         obj = self.dbstate.db.get_repository_from_handle(handle)
         name = obj.get_name()
         return ("%s [%s]" % (name, obj.gramps_id), obj)
@@ -372,13 +404,13 @@ class RepoBookmarks(ListBookmarks) :
         self.dbstate.db.connect('repository-delete', self.remove_handles)
 
 class PlaceBookmarks(ListBookmarks) :
-    "Handle the bookmarks interface for Gramps"
+    "Handle the bookmarks interface for Gramps."
     
-    def __init__(self,dbstate,uistate,bookmarks, goto_handle):
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
         ListBookmarks.__init__(self, dbstate, uistate, bookmarks,
                                goto_handle)
         
-    def make_label(self,handle):
+    def make_label(self, handle):
         obj = self.dbstate.db.get_place_from_handle(handle)
         name = obj.get_title()
         return ("%s [%s]" % (name, obj.gramps_id), obj)
@@ -386,5 +418,25 @@ class PlaceBookmarks(ListBookmarks) :
     def connect_signals(self):
         self.dbstate.db.connect('place-delete', self.remove_handles)
 
-def make_callback(n,f):
-    return lambda x: f(n)
+class NoteBookmarks(ListBookmarks) :
+    "Handle the bookmarks interface for Gramps."
+    
+    def __init__(self, dbstate, uistate, bookmarks, goto_handle):
+        ListBookmarks.__init__(self, dbstate, uistate, bookmarks,
+                               goto_handle)
+        
+    def make_label(self, handle):
+        obj = self.dbstate.db.get_note_from_handle(handle)
+        name = obj.get().replace('\n', ' ')
+        if len(name) > 40:
+            name = name[:40]+"..."
+        return ("%s [%s]" % (name, obj.gramps_id), obj)
+
+    def connect_signals(self):
+        self.dbstate.db.connect('note-delete', self.remove_handles)
+
+def make_callback(handle, function):
+    """
+    Build a unique call to the function with the associated handle.
+    """
+    return lambda x: function(handle)
