@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _GrampsIniKeys.py 10055 2008-02-18 20:07:09Z acraphae $
+# $Id: _GrampsIniKeys.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 Low-level handling of .ini keys. 
@@ -42,7 +42,7 @@ def make_bool(val):
     else:
         return True
 
-class IniKeyClient:
+class IniKeyClient(object):
     """ Class to emulate gconf's client """
     def __init__(self, filename = None):
         """ Constructor takes an optional filename """
@@ -75,7 +75,7 @@ class IniKeyClient:
         data = {}
         for sec in cp.sections():
             name = sec.lower()
-            if not data.has_key(name):
+            if name not in data:
                 data[name] = {}
             for opt in cp.options(sec):
                 data[name][opt.lower()] = cp.get(sec, opt).strip()
@@ -209,7 +209,7 @@ def get(key):
         val = get_int(key)
     else:
         val = get_string(key)
-    if val == None or val == "":
+    if val is None or val == "":
         val = default_value[key]
     return val
 
