@@ -20,14 +20,15 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: PedigreeView.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: PedigreeView.py 12560 2009-05-21 17:58:31Z gbritton $
 
 #-------------------------------------------------------------------------
 #
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from TransUtils import sgettext as _
+from gettext import ngettext
 from cgi import escape
 import math
 
@@ -69,12 +70,12 @@ from QuestionDialog import RunDatabaseRepair, ErrorDialog
 #
 #-------------------------------------------------------------------------
 _PERSON = "p"
-_BORN = _('b.')
-_DIED = _('d.')
-_BAPT = _('bap.')
-_CHRI = _('chr.')
-_BURI = _('bur.')
-_CREM = _('crem.')
+_BORN = _('short for born|b.')
+_DIED = _('short for died|d.')
+_BAPT = _('short for baptized|bap.')
+_CHRI = _('short for chistianized|chr.')
+_BURI = _('short for buried|bur.')
+_CREM = _('short for cremated|crem.')
 
 class PersonBoxWidget_old( gtk.Button):
     def __init__(self,fh,person,maxlines,image=None):
@@ -98,11 +99,14 @@ class PersonBoxWidget_old( gtk.Button):
         self.modify_bg( gtk.STATE_SELECTED, white)
 
 class _PersonWidget_base:
-    def __init__(self, fh, person):
+    def __init__(self, view, fh, person):
+        self.view = view
         self.fh = fh
         self.person = person
         self.force_mouse_over = False
         if self.person:
+            self.add_events(gtk.gdk.BUTTON_RELEASE_MASK)
+            self.connect("button-release-event", self.on_button_release_cb)
             self.connect("drag_data_get", self.drag_data_get)
             self.connect('drag_begin', self.drag_begin_cb)
             self.drag_source_set(gtk.gdk.BUTTON1_MASK,
@@ -120,11 +124,16 @@ class _PersonWidget_base:
         else:
             sel_data.set(sel_data.target, 8, self.fh.format_person( self.person,11))
 
+    def on_button_release_cb(self,widget,event):
+        self.view.on_childmenu_changed(None, self.person.get_handle())
+        return False
+
+
             
 class PersonBoxWidget_cairo( gtk.DrawingArea, _PersonWidget_base):
-    def __init__(self,fh,person,alive,maxlines,image=None):
+    def __init__(self,view,fh,person,alive,maxlines,image=None):
         gtk.DrawingArea.__init__(self)
-        _PersonWidget_base.__init__(self,fh,person)
+        _PersonWidget_base.__init__(self,view,fh,person)
         self.add_events(gtk.gdk.BUTTON_PRESS_MASK)  # Required for popup menu
         self.add_events(gtk.gdk.ENTER_NOTIFY_MASK)  # Required for tooltip and mouse-over
         self.add_events(gtk.gdk.LEAVE_NOTIFY_MASK)  # Required for tooltip and mouse-over
@@ -258,9 +267,9 @@ class PersonBoxWidget_cairo( gtk.DrawingArea, _PersonWidget_base):
 
 
 class PersonBoxWidget( gtk.DrawingArea, _PersonWidget_base):
-    def __init__(self,fh,person,alive,maxlines,image=None):
+    def __init__(self,view,fh,person,alive,maxlines,image=None):
         gtk.DrawingArea.__init__(self)
-        _PersonWidget_base.__init__(self,fh,person)
+        _PersonWidget_base.__init__(self,view,fh,person)
         self.add_events(gtk.gdk.BUTTON_PRESS_MASK)  # Required for popup menu
         self.add_events(gtk.gdk.ENTER_NOTIFY_MASK)  # Required for tooltip and mouse-over
         self.add_events(gtk.gdk.LEAVE_NOTIFY_MASK)  # Required for tooltip and mouse-over
@@ -285,7 +294,7 @@ class PersonBoxWidget( gtk.DrawingArea, _PersonWidget_base):
             xmin += self.image.get_width()
             ymin = max( ymin,self.image.get_height()+4)
         self.set_size_request(max(xmin,120),max(ymin,25))
-    
+
     def on_enter_cb(self,widget,event):
         """ On mouse-over hightlight border"""
         self.border_gc.line_width = 3
@@ -348,7 +357,7 @@ class PersonBoxWidget( gtk.DrawingArea, _PersonWidget_base):
         else:
             self.window.draw_rectangle(self.border_gc, False, 0, 0, alloc.width-4, alloc.height-4)
 
-class FormattingHelper:
+class FormattingHelper(object):
     def __init__(self,dbstate):
         self.dbstate = dbstate
         self._text_cache = {}
@@ -826,9 +835,9 @@ class PedigreeView(PageView.PersonNavView):
             if not lst[i]:
                 # No person -> show empty box
                 if cairo_available:
-                    pw = PersonBoxWidget_cairo( self.format_helper, None, False, 0, None);
+                    pw = PersonBoxWidget_cairo( self, self.format_helper, None, False, 0, None);
                 else:
-                    pw = PersonBoxWidget( self.format_helper, None, False, 0, None);
+                    pw = PersonBoxWidget( self, self.format_helper, None, False, 0, None);
                 if i > 0 and lst[((i+1)/2)-1]:
                     fam_h = None
                     fam = lst[((i+1)/2)-1][2]
@@ -863,9 +872,9 @@ class PedigreeView(PageView.PersonNavView):
                                                         obj.get_path()),
                                             rectangle=ph.get_rectangle())
                 if cairo_available:
-                    pw = PersonBoxWidget_cairo( self.format_helper, lst[i][0], lst[i][3], positions[i][0][3], image);
+                    pw = PersonBoxWidget_cairo( self, self.format_helper, lst[i][0], lst[i][3], positions[i][0][3], image);
                 else:
-                    pw = PersonBoxWidget( self.format_helper, lst[i][0], lst[i][3], positions[i][0][3], image);
+                    pw = PersonBoxWidget( self, self.format_helper, lst[i][0], lst[i][3], positions[i][0][3], image);
                 if positions[i][0][3] < 7:
                     self.tooltips.set_tip(pw, self.format_helper.format_person(lst[i][0], 11))
 
@@ -964,7 +973,6 @@ class PedigreeView(PageView.PersonNavView):
         
         # Add navigation arrows
         if lst[0]:
-            #l = gtk.Button("‚óÄ")
             l=gtk.Button()
             l.add(gtk.Arrow(gtk.ARROW_LEFT, gtk.SHADOW_IN))
             childlist = find_children(self.dbstate.db,lst[0][0])
@@ -975,7 +983,6 @@ class PedigreeView(PageView.PersonNavView):
                 l.set_sensitive(False)
             ymid = int(math.floor(ymax/2))
             table_widget.attach(l,0,1,ymid,ymid+1,0,0,0,0)
-            #l = gtk.Button("‚ñ∂")
             l = gtk.Button()
             l.add(gtk.Arrow(gtk.ARROW_RIGHT, gtk.SHADOW_IN))
             if lst[1]:
@@ -1255,7 +1262,7 @@ class PedigreeView(PageView.PersonNavView):
     def find_tree(self,person,index,depth,lst,val=0):
         """Recursively build a list of ancestors"""
 
-        if depth > 5 or person == None:
+        if depth > 5 or person is None:
             return
 
         try:
@@ -1276,7 +1283,7 @@ class PedigreeView(PageView.PersonNavView):
         mrel = True
         frel = True
         family = self.dbstate.db.get_family_from_handle(family_handle)
-        if family != None:
+        if family is not None:
             for child_ref in family.get_child_ref_list():
                 if child_ref.ref == person.handle:
                     mrel = child_ref.mrel == gen.lib.ChildRefType.BIRTH
@@ -1284,11 +1291,11 @@ class PedigreeView(PageView.PersonNavView):
             
                     lst[index] = (person,val,family,alive)
                     father_handle = family.get_father_handle()
-                    if father_handle != None:
+                    if father_handle is not None:
                         father = self.dbstate.db.get_person_from_handle(father_handle)
                         self.find_tree(father,(2*index)+1,depth+1,lst,frel)
                     mother_handle = family.get_mother_handle()
-                    if mother_handle != None:
+                    if mother_handle is not None:
                         mother = self.dbstate.db.get_person_from_handle(mother_handle)
                         self.find_tree(mother,(2*index)+2,depth+1,lst,mrel)
 
@@ -1387,7 +1394,7 @@ class PedigreeView(PageView.PersonNavView):
         size_menu.append(entry)
 
         for n in range(2,6):
-            entry = gtk.ImageMenuItem(_("%d generations") % n)
+            entry = gtk.ImageMenuItem(ngettext("%d generation", "%d generations", n) %n)
             if self.force_size == n:
                 entry.set_image(current_size_image)
             entry.connect("activate", self.change_force_size_cb, n)
