@@ -1,4 +1,4 @@
-# Gramps - a GTK+/GNOME based genealogy program
+
 #
 # Copyright (C) 2001-2007  Donald N. Allingham
 #
@@ -17,7 +17,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: RelationView.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: RelationView.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 Relationship View
@@ -28,7 +28,8 @@ Relationship View
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from TransUtils import sgettext as _
+from gettext import ngettext
 import cgi
 
 #-------------------------------------------------------------------------
@@ -37,6 +38,7 @@ import cgi
 #
 #-------------------------------------------------------------------------
 import gtk
+import pango
 
 #-------------------------------------------------------------------------
 #
@@ -46,11 +48,11 @@ import gtk
 import gen.lib
 import PageView
 from BasicUtils import name_displayer
-from Utils import media_path_full
+from Utils import media_path_full, probably_alive
 import DateHandler
 import ThumbNails
 import Config
-import GrampsWidgets
+import widgets
 import Errors
 import gen.utils
 
@@ -92,7 +94,7 @@ _KP_ENTER = gtk.gdk.keyval_from_name("KP_Enter")
 _LEFT_BUTTON = 1
 _RIGHT_BUTTON = 3
 
-class AttachList:
+class AttachList(object):
 
     def __init__(self):
         self.list = []
@@ -486,7 +488,7 @@ class RelationshipView(PageView.PersonNavView):
         self.child = gtk.Table(self.attach.max_y, cols)
         self.child.set_border_width(12)
         self.child.set_col_spacings(12)
-        self.child.set_row_spacings(9)
+        self.child.set_row_spacings(0)
 
         for d in self.attach.list:
             x0 = d[1]
@@ -515,20 +517,21 @@ class RelationshipView(PageView.PersonNavView):
 
         table = gtk.Table(2, 3)
         table.set_col_spacings(12)
-        table.set_row_spacings(6)
+        table.set_row_spacings(0)
 
         # name and edit button
         name = name_displayer.display(person)
         fmt = '<span size="larger" weight="bold">%s</span>'
         text = fmt % cgi.escape(name)
-        label = GrampsWidgets.DualMarkupLabel(text, _GenderCode[person.gender])
+        label = widgets.DualMarkupLabel(text, _GenderCode[person.gender],
+                                        x_align=1, y_align=0)
         if Config.get(Config.RELEDITBTN):
-            button = GrampsWidgets.IconButton(self.edit_button_press, 
-                                              person.handle)
+            button = widgets.IconButton(self.edit_button_press, 
+                                        person.handle)
             self.tooltips.set_tip(button, _('Edit %s') % name)
         else:
             button = None
-        hbox = GrampsWidgets.LinkBox(label, button)
+        hbox = widgets.LinkBox(label, button)
 
         table.attach(hbox, 0, 2, 0, 1)
 
@@ -538,14 +541,14 @@ class RelationshipView(PageView.PersonNavView):
         table.attach(eventbox, 1, 2, 1, 2)
         subtbl = gtk.Table(3, 3)
         subtbl.set_col_spacings(12)
-        subtbl.set_row_spacings(6)
+        subtbl.set_row_spacings(0)
         eventbox.add(subtbl)
                 
         # GRAMPS ID
 
-        subtbl.attach(GrampsWidgets.BasicLabel("%s:" % _('ID')),
+        subtbl.attach(widgets.BasicLabel("%s:" % _('ID')),
                       1, 2, 0, 1, xoptions=gtk.FILL, yoptions=0)
-        subtbl.attach(GrampsWidgets.BasicLabel(person.gramps_id),
+        subtbl.attach(widgets.BasicLabel(person.gramps_id),
                       2, 3, 0, 1, yoptions=0)
 
         # Birth event.
@@ -555,9 +558,9 @@ class RelationshipView(PageView.PersonNavView):
         else:
             birth_title = _("Birth")
 
-        subtbl.attach(GrampsWidgets.BasicLabel("%s:" % birth_title),
+        subtbl.attach(widgets.BasicLabel("%s:" % birth_title),
                       1, 2, 1, 2, xoptions=gtk.FILL, yoptions=0)
-        subtbl.attach(GrampsWidgets.BasicLabel(self.format_event(birth)),
+        subtbl.attach(widgets.BasicLabel(self.format_event(birth)),
                       2, 3, 1, 2, yoptions=0)
 
         death = ReportUtils.get_death_or_fallback(self.dbstate.db, person)
@@ -566,11 +569,41 @@ class RelationshipView(PageView.PersonNavView):
         else:
             death_title = _("Death")
 
-        subtbl.attach(GrampsWidgets.BasicLabel("%s:" % death_title),
-                      1, 2, 2, 3, xoptions=gtk.FILL, yoptions=0)
-        subtbl.attach(GrampsWidgets.BasicLabel(self.format_event(death)),
-                      2, 3, 2, 3, yoptions=0)
+        showed_death = False
+        if birth:
+            birth_date = birth.get_date_object()
+            if (birth_date and birth_date.get_valid()):
+                if death:
+                    death_date = death.get_date_object()
+                    if (death_date and death_date.get_valid()):
+                        age = death_date - birth_date
+                        subtbl.attach(widgets.BasicLabel("%s:" % death_title),
+                                      1, 2, 2, 3, xoptions=gtk.FILL, yoptions=0)
+                        subtbl.attach(widgets.BasicLabel("%s (%s)" % 
+                                                         (self.format_event(death), age),
+                                                         pango.ELLIPSIZE_END),
+                                      2, 3, 2, 3, yoptions=0)
+                        showed_death = True
+                if not showed_death:
+                    age = gen.lib.date.Today() - birth_date
+                    if probably_alive(person, self.dbstate.db):
+                        subtbl.attach(widgets.BasicLabel("%s:" % _("Alive")),
+                                      1, 2, 2, 3, xoptions=gtk.FILL, yoptions=0)
+                        subtbl.attach(widgets.BasicLabel("(%s)" % age, pango.ELLIPSIZE_END),
+                                      2, 3, 2, 3, yoptions=0)
+                    else:
+                        subtbl.attach(widgets.BasicLabel("%s:" % _("Death")),
+                                      1, 2, 2, 3, xoptions=gtk.FILL, yoptions=0)
+                        subtbl.attach(widgets.BasicLabel("%s (%s)" % (_("unknown"), age), 
+                                                         pango.ELLIPSIZE_END),
+                                      2, 3, 2, 3, yoptions=0)
+                    showed_death = True
 
+        if not showed_death:
+            subtbl.attach(widgets.BasicLabel("%s:" % death_title),
+                          1, 2, 2, 3, xoptions=gtk.FILL, yoptions=0)
+            subtbl.attach(widgets.BasicLabel(self.format_event(death)),
+                          2, 3, 2, 3, yoptions=0)
 
         mbox = gtk.HBox()
         mbox.add(table)
@@ -648,10 +681,10 @@ class RelationshipView(PageView.PersonNavView):
             return ''
 
     def write_person_data(self, title, data):
-        self.attach.attach(GrampsWidgets.BasicLabel(title), _ALABEL_START, 
+        self.attach.attach(widgets.BasicLabel(title), _ALABEL_START, 
                            _ALABEL_STOP, self.row, self.row+1, 
                            xoptions=gtk.FILL|gtk.SHRINK)
-        self.attach.attach(GrampsWidgets.BasicLabel(data), 
+        self.attach.attach(widgets.BasicLabel(data), 
                            _ADATA_START, _ADATA_STOP, 
                            self.row, self.row+1)
         self.row += 1
@@ -659,22 +692,21 @@ class RelationshipView(PageView.PersonNavView):
     def write_label(self, title, family, is_parent, person = None):
         msg = '<span style="italic" weight="heavy">%s</span>' % cgi.escape(title)
         hbox = gtk.HBox()
-        label = GrampsWidgets.MarkupLabel(msg)
+        label = widgets.MarkupLabel(msg, x_align=1)
         # Draw the collapse/expand button:
-        if family != None:
-            if self.check_collapsed(person, family.handle):
-                arrow = GrampsWidgets.ExpandCollapseArrow(True,
-                                                self.expand_collapse_press,
-                                                (person, family.handle))
+        if family is not None:
+            if self.check_collapsed(person.handle, family.handle):
+                arrow = widgets.ExpandCollapseArrow(True,
+                                                    self.expand_collapse_press,
+                                                    (person, family.handle))
             else:
-                arrow = GrampsWidgets.ExpandCollapseArrow(False,
-                                                self.expand_collapse_press,
-                                                (person, family.handle))
+                arrow = widgets.ExpandCollapseArrow(False,
+                                                    self.expand_collapse_press,
+                                                    (person, family.handle))
         else :
             arrow = gtk.Arrow(gtk.ARROW_RIGHT, gtk.SHADOW_OUT)
         hbox.pack_start(arrow, False)
-
-        hbox.pack_start(label, False)
+        hbox.pack_start(label, True)
         self.attach.attach(hbox,
                            _LABEL_START, _LABEL_STOP, 
                            self.row, self.row+1, gtk.SHRINK|gtk.FILL)
@@ -683,11 +715,11 @@ class RelationshipView(PageView.PersonNavView):
             value = family.gramps_id
         else:
             value = ""
-        self.attach.attach(GrampsWidgets.BasicLabel(value), 
+        self.attach.attach(widgets.BasicLabel(value), 
                            _DATA_START, _DATA_STOP, 
                            self.row, self.row+1, gtk.SHRINK|gtk.FILL)
 
-        if family and self.check_collapsed(person, family.handle):
+        if family and self.check_collapsed(person.handle, family.handle):
             # show family names later
             pass
         else:
@@ -713,28 +745,29 @@ class RelationshipView(PageView.PersonNavView):
             if not self.toolbar_visible and not self.dbstate.db.readonly:
                 # Show edit-Buttons if toolbar is not visible
                 if self.reorder_sensitive:
-                    add = GrampsWidgets.IconButton(self.reorder, None, 
-                                                   gtk.STOCK_SORT_ASCENDING)
+                    add = widgets.IconButton(self.reorder_button_press, None, 
+                                             gtk.STOCK_SORT_ASCENDING)
                     self.tooltips.set_tip(add, ord_msg)
                     hbox.pack_start(add, False)
 
-                add = GrampsWidgets.IconButton(call_fcn, None, gtk.STOCK_ADD)
+                add = widgets.IconButton(call_fcn, None, gtk.STOCK_ADD)
                 self.tooltips.set_tip(add, add_msg)
                 hbox.pack_start(add, False)
 
                 if is_parent:
-                    add = GrampsWidgets.IconButton(self.select_family, None, gtk.STOCK_INDEX)
+                    add = widgets.IconButton(self.select_family, None,
+                                             gtk.STOCK_INDEX)
                     self.tooltips.set_tip(add, sel_msg)
                     hbox.pack_start(add, False)
 
             if family:
-                edit = GrampsWidgets.IconButton(self.edit_family, family.handle, 
-                                                gtk.STOCK_EDIT)
+                edit = widgets.IconButton(self.edit_family, family.handle, 
+                                          gtk.STOCK_EDIT)
                 self.tooltips.set_tip(edit, edit_msg)
                 hbox.pack_start(edit, False)
                 if not self.dbstate.db.readonly:
-                    delete = GrampsWidgets.IconButton(del_fcn, family.handle, 
-                                                      gtk.STOCK_REMOVE)
+                    delete = widgets.IconButton(del_fcn, family.handle, 
+                                                gtk.STOCK_REMOVE)
                     self.tooltips.set_tip(delete, del_msg)
                     hbox.pack_start(delete, False)
             self.attach.attach(hbox, _BTN_START, _BTN_STOP, self.row, self.row+1)
@@ -746,7 +779,7 @@ class RelationshipView(PageView.PersonNavView):
         family = self.dbstate.db.get_family_from_handle(family_handle)
         if not family:
             return
-        if person and self.check_collapsed(person, family_handle):
+        if person and self.check_collapsed(person.handle, family_handle):
             # don't show rest
             self.write_label("%s:" % _('Parents'), family, True, person)
             self.row -= 1 # back up one row for summary names
@@ -758,7 +791,7 @@ class RelationshipView(PageView.PersonNavView):
             else:
                 count = 0
             if count > 1 :
-                childmsg = _(" (%d siblings)") % count
+                childmsg = ngettext(" (%d sibling)", " (%d siblings)", count) % count
             elif count == 1 :
                 gender = self.dbstate.db.get_person_from_handle(\
                                         child_list[0]).gender
@@ -788,51 +821,88 @@ class RelationshipView(PageView.PersonNavView):
 
             if self.show_siblings:
                 active = self.dbstate.active.handle
-
-                child_list = [ref.ref for ref in family.get_child_ref_list()]
-
-                label_cell = self.build_label_cell(_('Siblings'))
-                label_cell.set_alignment(0, 0)
-                self.attach.attach(
-                    label_cell, _CLABEL_START-1, _CLABEL_STOP-1, self.row, 
-                    self.row+1, xoptions=gtk.FILL|gtk.SHRINK,
-                    yoptions=gtk.FILL)
-
                 hbox = gtk.HBox()
-                addchild = GrampsWidgets.IconButton(
-                                self.add_child_to_fam, 
-                                family.handle, 
-                                gtk.STOCK_ADD)
-                self.tooltips.set_tip(addchild, 
-                                      _('Add new child to family'))
-                selchild = GrampsWidgets.IconButton(
-                                self.sel_child_to_fam, 
-                                family.handle, 
-                                gtk.STOCK_INDEX)
-                self.tooltips.set_tip(selchild, 
-                                      _('Add existing child to family'))
-                hbox.pack_start(addchild, False)
-                hbox.pack_start(selchild, False)
-
+                if self.check_collapsed(person.handle, "SIBLINGS"):
+                    arrow = widgets.ExpandCollapseArrow(True,
+                                                        self.expand_collapse_press,
+                                                        (person, "SIBLINGS"))
+                else:
+                    arrow = widgets.ExpandCollapseArrow(False,
+                                                        self.expand_collapse_press,
+                                                        (person, "SIBLINGS"))
+                hbox.pack_start(arrow, False)
+                label_cell = self.build_label_cell(_('Siblings'))
+                hbox.pack_start(label_cell, True)
                 self.attach.attach(
-                    hbox, _CLABEL_START, _CLABEL_STOP, self.row, 
+                    hbox, _CLABEL_START-1, _CLABEL_STOP-1, self.row, 
                     self.row+1, xoptions=gtk.FILL|gtk.SHRINK,
                     yoptions=gtk.FILL)
 
-                self.row += 1
-                vbox = gtk.VBox()
-                i = 1
-                for child_handle in child_list:
-                    child_should_be_linked = (child_handle != active)
-                    self.write_child(vbox, child_handle, i, child_should_be_linked)
-                    i += 1
-                eventbox = gtk.EventBox()
-                if self.use_shade:
-                    eventbox.modify_bg(gtk.STATE_NORMAL, self.color)
-                eventbox.add(vbox)
-                self.attach.attach(
-                    eventbox, _CDATA_START-1, _CDATA_STOP-1, self.row,
-                    self.row+1)
+                if self.check_collapsed(person.handle, "SIBLINGS"):
+                    hbox = gtk.HBox()
+                    child_list = [ref.ref for ref in family.get_child_ref_list()
+                                  if ref.ref != active]
+                    if child_list:
+                        count = len(child_list)
+                    else:
+                        count = 0
+                    if count > 1 :
+                        childmsg = ngettext(" (%d sibling)"," (%d siblings)", count) % count
+                    elif count == 1 :
+                        gender = self.dbstate.db.get_person_from_handle(\
+                                                child_list[0]).gender
+                        if gender == gen.lib.Person.MALE :
+                            childmsg = _(" (1 brother)")
+                        elif gender == gen.lib.Person.FEMALE :
+                            childmsg = _(" (1 sister)")
+                        else :
+                            childmsg = _(" (1 sibling)")
+                    else :
+                        childmsg = _(" (only child)")
+                    box = self.get_people_box(post_msg=childmsg)
+                    eventbox = gtk.EventBox()
+                    if self.use_shade:
+                        eventbox.modify_bg(gtk.STATE_NORMAL, self.color)
+                    eventbox.add(box)
+                    self.attach.attach(
+                        eventbox, _PDATA_START, _PDATA_STOP,
+                        self.row, self.row+1)
+                    self.row += 1 # now advance it
+                else:
+                    hbox = gtk.HBox()
+                    addchild = widgets.IconButton(self.add_child_to_fam, 
+                                                  family.handle, 
+                                                  gtk.STOCK_ADD)
+                    self.tooltips.set_tip(addchild, 
+                                          _('Add new child to family'))
+                    selchild = widgets.IconButton(self.sel_child_to_fam, 
+                                                  family.handle, 
+                                                  gtk.STOCK_INDEX)
+                    self.tooltips.set_tip(selchild, 
+                                          _('Add existing child to family'))
+                    hbox.pack_start(addchild, False)
+                    hbox.pack_start(selchild, False)
+
+                    self.attach.attach(
+                        hbox, _CLABEL_START, _CLABEL_STOP, self.row, 
+                        self.row+1, xoptions=gtk.FILL|gtk.SHRINK,
+                        yoptions=gtk.FILL)
+
+                    self.row += 1
+                    vbox = gtk.VBox()
+                    i = 1
+                    child_list = [ref.ref for ref in family.get_child_ref_list()]
+                    for child_handle in child_list:
+                        child_should_be_linked = (child_handle != active)
+                        self.write_child(vbox, child_handle, i, child_should_be_linked)
+                        i += 1
+                    eventbox = gtk.EventBox()
+                    if self.use_shade:
+                        eventbox.modify_bg(gtk.STATE_NORMAL, self.color)
+                    eventbox.add(vbox)
+                    self.attach.attach(
+                        eventbox, _CDATA_START-1, _CDATA_STOP, self.row,
+                        self.row+1)
 
             self.row += 1
 
@@ -847,17 +917,16 @@ class RelationshipView(PageView.PersonNavView):
             initial_name = False
             if handle:
                 name = self.get_name(handle, True)
-                link_label = GrampsWidgets.LinkLabel(
-                    name, self._button_press, handle)
+                link_label = widgets.LinkLabel(name, self._button_press, handle)
                 if self.use_shade:
                     link_label.modify_bg(gtk.STATE_NORMAL, self.color)
                 if Config.get(Config.RELEDITBTN):
-                    button = GrampsWidgets.IconButton(self.edit_button_press, 
-                                                            handle)
+                    button = widgets.IconButton(self.edit_button_press, 
+                                                handle)
                     self.tooltips.set_tip(button, _('Edit %s') % name[0])
                 else:
                     button = None
-                vbox.pack_start(GrampsWidgets.LinkBox(link_label, button),
+                vbox.pack_start(widgets.LinkBox(link_label, button),
                                 expand=False)
             else:
                 link_label = gtk.Label(_('Unknown'))
@@ -875,8 +944,8 @@ class RelationshipView(PageView.PersonNavView):
         else:
             format = "%s"
 
-        label = GrampsWidgets.MarkupLabel(format % cgi.escape(title))
-        label.set_alignment(0, 0)
+        label = widgets.MarkupLabel(format % cgi.escape(title),
+                                    x_align=1, y_align=0)
         if Config.get(Config.RELEDITBTN):
             label.set_padding(0, 5)
         self.attach.attach(label, _PLABEL_START, _PLABEL_STOP, self.row, 
@@ -887,16 +956,30 @@ class RelationshipView(PageView.PersonNavView):
         
         if handle:
             name = self.get_name(handle, True)
-            link_label = GrampsWidgets.LinkLabel(
-                name, self._button_press, handle)
+            person = self.dbstate.db.get_person_from_handle(handle)
+            parent = len(person.get_parent_family_handle_list()) > 0
+            format = ''
+            relation_display_theme = Config.get(Config.RELATION_DISPLAY_THEME)
+            if parent:
+                if relation_display_theme == "CLASSIC":
+                    format = 'underline="single" weight="heavy" style="italic"'
+                elif relation_display_theme == "WEBPAGE":
+                    format = 'foreground="blue" weight="heavy"'
+            else:
+                if relation_display_theme == "CLASSIC":
+                    format = 'underline="single"'
+                elif relation_display_theme == "WEBPAGE":
+                    format = 'foreground="blue"'
+            link_label = widgets.LinkLabel(name, self._button_press, 
+                                           handle, format)
             if self.use_shade:
                 link_label.modify_bg(gtk.STATE_NORMAL, self.color)
             if Config.get(Config.RELEDITBTN):
-                button = GrampsWidgets.IconButton(self.edit_button_press, handle)
+                button = widgets.IconButton(self.edit_button_press, handle)
                 self.tooltips.set_tip(button, _('Edit %s') % name[0])
             else:
                 button = None
-            vbox.pack_start(GrampsWidgets.LinkBox(link_label, button))
+            vbox.pack_start(widgets.LinkBox(link_label, button))
         else:
             link_label = gtk.Label(_('Unknown'))
             link_label.set_alignment(0, 1)
@@ -906,7 +989,7 @@ class RelationshipView(PageView.PersonNavView):
         if self.show_details:
             value = self.info_string(handle)
             if value:
-                vbox.pack_start(GrampsWidgets.MarkupLabel(value))
+                vbox.pack_start(widgets.MarkupLabel(value))
 
         eventbox = gtk.EventBox()
         if self.use_shade:
@@ -924,22 +1007,48 @@ class RelationshipView(PageView.PersonNavView):
         else:
             format = "%s"
 
-        lbl = GrampsWidgets.MarkupLabel(format % cgi.escape(title))
+        lbl = widgets.MarkupLabel(format % cgi.escape(title),
+                                  x_align=1, y_align=.5)
         if Config.get(Config.RELEDITBTN):
             lbl.set_padding(0, 5)
         return lbl
 
     def write_child(self, vbox, handle, index, child_should_be_linked):
+        if not child_should_be_linked:
+            original_vbox = vbox
+            vbox = gtk.VBox()
+            frame = gtk.Frame()
+            frame.set_shadow_type(gtk.SHADOW_ETCHED_IN)
+            if self.use_shade:
+                ev = gtk.EventBox()
+                ev.modify_bg(gtk.STATE_NORMAL, self.color)
+                ev.add(vbox)
+                frame.add(ev)
+            else:
+                frame.add(vbox)
+            original_vbox.add(frame)
+        
         parent = has_children(self.dbstate.db,
                               self.dbstate.db.get_person_from_handle(handle))
 
         format = ''
+        relation_display_theme = Config.get(Config.RELATION_DISPLAY_THEME)
         if child_should_be_linked and parent:
-            format = 'underline="single" weight="heavy" style="italic"'
+            if relation_display_theme == "CLASSIC":
+                format = 'underline="single" weight="heavy" style="italic"'
+            elif relation_display_theme == "WEBPAGE":
+                format = 'foreground="blue" weight="heavy"'
+            else:
+                raise AttributeError("invalid relation-display-theme: '%s'" % relation_display_theme)
         elif child_should_be_linked and not parent:
-            format = 'underline="single"'
+            if relation_display_theme == "CLASSIC":
+                format = 'underline="single"'
+            elif relation_display_theme == "WEBPAGE":
+                format = 'foreground="blue"'
+            else:
+                raise AttributeError("invalid relation-display-theme: '%s'" % relation_display_theme)
         elif parent and not child_should_be_linked:
-            format = 'weight="heavy" style="italic"'
+            format = 'weight="heavy"'
 
         if child_should_be_linked:
             link_func = self._button_press
@@ -947,26 +1056,23 @@ class RelationshipView(PageView.PersonNavView):
             link_func = None
 
         name = self.get_name(handle, True)
-        link_label = GrampsWidgets.LinkLabel(name, link_func, handle, format)
+        link_label = widgets.LinkLabel(name, link_func, handle, format)
 
         if self.use_shade:
             link_label.modify_bg(gtk.STATE_NORMAL, self.color)
         link_label.set_padding(3, 0)
         if child_should_be_linked and Config.get(Config.RELEDITBTN):
-            button = GrampsWidgets.IconButton(self.edit_button_press, handle)
+            button = widgets.IconButton(self.edit_button_press, handle)
             self.tooltips.set_tip(button, _('Edit %s') % name[0])
         else:
             button = None
 
         hbox = gtk.HBox()
-        if child_should_be_linked:
-            l = GrampsWidgets.BasicLabel("%d." % index)
-        else:
-            l = GrampsWidgets.BasicLabel("> %d." % index)
-        l.set_width_chars(5)
+        l = widgets.BasicLabel("%d." % index)
+        l.set_width_chars(3)
         l.set_alignment(1.0, 0.5)
         hbox.pack_start(l, False, False, 0)
-        hbox.pack_start(GrampsWidgets.LinkBox(link_label, button),
+        hbox.pack_start(widgets.LinkBox(link_label, button),
                         False, False, 4)
         hbox.show()
         vbox.pack_start(hbox)
@@ -974,30 +1080,38 @@ class RelationshipView(PageView.PersonNavView):
         if self.show_details:
             value = self.info_string(handle)
             if value:
-                l = GrampsWidgets.MarkupLabel(value)
+                l = widgets.MarkupLabel(value)
                 l.set_padding(48, 0)
                 vbox.add(l)
-        
+
     def write_data(self, box, title, start_col=_SDATA_START,
                    stop_col=_SDATA_STOP):
-        box.add(GrampsWidgets.BasicLabel(title))
+        box.add(widgets.BasicLabel(title))
 
     def info_string(self, handle):
-        child = self.dbstate.db.get_person_from_handle(handle)
-        if not child:
+        person = self.dbstate.db.get_person_from_handle(handle)
+        if not person:
             return None
 
-        birth = ReportUtils.get_birth_or_fallback(self.dbstate.db, child)
+        birth = ReportUtils.get_birth_or_fallback(self.dbstate.db, person)
         if birth and birth.get_type != gen.lib.EventType.BIRTH:
-            bdate  = "<i>%s</i>" % cgi.escape(DateHandler.get_date(birth))
+            sdate = DateHandler.get_date(birth)
+            if sdate:
+                bdate  = "<i>%s</i>" % cgi.escape(sdate)
+            else:
+                bdate = ""
         elif birth:
             bdate  = cgi.escape(DateHandler.get_date(birth))
         else:
             bdate = ""
 
-        death = ReportUtils.get_death_or_fallback(self.dbstate.db, child)
+        death = ReportUtils.get_death_or_fallback(self.dbstate.db, person)
         if death and death.get_type != gen.lib.EventType.DEATH:
-            ddate  = "<i>%s</i>" % cgi.escape(DateHandler.get_date(death))
+            sdate = DateHandler.get_date(death)
+            if sdate:
+                ddate  = "<i>%s</i>" % cgi.escape(sdate)
+            else:
+                ddate = ""
         elif death:
             ddate  = cgi.escape(DateHandler.get_date(death))
         else:
@@ -1009,32 +1123,33 @@ class RelationshipView(PageView.PersonNavView):
                 'deathdate' : ddate
                 }
         elif bdate:
-            value = _("b. %s") % (bdate)
+            value = _("short for born|b. %s") % (bdate)
         elif ddate:
-            value = _("d. %s") % (ddate)
+            value = _("short for dead|d. %s") % (ddate)
         else:
             value = ""
         return value
 
-    def check_collapsed(self, person, handle):
+    def check_collapsed(self, person_handle, handle):
         """ Return true if collapsed. """
-        return (handle in self.collapsed_items.get(person.handle, []))
+        return (handle in self.collapsed_items.get(person_handle, []))
 
     def expand_collapse_press(self, obj, event, pair):
-        """ Calback function for ExpandCollapseArrow, user param is pair,
-            which is a tuple (person, handle) with handle the section of which 
-            the collapse state must change, so a parent, siblings id, 
-            family id, family children id, etc
+        """ Calback function for ExpandCollapseArrow, user param is
+            pair, which is a tuple (object, handle) which handles the
+            section of which the collapse state must change, so a
+            parent, siblings id, family id, family children id, etc.
+            NOTE: object must be a thing that has a handle field.
         """
         if button_activated(event, _LEFT_BUTTON):
-            person, handle = pair
-            if self.collapsed_items.has_key(person.handle):
-                if handle in self.collapsed_items[person.handle]:
-                    self.collapsed_items[person.handle].remove(handle)
+            object, handle = pair
+            if object.handle in self.collapsed_items:
+                if handle in self.collapsed_items[object.handle]:
+                    self.collapsed_items[object.handle].remove(handle)
                 else:
-                    self.collapsed_items[person.handle].append(handle)
+                    self.collapsed_items[object.handle].append(handle)
             else:
-                self.collapsed_items[person.handle] = [handle]
+                self.collapsed_items[object.handle] = [handle]
             self.redraw()
 
     def _button_press(self, obj, event, handle):
@@ -1073,7 +1188,7 @@ class RelationshipView(PageView.PersonNavView):
 
     def write_relationship(self, box, family):
         msg = _('Relationship type: %s') % cgi.escape(str(family.get_relationship()))
-        box.add(GrampsWidgets.MarkupLabel(msg))
+        box.add(widgets.MarkupLabel(msg))
 
     def place_name(self, handle):
         p = self.dbstate.db.get_place_from_handle(handle)
@@ -1128,7 +1243,7 @@ class RelationshipView(PageView.PersonNavView):
 
     def write_family(self, family_handle, person = None):
         family = self.dbstate.db.get_family_from_handle(family_handle)
-        if family == None:
+        if family is None:
             from QuestionDialog import WarningDialog
             WarningDialog(
                 _('Broken family detected'),
@@ -1143,7 +1258,7 @@ class RelationshipView(PageView.PersonNavView):
             handle = father_handle
 
         # collapse button
-        if self.check_collapsed(person, family_handle):
+        if self.check_collapsed(person.handle, family_handle):
             # show "> Family: ..." and nothing else
             self.write_label("%s:" % _('Family'), family, False, person)
             self.row -= 1 # back up
@@ -1152,10 +1267,8 @@ class RelationshipView(PageView.PersonNavView):
                 count = len(child_list)
             else:
                 count = 0
-            if count > 1 :
-                childmsg = _(" (%d children)") % count
-            elif count == 1 :
-                childmsg = _(" (1 child)")
+            if count >= 1 :
+                childmsg = ngettext(" (%d child)"," (%d children)", count) % count
             else :
                 childmsg = _(" (no children)")
             box = self.get_people_box(handle, post_msg=childmsg)
@@ -1176,50 +1289,78 @@ class RelationshipView(PageView.PersonNavView):
                 if not self.write_marriage(box, family):
                     self.write_relationship(box, family)
 
-            child_list = family.get_child_ref_list()
-
-            label_cell = self.build_label_cell(_('Children'))
-            label_cell.set_alignment(0, 0)
-            self.attach.attach(
-                label_cell, _CLABEL_START-1, _CLABEL_STOP-1, self.row, 
-                self.row+1, xoptions=gtk.FILL|gtk.SHRINK,
-                yoptions=gtk.FILL)
-
             hbox = gtk.HBox()
-            addchild = GrampsWidgets.IconButton(
-                            self.add_child_to_fam, 
-                            family.handle, 
-                            gtk.STOCK_ADD)
-            self.tooltips.set_tip(addchild, 
-                                  _('Add new child to family'))
-            selchild = GrampsWidgets.IconButton(
-                            self.sel_child_to_fam, 
-                            family.handle, 
-                            gtk.STOCK_INDEX)
-            self.tooltips.set_tip(selchild, 
-                                  _('Add existing child to family'))
-            hbox.pack_start(addchild, False)
-            hbox.pack_start(selchild, False)
+            if self.check_collapsed(family.handle, "CHILDREN"):
+                arrow = widgets.ExpandCollapseArrow(True,
+                                                    self.expand_collapse_press,
+                                                    (family, "CHILDREN"))
+            else:
+                arrow = widgets.ExpandCollapseArrow(False,
+                                                    self.expand_collapse_press,
+                                                    (family, "CHILDREN"))
+            hbox.pack_start(arrow, False)
+            label_cell = self.build_label_cell(_('Children'))
+            hbox.pack_start(label_cell, True)
             self.attach.attach(
-                hbox, _CLABEL_START, _CLABEL_STOP, self.row, 
+                hbox, _CLABEL_START-1, _CLABEL_STOP-1, self.row, 
                 self.row+1, xoptions=gtk.FILL|gtk.SHRINK,
                 yoptions=gtk.FILL)
 
-            vbox = gtk.VBox()
-            i = 1
-            for child_ref in child_list:
-                self.write_child(vbox, child_ref.ref, i, True)
-                i += 1
+            if self.check_collapsed(family.handle, "CHILDREN"):
+                hbox = gtk.HBox()
+                child_list = family.get_child_ref_list()
+                if child_list:
+                    count = len(child_list)
+                else:
+                    count = 0
+                if count >= 1 :
+                    childmsg = ngettext(" (%d child)"," (%d children)", count) % count
+                else :
+                    childmsg = _(" (no children)")
+                box = self.get_people_box(post_msg=childmsg)
+                eventbox = gtk.EventBox()
+                if self.use_shade:
+                    eventbox.modify_bg(gtk.STATE_NORMAL, self.color)
+                eventbox.add(box)
+                self.attach.attach(
+                    eventbox, _PDATA_START, _PDATA_STOP,
+                    self.row, self.row+1)
+                self.row += 1 # now advance it
+            else:
+                hbox = gtk.HBox()
+                addchild = widgets.IconButton(self.add_child_to_fam, 
+                                              family.handle, 
+                                              gtk.STOCK_ADD)
+                self.tooltips.set_tip(addchild, 
+                                      _('Add new child to family'))
+                selchild = widgets.IconButton(self.sel_child_to_fam, 
+                                              family.handle, 
+                                              gtk.STOCK_INDEX)
+                self.tooltips.set_tip(selchild, 
+                                      _('Add existing child to family'))
+                hbox.pack_start(addchild, False)
+                hbox.pack_start(selchild, False)
+                self.attach.attach(
+                    hbox, _CLABEL_START, _CLABEL_STOP, self.row, 
+                    self.row+1, xoptions=gtk.FILL|gtk.SHRINK,
+                    yoptions=gtk.FILL)
 
-            self.row += 1
-            eventbox = gtk.EventBox()
-            if self.use_shade:
-                eventbox.modify_bg(gtk.STATE_NORMAL, self.color)
-            eventbox.add(vbox)
-            self.attach.attach(
-                eventbox, _CDATA_START-1, _CDATA_STOP-1, self.row,
-                self.row+1)
-            self.row += 1
+                vbox = gtk.VBox()
+                i = 1
+                child_list = family.get_child_ref_list()
+                for child_ref in child_list:
+                    self.write_child(vbox, child_ref.ref, i, True)
+                    i += 1
+
+                self.row += 1
+                eventbox = gtk.EventBox()
+                if self.use_shade:
+                    eventbox.modify_bg(gtk.STATE_NORMAL, self.color)
+                eventbox.add(vbox)
+                self.attach.attach(
+                    eventbox, _CDATA_START-1, _CDATA_STOP, self.row,
+                    self.row+1)
+                self.row += 1
 
     def edit_button_press(self, obj, event, handle):
         if button_activated(event, _LEFT_BUTTON):
@@ -1314,7 +1455,7 @@ class RelationshipView(PageView.PersonNavView):
         self.dbstate.db.commit_family(family, trans)
         self.dbstate.db.transaction_commit(trans, _("Add Child to Family"))
 
-    def sel_child_to_fam(self, obj, event, handle):
+    def sel_child_to_fam(self, obj, event, handle, surname=None):
         from Selectors import selector_factory
         if button_activated(event, _LEFT_BUTTON):
             SelectPerson = selector_factory('Person')
@@ -1420,6 +1561,10 @@ class RelationshipView(PageView.PersonNavView):
     def change_to(self, obj, handle):
         self.dbstate.change_active_handle(handle)
 
+    def reorder_button_press(self, obj, event, handle):
+        if button_activated(event, _LEFT_BUTTON):
+            self.reorder(obj)
+            
     def reorder(self, obj, dumm1=None, dummy2=None):
         if self.dbstate.active:
             try:
