@@ -37,7 +37,7 @@ import re
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from RelLib import Date
+from gen.lib import Date
 from _DateParser import DateParser
 from _DateDisplay import DateDisplay
 from _DateHandler import register_datehandler
@@ -107,6 +107,8 @@ class DateParserPL(DateParser):
         u'francuski republikański': Date.CAL_FRENCH,
         u'franc.'         : Date.CAL_FRENCH,
         u'perski'       : Date.CAL_PERSIAN,
+        u'swedish'      : Date.CAL_SWEDISH, 
+        u's'            : Date.CAL_SWEDISH, 
         }
 
     quality_to_int = {
@@ -137,7 +139,8 @@ class DateDisplayPL(DateDisplay):
 
     calendar = (
         "", u" (juliański)", u" (hebrajski)", 
-        u" (francuski republikański)", u" (perski)", u" (islamski)"
+        u" (francuski republikański)", u" (perski)", u" (islamski)", 
+        u" (swedish)" 
         )
 
     _mod_str = ("",u"przed ",u"po ",u"ok. ","","","")
@@ -175,7 +178,7 @@ class DateDisplayPL(DateDisplay):
             if date_val[3]:
                 return self.display_iso(date_val)
             else:
-                if date_val[0] == 0 and date_val[1] == 0:
+                if date_val[0] == date_val[1] == 0:
                     value = str(date_val[2])
                 else:
                     value = self._tformat.replace('%m',str(date_val[0]))
@@ -224,7 +227,7 @@ class DateDisplayPL(DateDisplay):
 
     def display(self,date):
         """
-        Returns a text string representing the date.
+        Return a text string representing the date.
         """
         mod = date.get_modifier()
         cal = date.get_calendar()
