@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_sk.py 11298 2008-11-13 08:42:05Z ldnp $
+# $Id: _Date_sk.py 11676 2009-01-20 15:38:29Z ldnp $
 
 """
 Slovak-specific classes for parsing and displaying dates.
@@ -71,6 +71,8 @@ class DateParserSK(DateParser):
         u'r'             : Date.CAL_FRENCH, 
         u'perzský'       : Date.CAL_PERSIAN, 
         u'p'             : Date.CAL_PERSIAN, 
+        u'swedish'      : Date.CAL_SWEDISH, 
+        u's'            : Date.CAL_SWEDISH, 
         }
 
     quality_to_int = {
@@ -102,7 +104,8 @@ class DateDisplaySK(DateDisplay):
 
     calendar = (
         "", u" (juliánský)", u" (hebrejský)", 
-        u" (republikánsky)", u" (perzský)", u" (islamský)"
+        u" (republikánsky)", u" (perzský)", u" (islamský)", 
+        u" (swedish)" 
         )
 
     _mod_str = ("", u"pred ", u"po ", u"okolo ", "", "", "")
