@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 10055 2008-02-18 20:07:09Z acraphae $
+# $Id: __init__.py 11952 2009-02-10 19:16:19Z ltosky $
 
 """
 Class handling language-specific selection for date parser and displayer.
@@ -42,10 +42,13 @@ import _Date_pt
 import _Date_ru
 import _Date_sk
 import _Date_sv
+import _Date_hr
+import _Date_ca
+import _Date_it
 
 # Initialize global parser
 try:
-    if LANG_TO_PARSER.has_key(LANG):
+    if LANG in LANG_TO_PARSER:
         parser = LANG_TO_PARSER[LANG]()
     else:
         parser = LANG_TO_PARSER[LANG_SHORT]()
@@ -64,7 +67,7 @@ except:
         val = 0
 
 try:
-    if LANG_TO_DISPLAY.has_key(LANG):
+    if LANG in LANG_TO_DISPLAY:
         displayer = LANG_TO_DISPLAY[LANG](val)
     else:
         displayer = LANG_TO_DISPLAY[LANG_SHORT](val)
