@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _PeopleModel.py 11325 2008-11-21 14:39:16Z ldnp $
+# $Id: _PeopleModel.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 TreeModel for the GRAMPS Person tree.
@@ -66,9 +66,9 @@ from Filters import SearchFilter, ExactSearchFilter
 from Lru import LRU
 
 _CACHE_SIZE = 250
+invalid_date_format = Config.get(Config.INVALID_DATE_FORMAT)
 
-
-class NodeTreeMap:
+class NodeTreeMap(object):
 
     def __init__(self):
 
@@ -127,7 +127,7 @@ class NodeTreeMap:
             return (self.top_iter2path[surname], index)
 
     def has_entry(self, handle):
-        return self.iter2path.has_key(handle)
+        return handle in self.iter2path
 
     def get_iter(self, path):
         try:
@@ -140,7 +140,7 @@ class NodeTreeMap:
             return None
         
     def has_top_node(self, node):
-        return self.sname_sub.has_key(node)
+        return node in self.sname_sub
 
     def find_next_node(self, node):
         try:
@@ -153,20 +153,20 @@ class NodeTreeMap:
             return self.path2iter.get((surname, val+1))
 
     def first_child(self, node):
-        if node == None:
+        if node is None:
             return self.top_path2iter[0]
         else:
             return self.path2iter.get((node, 0))
 
     def has_child(self, node):
-        if node == None:
+        if node is None:
             return len(self.sname_sub)
-        if self.sname_sub.has_key(node) and len(self.sname_sub[node]) > 0:
+        if node in self.sname_sub and len(self.sname_sub[node]) > 0:
             return True
         return False
 
     def number_of_children(self, node):
-        if node == None:
+        if node is None:
             return len(self.sname_sub)
         try:
             return len(self.sname_sub[node])
@@ -175,7 +175,7 @@ class NodeTreeMap:
 
     def get_nth_child(self, node, n):
         try:
-            if node == None:
+            if node is None:
                 return self.top_path2iter[n]
             try:
                 return self.path2iter[(node, n)]
@@ -542,7 +542,11 @@ class PeopleModel(gtk.GenericTreeModel):
                 birth = self.db.get_event_from_handle(b.ref)
                 date_str = DateHandler.get_date(birth)
                 if date_str != "":
-                    return cgi.escape(date_str)
+                    retval = cgi.escape(date_str)
+                if not DateHandler.get_date_valid(birth):
+                    return invalid_date_format % retval
+                else:
+                    return retval
             except:
                 return u''
         
@@ -555,7 +559,11 @@ class PeopleModel(gtk.GenericTreeModel):
             if (etype in [EventType.BAPTISM, EventType.CHRISTEN]
                 and er.get_role() == EventRoleType.PRIMARY
                 and date_str != ""):
-                return "<i>%s</i>" % cgi.escape(date_str)
+                retval = u"<i>%s</i>" % cgi.escape(date_str)
+                if not DateHandler.get_date_valid(event):
+                    return invalid_date_format % retval
+                else:
+                    return retval
         
         return u""
 
@@ -578,7 +586,11 @@ class PeopleModel(gtk.GenericTreeModel):
                 event = self.db.get_event_from_handle(ref.ref)
                 date_str = DateHandler.get_date(event)
                 if date_str != "":
-                    return cgi.escape(date_str)
+                    retval = cgi.escape(date_str)
+                if not DateHandler.get_date_valid(event):
+                    return invalid_date_format % retval
+                else:
+                    return retval
             except:
                 return u''
         
@@ -588,11 +600,14 @@ class PeopleModel(gtk.GenericTreeModel):
             event = self.db.get_event_from_handle(er.ref)
             etype = event.get_type()
             date_str = DateHandler.get_date(event)
-            if (etype in [EventType.BURIAL, EventType.CREMATION]
+            if (etype in [EventType.BURIAL, EventType.CREMATION, EventType.CAUSE_DEATH]
                 and er.get_role() == EventRoleType.PRIMARY
                 and date_str):
-                return "<i>%s</i>" % cgi.escape(date_str)
-        
+                retval = "<i>%s</i>" % cgi.escape(date_str)
+                if not DateHandler.get_date_valid(event):
+                    return invalid_date_format % retval
+                else:
+                    return retval
         return u""
 
     def column_birth_place(self, data, node):
@@ -652,8 +667,8 @@ class PeopleModel(gtk.GenericTreeModel):
             er.unserialize(event_ref)
             event = self.db.get_event_from_handle(er.ref)
             etype = event.get_type()
-            if etype in [EventType.BURIAL, EventType.CREMATION]\
-               and er.get_role() == EventRoleType.PRIMARY:
+            if (etype in [EventType.BURIAL, EventType.CREMATION, EventType.CAUSE_DEATH]
+                and er.get_role() == EventRoleType.PRIMARY):
                 place_handle = event.get_place_handle()
                 if place_handle:
                     place = self.db.get_place_from_handle(place_handle)
