@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2008       Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DisplayState.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: DisplayState.py 12560 2009-05-21 17:58:31Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -55,7 +56,7 @@ import Config
 from BasicUtils import name_displayer
 import const
 import ManagedWindow
-from PluginUtils import _PluginMgr
+from gen.plug import PluginManager
 
 DISABLED = -1
 
@@ -191,7 +192,7 @@ _RCT_BTM = '</menu></menu></menubar></ui>'
 import RecentFiles
 import os
 
-class RecentDocsMenu:
+class RecentDocsMenu(object):
     def __init__(self, uistate, state, fileopen):
         self.action_group = gtk.ActionGroup('RecentFiles')
         self.active = DISABLED
@@ -299,7 +300,6 @@ class DisplayState(gen.utils.Callback):
         'filters-changed' : (str, ), 
         'filter-name-changed' : (str, unicode, unicode), 
         'nameformat-changed' : None, 
-        'plugins-reloaded' : (list, list), 
         }
 
     def __init__(self, window, status, progress, warnbtn, uimanager, 
@@ -344,7 +344,8 @@ class DisplayState(gen.utils.Callback):
         """method that rebinds the relationship to the current rel calc
            Should be called after load or reload of plugins
         """
-        self.relationship = _PluginMgr.relationship_class()
+        pmgr = PluginManager.get_instance()
+        self.relationship = pmgr.get_relationship_calculator()
 
     def set_gendepth(self, value):
         """ Set the generations we search back for showing relationships
@@ -367,7 +368,7 @@ class DisplayState(gen.utils.Callback):
         self.relationship.connect_db_signals(dbstate)
         default_person = dbstate.db.get_default_person()
         active = dbstate.get_active_person()
-        if default_person == None or active == None:
+        if default_person is None or active is None:
             return u''
         if default_person.handle == self.disprel_defpers and \
                 active.handle == self.disprel_active :
@@ -427,7 +428,7 @@ class DisplayState(gen.utils.Callback):
 
     def modify_statusbar(self, dbstate, active=None):
         self.status.pop(self.status_id)
-        if dbstate.active == None:
+        if dbstate.active is None:
             self.status.push(self.status_id, "")
         else:
             person = dbstate.get_active_person()
