@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EmbeddedList.py 10108 2008-02-24 18:58:45Z acraphae $
+# $Id: _EmbeddedList.py 11877 2009-02-05 20:25:28Z gburto01 $
 
 #-------------------------------------------------------------------------
 #
@@ -173,9 +173,9 @@ class EmbeddedList(ButtonTab):
         else:
             dnd_types = [ self._DND_TYPE.target() ]
         
-        self.tree.drag_dest_set(gtk.DEST_DEFAULT_ALL, dnd_types,
-                                gtk.gdk.ACTION_COPY)
-        self.tree.drag_source_set(gtk.gdk.BUTTON1_MASK,
+        self.tree.enable_model_drag_dest(dnd_types,
+                                         gtk.gdk.ACTION_COPY)
+        self.tree.enable_model_drag_source(gtk.gdk.BUTTON1_MASK,
                                   [self._DND_TYPE.target()],
                                   gtk.gdk.ACTION_COPY)
         self.tree.connect('drag_data_get', self.drag_data_get)
@@ -241,7 +241,7 @@ class EmbeddedList(ButtonTab):
 
     def _find_row(self, x, y):
         row = self.tree.get_path_at_pos(x, y)
-        if row == None:
+        if row is None:
             return len(self.get_data())
         else:
             return row[0][0]
@@ -347,7 +347,7 @@ class EmbeddedList(ButtonTab):
         scroll.set_shadow_type(gtk.SHADOW_IN)
         scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         scroll.add(self.tree)
-        self.pack_start(scroll, True)
+        self.pack_end(scroll, True)
 
     def get_selected(self):
         """
@@ -417,7 +417,10 @@ class EmbeddedList(ButtonTab):
             name = self._column_names[pair[1]][0]
             renderer = gtk.CellRendererText()
             renderer.set_property('ellipsize', pango.ELLIPSIZE_END)
-            column = gtk.TreeViewColumn(name, renderer, text=pair[1])
+            if name == _("Date"):
+                column = gtk.TreeViewColumn(name, renderer, markup=pair[1])
+            else:
+                column = gtk.TreeViewColumn(name, renderer, text=pair[1])
 
             # insert the colum into the tree
             column.set_resizable(True)
