@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EventRefModel.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _EventRefModel.py 10618 2008-04-22 01:36:03Z dsblank $
 
 #-------------------------------------------------------------------------
 #
@@ -26,6 +26,7 @@
 #
 #-------------------------------------------------------------------------
 import gtk
+import cgi
 
 #-------------------------------------------------------------------------
 #
@@ -33,6 +34,14 @@ import gtk
 #
 #-------------------------------------------------------------------------
 import DateHandler
+import Config
+
+#-------------------------------------------------------------------------
+#
+# Globals
+#
+#-------------------------------------------------------------------------
+invalid_date_format = Config.get(Config.INVALID_DATE_FORMAT)
 
 #-------------------------------------------------------------------------
 #
@@ -46,23 +55,26 @@ class EventRefModel(gtk.ListStore):
         self.db = db
         for event_ref in event_list:
             event = db.get_event_from_handle(event_ref.ref)
-            self.append(row=[
-                str(event.get_type()), 
-                event.get_description(), 
-                event.get_gramps_id(), 
-                self.column_date(event_ref), 
-                self.column_place(event_ref), 
-                self.column_role(event_ref), 
-                self.column_sort_date(event_ref),
-                event_ref
-                ])
+            self.append(row=[str(event.get_type()), 
+                             event.get_description(), 
+                             event.get_gramps_id(), 
+                             self.column_date(event_ref), 
+                             self.column_place(event_ref), 
+                             self.column_role(event_ref), 
+                             self.column_sort_date(event_ref),
+                             event_ref
+                             ])
 
     def column_role(self, event_ref):
         return str(event_ref.get_role())
 
     def column_date(self, event_ref):
         event = self.db.get_event_from_handle(event_ref.ref)
-        return DateHandler.get_date(event)
+        retval = DateHandler.get_date(event)
+        if not DateHandler.get_date_valid(event):
+            return invalid_date_format % cgi.escape(retval)
+        else:
+            return retval
 
     def column_sort_date(self, event_ref):
         event = self.db.get_event_from_handle(event_ref.ref)
