@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _GalleryTab.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _GalleryTab.py 11877 2009-02-05 20:25:28Z gburto01 $
 
 #-------------------------------------------------------------------------
 #
@@ -57,8 +57,8 @@ from DisplayTabs._ButtonTab import ButtonTab
 # 
 #
 #-------------------------------------------------------------------------
-def make_launcher(prog, path):
-    return lambda x: Utils.launch(prog, path)
+def make_launcher(path):
+    return lambda x: Utils.open_file_with_default_application(path)
 
 #-------------------------------------------------------------------------
 #
@@ -115,19 +115,15 @@ class GalleryTab(ButtonTab):
         menu = gtk.Menu()
 
         ref_obj = self.dbstate.db.get_object_from_handle(obj.ref)
-        mime_type = ref_obj.get_mime_type()
-        if mime_type:
-            app = Mime.get_application(mime_type)
-            if app:
-                item = gtk.MenuItem(_('Open with %s') % app[1])
-                item.connect('activate', make_launcher(app[0],
-                                    Utils.media_path_full(self.dbstate.db, 
-                                                          ref_obj.get_path())))
-                item.show()
-                menu.append(item)
-                item = gtk.SeparatorMenuItem()
-                item.show()
-                menu.append(item)
+        media_path = Utils.media_path_full(self.dbstate.db, ref_obj.get_path())
+        if media_path:
+            item = gtk.MenuItem(_('View'))
+            item.connect('activate', make_launcher(media_path))
+            item.show()
+            menu.append(item)
+            item = gtk.SeparatorMenuItem()
+            item.show()
+            menu.append(item)
         
         for (needs_write_access, image, title, func) in itemlist:
             if image:
@@ -198,12 +194,12 @@ class GalleryTab(ButtonTab):
         
         # put everything together
         scroll.add(self.iconlist)
-        self.pack_start(scroll, True)
+        self.pack_end(scroll, True)
 
     def _update_internal_list(self, *obj):
         newlist = []
         node = self.iconmodel.get_iter_first()
-        while node != None:
+        while node is not None:
             newlist.append(self.iconmodel.get_value(node, 2))
             node = self.iconmodel.iter_next(node)
         for i in xrange(len(self.media_list)):
