@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditEventRef.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _EditEventRef.py 11905 2009-02-07 22:54:16Z gburto01 $
 
 #-------------------------------------------------------------------------
 #
@@ -45,10 +46,12 @@ import gen.lib
 
 from DisplayTabs import (SourceEmbedList, NoteTab, GalleryTab, 
                          EventBackRefList, AttrEmbedList)
-from GrampsWidgets import (PrivacyButton, MonitoredEntry, PlaceEntry, 
-                           MonitoredDate, MonitoredDataType)
+from widgets import (PrivacyButton, MonitoredEntry,
+                     MonitoredDate, MonitoredDataType)
 from _EditReference import RefTab, EditReference
 
+from ObjectEntries import PlaceEntry
+
 #-------------------------------------------------------------------------
 #
 # Constants
@@ -63,15 +66,14 @@ from _EditReference import RefTab, EditReference
 #-------------------------------------------------------------------------
 class EditEventRef(EditReference):
 
-    WIDTH_KEY = Config.EVENT_REF_WIDTH
-    HEIGHT_KEY = Config.EVENT_REF_HEIGHT
-
     def __init__(self, state, uistate, track, event, event_ref, update):
         EditReference.__init__(self, state, uistate, track, event, event_ref,
                                update)
         self._init_event()
 
     def _local_init(self):
+        self.width_key = Config.EVENT_REF_WIDTH
+        self.height_key = Config.EVENT_REF_HEIGHT
 
         self.top = glade.XML(const.GLADE_FILE, "event_eref_edit","gramps")
         self.set_window(self.top.get_widget('event_eref_edit'),
@@ -106,7 +108,7 @@ class EditEventRef(EditReference):
         self.define_ok_button(self.top.get_widget('ok'),self.ok_clicked)
         self.define_cancel_button(self.top.get_widget('cancel'))
         # FIXME: activate when help page is available
-        #self.define_help_button(self.top.get_widget('help'), 'tag')
+        #self.define_help_button(self.top.get_widget('help'))
 
     def _setup_fields(self):
         
