@@ -2,6 +2,8 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2008-2009  Stephane Charette <stephanecharette@gmail.com>
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,14 +20,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditMediaRef.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _EditMediaRef.py 11905 2009-02-07 22:54:16Z gburto01 $
 
 #-------------------------------------------------------------------------
 #
 # Standard python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from TransUtils import sgettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -44,12 +46,12 @@ import const
 import Config
 import Mime
 import ThumbNails
-from Utils import media_path_full
+import Utils
 from gen.lib import NoteType
 
 from DisplayTabs import (SourceEmbedList, AttrEmbedList, MediaBackRefList, 
                          NoteTab)
-from GrampsWidgets import MonitoredSpinButton, MonitoredEntry, PrivacyButton
+from widgets import MonitoredSpinButton, MonitoredEntry, PrivacyButton
 from _EditReference import RefTab, EditReference
 from AddMedia import AddMediaObject
 
@@ -60,9 +62,6 @@ from AddMedia import AddMediaObject
 #-------------------------------------------------------------------------
 class EditMediaRef(EditReference):
 
-    WIDTH_KEY = Config.MEDIA_REF_WIDTH
-    HEIGHT_KEY = Config.MEDIA_REF_HEIGHT
-
     def __init__(self, state, uistate, track, media, media_ref, update):
         EditReference.__init__(self, state, uistate, track, media,
                                media_ref, update)
@@ -72,7 +71,8 @@ class EditMediaRef(EditReference):
                            self._update_addmedia)
 
     def _local_init(self):
-
+        self.width_key = Config.MEDIA_REF_WIDTH
+        self.height_key = Config.MEDIA_REF_HEIGHT
         self.top = glade.XML(const.GLADE_FILE,
                                  "change_description","gramps")
 
@@ -80,6 +80,8 @@ class EditMediaRef(EditReference):
                         self.top.get_widget('title'),
                         _('Media Reference Editor'))
         self.define_warn_box(self.top.get_widget("warn_box"))
+        self.top.get_widget("label427").set_text(_("Y coordinate|Y"))
+        self.top.get_widget("label428").set_text(_("Y coordinate|Y"))
 
         tblref =  self.top.get_widget('table50')
         notebook = self.top.get_widget('notebook_ref')
@@ -100,7 +102,7 @@ class EditMediaRef(EditReference):
         the path.
         """
         self.mtype = self.source.get_mime_type()
-        fullpath = media_path_full(self.db, self.source.get_path())
+        fullpath = Utils.media_path_full(self.db, self.source.get_path())
         self.pix = ThumbNails.get_thumbnail_image(fullpath,
                                                   self.mtype)
         self.pixmap.set_from_pixbuf(self.pix)
@@ -117,26 +119,35 @@ class EditMediaRef(EditReference):
             self.top.get_widget("type").set_text("")
 
     def _setup_fields(self):
-        ebox = self.top.get_widget('eventbox')
-        ebox.connect('button-press-event', self.button_press_event)
-        
+        ebox_shared = self.top.get_widget('eventbox')
+        ebox_shared.connect('button-press-event', self.button_press_event)
+
+        if not self.dbstate.db.readonly:
+            self.button_press_coords = (0, 0)
+            ebox_ref = self.top.get_widget('eventbox1')
+            ebox_ref.connect('button-press-event', self.button_press_event_ref)
+            ebox_ref.connect('button-release-event', self.button_release_event_ref)
+            ebox_ref.add_events(gtk.gdk.BUTTON_PRESS_MASK)
+            ebox_ref.add_events(gtk.gdk.BUTTON_RELEASE_MASK)
+
         self.pixmap = self.top.get_widget("pixmap")
         
         coord = self.source_ref.get_rectangle()
         #upgrade path: set invalid (from eg old db) to none
-        if coord is not None and ((coord[0] == None and coord[1] == None
-                and coord[2] == None and coord[3] == None) or (
-            coord[0] == 0 and coord[1] == 0
-                and coord[2] == 100 and coord[3] == 100) or (
-            coord[0] == coord[2] and coord[1] == coord[3]
-           )):
+
+        if coord is not None and coord in (
+                (None, None, None, None),  
+                (0, 0, 100, 100),
+                (coord[0], coord[1], coord[0], coord[1])
+            ):
             coord = None
+
         self.rectangle = coord
         self.subpixmap = self.top.get_widget("subpixmap")
 
         self.draw_preview()
 
-        if coord and type(coord) == tuple:
+        if coord and isinstance(coord, tuple):
             self.top.get_widget("corner1_x").set_value(coord[0])
             self.top.get_widget("corner1_y").set_value(coord[1])
             self.top.get_widget("corner2_x").set_value(coord[2])
@@ -339,7 +350,7 @@ class EditMediaRef(EditReference):
             self.subpixmap.hide()
         else:
             try:
-                fullpath = media_path_full(self.db, path)
+                fullpath = Utils.media_path_full(self.db, path)
                 pixbuf = gtk.gdk.pixbuf_new_from_file(fullpath)
                 width = pixbuf.get_width()
                 height = pixbuf.get_height()
@@ -378,7 +389,96 @@ class EditMediaRef(EditReference):
     
     def button_press_event(self, obj, event):
         if event.button==1 and event.type == gtk.gdk._2BUTTON_PRESS:
-            self.view_media(obj)
+            photo_path = Utils.media_path_full(self.db, self.source.get_path())
+            Utils.open_file_with_default_application(photo_path)
+
+    def button_press_event_ref(self, widget, event):
+        """
+        Handle the button-press-event generated by the eventbox
+        parent of the subpixmap.  Remember these coordinates
+        so we can crop the picture when button-release-event
+        is received.
+        """
+        self.button_press_coords = (event.x, event.y)
+
+    def button_release_event_ref(self, widget, event):
+        """
+        Handle the button-release-event generated by the eventbox
+        parent of the subpixmap.  Crop the picture accordingly.
+        """
+
+        # reset the crop on double-click or click+CTRL
+        if (event.button==1 and event.type == gtk.gdk._2BUTTON_PRESS) or \
+            (event.button==1 and (event.state & gtk.gdk.CONTROL_MASK) ):
+            self.corner1_x_spinbutton.set_value(0)
+            self.corner1_y_spinbutton.set_value(0)
+            self.corner2_x_spinbutton.set_value(100)
+            self.corner2_y_spinbutton.set_value(100)
+
+        else:
+
+            # ensure the clicks happened at least 5 pixels away from each other
+            new_x1 = min(self.button_press_coords[0], event.x)
+            new_y1 = min(self.button_press_coords[1], event.y)
+            new_x2 = max(self.button_press_coords[0], event.x)
+            new_y2 = max(self.button_press_coords[1], event.y)
+
+            if new_x2 - new_x1 >= 5 and new_y2 - new_y1 >= 5:
+
+                # get the image size and calculate the X and Y offsets
+                # (image is centered when smaller than const.THUMBSCALE)
+                pixbuf = self.subpixmap.get_pixbuf();
+                w = pixbuf.get_width()
+                h = pixbuf.get_height()
+                x = (const.THUMBSCALE - w) / 2
+                y = (const.THUMBSCALE - h) / 2
+
+                # if the click was outside of the image,
+                # bring it within the boundaries
+                if new_x1 < x:
+                    new_x1 = x
+                if new_y1 < y:
+                    new_y1 = y
+                if new_x2 >= x + w:
+                    new_x2 = x + w - 1
+                if new_y2 >= y + h:
+                    new_y2 = y + h - 1
+
+                # get the old spinbutton % values
+                old_x1 = self.corner1_x_spinbutton.get_value()
+                old_y1 = self.corner1_y_spinbutton.get_value()
+                old_x2 = self.corner2_x_spinbutton.get_value()
+                old_y2 = self.corner2_y_spinbutton.get_value()
+                delta_x = old_x2 - old_x1   # horizontal scale
+                delta_y = old_y2 - old_y1   # vertical scale
+
+                # Took a while to figure out the math here.
+                #
+                #   1)  figure out the current crop % values
+                #       by doing the following:
+                #
+                #           xp = click_location_x / width * 100
+                #           yp = click_location_y / height * 100
+                #
+                #       but remember that click_location_x and _y
+                #       might not be zero-based for non-rectangular
+                #       images, so subtract the pixbuf "x" and "y"
+                #       to bring the values back to zero-based
+                #
+                #   2)  the minimum value cannot be less than the
+                #       existing crop value, so add the current
+                #       minimum to the new values
+
+                new_x1 = old_x1 + delta_x * (new_x1 - x) / w
+                new_y1 = old_y1 + delta_y * (new_y1 - y) / h
+                new_x2 = old_x1 + delta_x * (new_x2 - x) / w
+                new_y2 = old_y1 + delta_y * (new_y2 - y) / h
+
+                # set the new values
+                self.corner1_x_spinbutton.set_value(new_x1)
+                self.corner1_y_spinbutton.set_value(new_y1)
+                self.corner2_x_spinbutton.set_value(new_x2)
+                self.corner2_y_spinbutton.set_value(new_y2)
 
     def _update_addmedia(self, obj):
         """
@@ -390,13 +490,6 @@ class EditMediaRef(EditReference):
             obj.update()
         self.draw_preview()
 
-    def view_media(self, obj):
-        mime_type = self.source.get_mime_type()
-        app = Mime.get_application(mime_type)
-        if app:
-            from Utils import launch
-            launch(app[0], media_path_full(self.db, self.source.get_path()))
-
     def _connect_signals(self):
         self.define_cancel_button(self.top.get_widget('button84'))
         self.define_ok_button(self.top.get_widget('button82'),self.save)
@@ -473,14 +566,16 @@ class EditMediaRef(EditReference):
             self.top.get_widget("corner2_x").get_value_as_int(),
             self.top.get_widget("corner2_y").get_value_as_int(),
             )
+
         #do not set unset or invalid coord
-        if (coord[0] == None and coord[1] == None
-                and coord[2] == None and coord[3] == None) or (
-            coord[0] == 0 and coord[1] == 0
-                and coord[2] == 100 and coord[3] == 100) or (
-            coord[0] == coord[2] and coord[1] == coord[3]
-           ):
+
+        if coord is not None and coord in (
+                (None, None, None, None),  
+                (0, 0, 100, 100),
+                (coord[0], coord[1], coord[0], coord[1])
+            ):
             coord = None
+
         self.source_ref.set_rectangle(coord)
 
         #call callback if given
