@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditPlace.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _EditPlace.py 12560 2009-05-21 17:58:31Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -49,7 +50,7 @@ import gen.lib
 from Editors._EditPrimary import EditPrimary
 from DisplayTabs import (GrampsTab, LocationEmbedList, SourceEmbedList, 
                          GalleryTab, NoteTab, WebEmbedList, PlaceBackRefList)
-from GrampsWidgets import MonitoredEntry, PrivacyButton
+from widgets import MonitoredEntry, PrivacyButton
 from Errors import ValidationError
 from PlaceUtils import conv_lat_lon
 from QuestionDialog import ErrorDialog
@@ -113,13 +114,12 @@ class EditPlace(EditPrimary):
         return gen.lib.Place()
 
     def _local_init(self):
+        self.width_key = Config.PLACE_WIDTH
+        self.height_key = Config.PLACE_HEIGHT
         self.top = glade.XML(const.GLADE_FILE, "place_editor","gramps")
 
         self.set_window(self.top.get_widget("place_editor"), None,
                         self.get_menu_title())
-        width = Config.get(Config.PLACE_WIDTH)
-        height = Config.get(Config.PLACE_HEIGHT)
-        self.window.resize(width, height)
         tblmloc =  self.top.get_widget('table19')
         notebook = self.top.get_widget('notebook3')
         #recreate start page as GrampsTab
@@ -138,7 +138,7 @@ class EditPlace(EditPrimary):
     def _connect_signals(self):
         self.define_ok_button(self.top.get_widget('ok'), self.save)
         self.define_cancel_button(self.top.get_widget('cancel'))
-        self.define_help_button(self.top.get_widget('help'),'adv-plc')
+        self.define_help_button(self.top.get_widget('help'))
 
     def _setup_fields(self):
         mloc = self.obj.get_main_location()
@@ -191,12 +191,16 @@ class EditPlace(EditPrimary):
             self.obj.set_longitude, self.obj.get_longitude,
             self.db.readonly)
         self.longitude.connect("validate", self._validate_coordinate, "lon")
+        #force validation now with initial entry
+        self.top.get_widget("lon_entry").validate(force=True)
 
         self.latitude = MonitoredEntry(
             self.top.get_widget("lat_entry"),
             self.obj.set_latitude, self.obj.get_latitude,
             self.db.readonly)
         self.latitude.connect("validate", self._validate_coordinate, "lat")
+        #force validation now with initial entry
+        self.top.get_widget("lat_entry").validate(force=True)
         
     def _validate_coordinate(self, widget, text, typedeg):
         if (typedeg == 'lat') and not conv_lat_lon(text, "0", "ISO-D"):
@@ -253,10 +257,6 @@ class EditPlace(EditPrimary):
 
     def _cleanup_on_exit(self):
         self.backref_list.close()
-        (width, height) = self.window.get_size()
-        Config.set(Config.PLACE_WIDTH, width)
-        Config.set(Config.PLACE_HEIGHT, height)
-        Config.sync()
 
     def save(self, *obj):
         self.ok_button.set_sensitive(False)
@@ -301,7 +301,7 @@ class EditPlace(EditPrimary):
 # DeletePlaceQuery
 #
 #-------------------------------------------------------------------------
-class DeletePlaceQuery:
+class DeletePlaceQuery(object):
 
     def __init__(self, dbstate, uistate, place, person_list, family_list, 
                  event_list):
