@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditRepository.py 10108 2008-02-24 18:58:45Z acraphae $
+# $Id: _EditRepository.py 12560 2009-05-21 17:58:31Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -44,7 +45,7 @@ import const
 import Config
 import gen.lib
 
-from GrampsWidgets import MonitoredEntry, MonitoredDataType, PrivacyButton
+from widgets import MonitoredEntry, MonitoredDataType, PrivacyButton
 from DisplayTabs import AddrEmbedList, WebEmbedList, NoteTab, SourceBackRefList
 from Editors._EditPrimary import EditPrimary
 from QuestionDialog import ErrorDialog
@@ -72,15 +73,13 @@ class EditRepository(EditPrimary):
         return title
 
     def _local_init(self):
+        self.width_key = Config.REPO_WIDTH
+        self.height_key = Config.REPO_HEIGHT
         self.glade = glade.XML(const.GLADE_FILE, "repository_editor","gramps")
 
         self.set_window(self.glade.get_widget("repository_editor"), None, 
                         self.get_menu_title())
 
-        width = Config.get(Config.REPO_WIDTH)
-        height = Config.get(Config.REPO_HEIGHT)
-        self.window.resize(width, height)
-
     def build_menu_names(self, source):
         return (_('Edit Repository'), self.get_menu_title())        
 
@@ -134,7 +133,7 @@ class EditRepository(EditPrimary):
         self.glade.get_widget("vbox").pack_start(notebook, True, True)
 
     def _connect_signals(self):
-        self.define_help_button(self.glade.get_widget('help'),'adv-src')
+        self.define_help_button(self.glade.get_widget('help'))
         self.define_cancel_button(self.glade.get_widget('cancel'))
         self.define_ok_button(self.glade.get_widget('ok'), self.save)
 
@@ -176,12 +175,8 @@ class EditRepository(EditPrimary):
 
     def _cleanup_on_exit(self):
         self.backref_tab.close()
-        (width, height) = self.window.get_size()
-        Config.set(Config.REPO_WIDTH, width)
-        Config.set(Config.REPO_HEIGHT, height)
-        Config.sync()
 
-class DelRepositoryQuery:
+class DelRepositoryQuery(object):
     def __init__(self, dbstate, uistate, repository, sources):
         self.obj = repository
         self.db = dbstate.db
