@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditSource.py 7958 2007-01-23 03:37:13Z rshura $
+# $Id: _EditSource.py 12560 2009-05-21 17:58:31Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -35,7 +36,8 @@ log = logging.getLogger(".")
 # GTK/Gnome modules
 #
 #-------------------------------------------------------------------------
-import gtk.glade
+import gtk
+from gtk import glade
 
 #-------------------------------------------------------------------------
 #
@@ -44,12 +46,13 @@ import gtk.glade
 #-------------------------------------------------------------------------
 import const
 import Config
-import RelLib
-from _EditPrimary import EditPrimary
+import gen.lib
+from Editors._EditPrimary import EditPrimary
 
-from DisplayTabs import \
-     NoteTab,GalleryTab,DataEmbedList,SourceBackRefList,RepoEmbedList
-from GrampsWidgets import *
+from DisplayTabs import (NoteTab, GalleryTab, DataEmbedList,
+                         SourceBackRefList, RepoEmbedList)
+from widgets import MonitoredEntry, PrivacyButton
+from QuestionDialog import ErrorDialog
 
 #-------------------------------------------------------------------------
 #
@@ -58,13 +61,14 @@ from GrampsWidgets import *
 #-------------------------------------------------------------------------
 class EditSource(EditPrimary):
 
-    def __init__(self,dbstate,uistate,track,source):
+    def __init__(self, dbstate, uistate, track, source):
 
-        EditPrimary.__init__(self, dbstate, uistate, track,
-                             source, dbstate.db.get_source_from_handle)
+        EditPrimary.__init__(self, dbstate, uistate, track, source, 
+                             dbstate.db.get_source_from_handle, 
+                             dbstate.db.get_source_from_gramps_id)
 
     def empty_object(self):
-        return RelLib.Source()
+        return gen.lib.Source()
 
     def get_menu_title(self):
         title = self.obj.get_title()
@@ -75,54 +79,44 @@ class EditSource(EditPrimary):
         return title
 
     def _local_init(self):
-
+        self.width_key = Config.SOURCE_WIDTH
+        self.height_key = Config.SOURCE_HEIGHT
         assert(self.obj)
-        self.glade = gtk.glade.XML(const.gladeFile,"source_editor","gramps")
+        self.glade = glade.XML(const.GLADE_FILE, "source_editor","gramps")
 
-        self.set_window(self.glade.get_widget("source_editor"), None, self.get_menu_title())
-        width = Config.get(Config.SOURCE_WIDTH)
-        height = Config.get(Config.SOURCE_HEIGHT)
-        self.window.resize(width, height)
+        self.set_window(self.glade.get_widget("source_editor"), None, 
+                        self.get_menu_title())
 
     def _connect_signals(self):
         self.define_ok_button(self.glade.get_widget('ok'),self.save)
         self.define_cancel_button(self.glade.get_widget('cancel'))
-        self.define_help_button(self.glade.get_widget('help'),'adv-src')
+        self.define_help_button(self.glade.get_widget('help'))
 
     def _setup_fields(self):
-        self.author = MonitoredEntry(
-            self.glade.get_widget("author"),
-            self.obj.set_author,
-            self.obj.get_author,
-            self.db.readonly)
+        self.author = MonitoredEntry(self.glade.get_widget("author"),
+                                     self.obj.set_author, self.obj.get_author,
+                                     self.db.readonly)
 
-        self.pubinfo = MonitoredEntry(
-            self.glade.get_widget("pubinfo"),
-            self.obj.set_publication_info,
-            self.obj.get_publication_info,
-            self.db.readonly)
+        self.pubinfo = MonitoredEntry(self.glade.get_widget("pubinfo"),
+                                      self.obj.set_publication_info,
+                                      self.obj.get_publication_info,
+                                      self.db.readonly)
 
-        self.gid = MonitoredEntry(
-            self.glade.get_widget("gid"),
-            self.obj.set_gramps_id,
-            self.obj.get_gramps_id,
-            self.db.readonly)
+        self.gid = MonitoredEntry(self.glade.get_widget("gid"),
+                                  self.obj.set_gramps_id, 
+                                  self.obj.get_gramps_id, self.db.readonly)
 
-        self.priv = PrivacyButton(
-            self.glade.get_widget("private"),
-            self.obj, self.db.readonly)
+        self.priv = PrivacyButton(self.glade.get_widget("private"), self.obj, 
+                                  self.db.readonly)
 
-        self.abbrev = MonitoredEntry(
-            self.glade.get_widget("abbrev"),
-            self.obj.set_abbreviation,
-            self.obj.get_abbreviation,
-            self.db.readonly)
+        self.abbrev = MonitoredEntry(self.glade.get_widget("abbrev"),
+                                     self.obj.set_abbreviation,
+                                     self.obj.get_abbreviation, 
+                                     self.db.readonly)
 
-        self.title = MonitoredEntry(
-            self.glade.get_widget("source_title"),
-            self.obj.set_title,
-            self.obj.get_title,
-            self.db.readonly)
+        self.title = MonitoredEntry(self.glade.get_widget("source_title"),
+                                    self.obj.set_title, self.obj.get_title,
+                                    self.db.readonly)
 
     def _create_tabbed_pages(self):
         notebook = gtk.Notebook()
@@ -130,7 +124,8 @@ class EditSource(EditPrimary):
         self.note_tab = self._add_tab(
             notebook,
             NoteTab(self.dbstate, self.uistate, self.track,
-                    self.obj.get_note_object()))
+                    self.obj.get_note_list(), self.get_menu_title(),
+                    gen.lib.NoteType.SOURCE))
         
         self.gallery_tab = self._add_tab(
             notebook,
@@ -154,38 +149,52 @@ class EditSource(EditPrimary):
         
         self._setup_notebook_tabs( notebook)
         notebook.show_all()
-        self.glade.get_widget('vbox').pack_start(notebook,True)
+        self.glade.get_widget('vbox').pack_start(notebook, True)
 
-    def build_menu_names(self,source):
+    def build_menu_names(self, source):
         return (_('Edit Source'), self.get_menu_title())        
 
-    def save(self,*obj):
+    def save(self, *obj):
+        self.ok_button.set_sensitive(False)
         if self.object_is_empty():
-            from QuestionDialog import ErrorDialog
-            
             ErrorDialog(_("Cannot save source"),
                         _("No data exists for this source. Please "
                           "enter data or cancel the edit."))
+            self.ok_button.set_sensitive(True)
+            return
+        
+        (uses_dupe_id, id) = self._uses_duplicate_id()
+        if uses_dupe_id:
+            prim_object = self.get_from_gramps_id(id)
+            name = prim_object.get_title()
+            msg1 = _("Cannot save source. ID already exists.")
+            msg2 = _("You have attempted to use the existing GRAMPS ID with "
+                         "value %(id)s. This value is already used by '" 
+                         "%(prim_object)s'. Please enter a different ID or leave "
+                         "blank to get the next available ID value.") % {
+                         'id' : id, 'prim_object' : name }
+            ErrorDialog(msg1, msg2)
+            self.ok_button.set_sensitive(True)
             return
 
         trans = self.db.transaction_begin()
-        if self.obj.get_handle() == None:
-            self.db.add_source(self.obj,trans)
+        if not self.obj.get_handle():
+            self.db.add_source(self.obj, trans)
+            msg = _("Add Source (%s)") % self.obj.get_title()
         else:
-            self.db.commit_source(self.obj,trans)
-        self.db.transaction_commit(trans,
-                                   _("Edit Source (%s)") % self.obj.get_title())
+            if not self.obj.get_gramps_id():
+                self.obj.set_gramps_id(self.db.find_next_source_gramps_id())
+            self.db.commit_source(self.obj, trans)
+            msg = _("Edit Source (%s)") % self.obj.get_title()
+                        
+        self.db.transaction_commit(trans, msg)
         self.close()
 
     def _cleanup_on_exit(self):
         self.backref_tab.close()
-        (width, height) = self.window.get_size()
-        Config.set(Config.SOURCE_WIDTH, width)
-        Config.set(Config.SOURCE_HEIGHT, height)
-        Config.sync()
 
-class DelSrcQuery:
-    def __init__(self,dbstate,uistate,source,the_lists):
+class DelSrcQuery(object):
+    def __init__(self, dbstate, uistate, source, the_lists):
         self.source = source
         self.db = dbstate.db
         self.uistate = uistate
@@ -195,47 +204,47 @@ class DelSrcQuery:
         trans = self.db.transaction_begin()
         self.db.disable_signals()
         
-        (person_list,family_list,event_list,place_list,source_list,
-         media_list,repo_list) = self.the_lists
+        (person_list, family_list, event_list, place_list, source_list, 
+         media_list, repo_list) = self.the_lists
 
         src_handle_list = [self.source.get_handle()]
 
         for handle in person_list:
             person = self.db.get_person_from_handle(handle)
             person.remove_source_references(src_handle_list)
-            self.db.commit_person(person,trans)
+            self.db.commit_person(person, trans)
 
         for handle in family_list:
             family = self.db.get_family_from_handle(handle)
             family.remove_source_references(src_handle_list)
-            self.db.commit_family(family,trans)
+            self.db.commit_family(family, trans)
 
         for handle in event_list:
             event = self.db.get_event_from_handle(handle)
             event.remove_source_references(src_handle_list)
-            self.db.commit_event(event,trans)
+            self.db.commit_event(event, trans)
 
         for handle in place_list:
             place = self.db.get_place_from_handle(handle)
             place.remove_source_references(src_handle_list)
-            self.db.commit_place(place,trans)
+            self.db.commit_place(place, trans)
 
         for handle in source_list:
             source = self.db.get_source_from_handle(handle)
             source.remove_source_references(src_handle_list)
-            self.db.commit_source(source,trans)
+            self.db.commit_source(source, trans)
 
         for handle in media_list:
             media = self.db.get_object_from_handle(handle)
             media.remove_source_references(src_handle_list)
-            self.db.commit_media_object(media,trans)
+            self.db.commit_media_object(media, trans)
 
         for handle in repo_list:
             repo = self.db.get_repository_from_handle(handle)
             repo.remove_source_references(src_handle_list)
-            self.db.commit_repository(repo,trans)
+            self.db.commit_repository(repo, trans)
 
         self.db.enable_signals()
-        self.db.remove_source(self.source.get_handle(),trans)
+        self.db.remove_source(self.source.get_handle(), trans)
         self.db.transaction_commit(
-            trans,_("Delete Source (%s)") % self.source.get_title())
+            trans, _("Delete Source (%s)") % self.source.get_title())
