@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditSourceRef.py 7980 2007-01-25 05:37:24Z dallingham $
+# $Id: _EditSourceRef.py 11905 2009-02-07 22:54:16Z gburto01 $
 
 #-------------------------------------------------------------------------
 #
@@ -32,7 +33,7 @@ from gettext import gettext as _
 # GTK/Gnome modules
 #
 #-------------------------------------------------------------------------
-import gtk
+from gtk import glade
 
 #-------------------------------------------------------------------------
 #
@@ -40,12 +41,14 @@ import gtk
 #
 #-------------------------------------------------------------------------
 import const
-import RelLib
+import Config
+import gen.lib
 
-from DisplayTabs import \
-     NoteTab,TextTab,GalleryTab,SourceBackRefList,DataEmbedList,RepoEmbedList
-from GrampsWidgets import *
-from _EditReference import EditReference
+from DisplayTabs import (NoteTab, GalleryTab, SourceBackRefList, 
+                         DataEmbedList, RepoEmbedList)
+from widgets import (PrivacyButton, MonitoredEntry, MonitoredMenu, 
+                     MonitoredDate)
+from _EditReference import RefTab, EditReference
 
 #-------------------------------------------------------------------------
 #
@@ -53,14 +56,17 @@ from _EditReference import EditReference
 #
 #-------------------------------------------------------------------------
 class EditSourceRef(EditReference):
+
     def __init__(self, state, uistate, track, source, source_ref, update):
 
         EditReference.__init__(self, state, uistate, track, source,
                                source_ref, update)
 
     def _local_init(self):
+        self.width_key = Config.EVENT_REF_WIDTH
+        self.height_key = Config.EVENT_REF_HEIGHT
         
-        self.top = gtk.glade.XML(const.gladeFile, "source_ref_edit","gramps")
+        self.top = glade.XML(const.GLADE_FILE, "source_ref_edit","gramps")
         
         self.set_window(self.top.get_widget('source_ref_edit'),
                         self.top.get_widget('source_title'),        
@@ -69,20 +75,24 @@ class EditSourceRef(EditReference):
         self.define_warn_box(self.top.get_widget("warn_box"))
         self.define_expander(self.top.get_widget("src_expander"))
 
+        tblref =  self.top.get_widget('table67')
+        notebook = self.top.get_widget('notebook_ref')
+        #recreate start page as GrampsTab
+        notebook.remove_page(0)
+        self.reftab = RefTab(self.dbstate, self.uistate, self.track, 
+                              _('General'), tblref)
+        tblref =  self.top.get_widget('table68')
+        notebook = self.top.get_widget('notebook_src')
+        #recreate start page as GrampsTab
+        notebook.remove_page(0)
+        self.primtab = RefTab(self.dbstate, self.uistate, self.track, 
+                              _('General'), tblref)
+
     def _connect_signals(self):
         self.define_ok_button(self.top.get_widget('ok'),self.ok_clicked)
         self.define_cancel_button(self.top.get_widget('cancel'))
+        self.define_help_button(self.top.get_widget("help"))
 
-    def _cleanup_on_exit(self):
-        # FIXME: the second call was causing the problem, as it was
-        # re-setting the whole sref to its original state.
-        # that problem is fixed, but _cleanup_on_exit SHOULD NOT be run
-        # in close(), because close() is called on OK.
-        # Until this is fixed, notes, text and comments are not saved!!!
-	self.note_tab.cancel()
-	self.text_tab.cancel()
-	self.comment_tab.cancel()
-        
     def _setup_fields(self):
         self.ref_privacy = PrivacyButton(
             self.top.get_widget('privacy'), self.source_ref, self.db.readonly)
@@ -121,20 +131,15 @@ class EditSourceRef(EditReference):
             self.top.get_widget('confidence'),
             self.source_ref.set_confidence_level,
             self.source_ref.get_confidence_level, [
-            (_('Very Low'), RelLib.SourceRef.CONF_VERY_LOW),
-            (_('Low'), RelLib.SourceRef.CONF_LOW),
-            (_('Normal'), RelLib.SourceRef.CONF_NORMAL),
-            (_('High'), RelLib.SourceRef.CONF_HIGH),
-            (_('Very High'), RelLib.SourceRef.CONF_VERY_HIGH)],
+            (_('Very Low'), gen.lib.SourceRef.CONF_VERY_LOW),
+            (_('Low'), gen.lib.SourceRef.CONF_LOW),
+            (_('Normal'), gen.lib.SourceRef.CONF_NORMAL),
+            (_('High'), gen.lib.SourceRef.CONF_HIGH),
+            (_('Very High'), gen.lib.SourceRef.CONF_VERY_HIGH)],
             self.db.readonly)
 
-        table = self.top.get_widget('table67')
-	date_entry = ValidatableMaskedEntry(str)
-        date_entry.show()
-        table.attach(date_entry, 1, 2, 0, 1)
-
         self.date = MonitoredDate(
-            date_entry,
+            self.top.get_widget("date_entry"),
             self.top.get_widget("date_stat"), 
             self.source_ref.get_date_object(),
             self.uistate,
@@ -143,18 +148,20 @@ class EditSourceRef(EditReference):
 
     def _create_tabbed_pages(self):
         """
-        Creates the notebook tabs and inserts them into the main
+        Create the notebook tabs and inserts them into the main
         window.
-        
         """
-
         notebook_src = self.top.get_widget('notebook_src')
         notebook_ref = self.top.get_widget('notebook_ref')
 
+        self._add_tab(notebook_src, self.primtab)
+        self._add_tab(notebook_ref, self.reftab)
+
         self.note_tab = self._add_tab(
             notebook_src,
             NoteTab(self.dbstate, self.uistate, self.track,
-                    self.source.get_note_object()))
+                    self.source.get_note_list(), 
+                    notetype=gen.lib.NoteType.SOURCE))
         
         self.gallery_tab = self._add_tab(
             notebook_src,
@@ -178,14 +185,11 @@ class EditSourceRef(EditReference):
                               self.enable_warnbox
                               ))
 
-        self.text_tab = self._add_tab(
-            notebook_ref,
-            TextTab(self.dbstate, self.uistate, self.track,self.source_ref))
-
         self.comment_tab = self._add_tab(
             notebook_ref,
             NoteTab(self.dbstate, self.uistate, self.track,
-                    self.source_ref.get_note_object(),_('Comments')))
+                    self.source_ref.get_note_list(),
+                    notetype=gen.lib.NoteType.SOURCEREF))
 
         self._setup_notebook_tabs( notebook_src)
         self._setup_notebook_tabs( notebook_ref)
@@ -198,7 +202,7 @@ class EditSourceRef(EditReference):
             submenu_label = _('New Source')
         return (_('Source Reference Editor'),submenu_label)
         
-    def ok_clicked(self,obj):
+    def ok_clicked(self, obj):
 
         trans = self.db.transaction_begin()
         if self.source.handle:
