@@ -2,6 +2,8 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2007-2008  Brian G. Matherly
+# Copyright (C) 2008  Benny Malengier
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditRule.py 10094 2008-02-22 10:50:06Z acraphae $
+# $Id: _EditRule.py 12396 2009-03-30 10:19:10Z bmcage $
 
 """
 Custom Filter Editor tool.
@@ -81,6 +83,8 @@ _name2typeclass = {
     _('Event type:')         : gen.lib.EventType,
     _('Personal attribute:') : gen.lib.AttributeType,
     _('Family attribute:')   : gen.lib.AttributeType,
+    _('Event attribute:')    : gen.lib.AttributeType,
+    _('Media attribute:')    : gen.lib.AttributeType,
     _('Relationship type:')  : gen.lib.FamilyRelType,
     _('Marker type:')        : gen.lib.MarkerType,
     _('Note type:')          : gen.lib.NoteType,
@@ -184,30 +188,31 @@ class MyFilters(gtk.ComboBox):
 #-------------------------------------------------------------------------
 class MyLesserEqualGreater(gtk.ComboBox):
 
-    def __init__(self):
+    def __init__(self, default=0):
         gtk.ComboBox.__init__(self)
         store = gtk.ListStore(gobject.TYPE_STRING)
         self.set_model(store)
         cell = gtk.CellRendererText()
         self.pack_start(cell, True)
         self.add_attribute(cell, 'text', 0)
-        self.clist = [_('lesser than'), _('equal to'), _('greater than')]
-        for name in self.clist:
+        self.clist = ['lesser than', 'equal to', 'greater than']
+        self.clist_trans = [_('lesser than'), _('equal to'), _('greater than')]
+        for name in self.clist_trans:
             store.append(row=[name])
-        self.set_active(0)
+        self.set_active(default)
         self.show()
 
     def get_text(self):
         active = self.get_active()
         if active < 0:
-            return _('equal to')
+            return 'equal to'
         return self.clist[active]
 
     def set_text(self, val):
         if val in self.clist:
             self.set_active(self.clist.index(val))
         else:
-            self.set_active(self.clist.index(_('equal to')))
+            self.set_active(self.clist.index('equal to'))
 
 #-------------------------------------------------------------------------
 #
@@ -307,7 +312,7 @@ class MyID(gtk.HBox):
         selector = selector_factory(obj_class)
         inst = selector(self.dbstate, self.uistate, self.track)
         val = inst.run()
-        if val == None:
+        if val is None:
             self.set_text('')
         else:
             self.set_text(val.get_gramps_id())
@@ -371,7 +376,7 @@ class MySelect(gtk.ComboBoxEntry):
     def set_text(self, val):
         tc = self.type_class()
         tc.set_from_xml_str(val)
-        self.sel.set_values((tc.val, tc.string))
+        self.sel.set_values((int(tc), str(tc)))
 
 #-------------------------------------------------------------------------
 #
@@ -467,10 +472,14 @@ class EditRule(ManagedWindow.ManagedWindow):
                 l.show()
                 if v == _('Place:'):
                     t = MyPlaces([])
-                elif v == _('Reference count:'):
+                elif v in [_('Reference count:'),
+                            _('Number of instances:')
+                            ]:
                     t = MyInteger(0, 999)
                 elif v == _('Reference count must be:'):
                     t = MyLesserEqualGreater()
+                elif v == _('Number must be:'):
+                    t = MyLesserEqualGreater(2)
                 elif v == _('Number of generations:'):
                     t = MyInteger(1, 32)
                 elif v == _('ID:'):
@@ -488,7 +497,7 @@ class EditRule(ManagedWindow.ManagedWindow):
                     t = MyFilters(self.filterdb.get_filters('Event'))
                 elif v == _('Source filter name:'):
                     t = MyFilters(self.filterdb.get_filters('Source'))
-                elif _name2typeclass.has_key(v):
+                elif v in _name2typeclass:
                     t = MySelect(_name2typeclass[v])
                 elif v == _('Inclusive:'):
                     t = MyBoolean(_('Include original person'))
@@ -569,17 +578,43 @@ class EditRule(ManagedWindow.ManagedWindow):
                 tlist[i].set_text(r[i])
             
         self.selection.connect('changed', self.on_node_selected)
+        self.rname.connect('button-press-event', self._button_press)
+        self.rname.connect('key-press-event', self._key_press)
         self.get_widget('ok').connect('clicked', self.rule_ok)
         self.get_widget('cancel').connect('clicked', self.close_window)
         self.get_widget('help').connect('clicked', self.on_help_clicked)
 
         self.show()
 
+    def _button_press(self, obj, event):
+        if event.type == gtk.gdk._2BUTTON_PRESS and event.button == 1:
+            return self.expand_collapse()
+
+    def _key_press(self, obj, event):
+        if not event.state or event.state  in (gtk.gdk.MOD2_MASK, ):
+            if event.keyval in (gtk.keysyms.Return, gtk.keysyms.KP_Enter):
+                return self.expand_collapse()
+        return False    
+    
+    def expand_collapse(self):
+        """
+        Expand or collapse the selected parent name node.
+        Return True if change done, False otherwise
+        """
+        store, paths = self.selection.get_selected_rows()
+        if paths and len(paths[0]) == 1 :
+            if self.rname.row_expanded(paths[0]):
+                self.rname.collapse_row(paths[0])
+            else:
+                self.rname.expand_row(paths[0], 0)
+            return True
+        return False
+
     def on_help_clicked(self, obj):
         """
         Display the relevant portion of GRAMPS manual.
         """
-        GrampsDisplay.help('append-filtref')
+        GrampsDisplay.help()
 
     def close_window(self, obj):
         self.close()
