@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasRelType.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _HasRelType.py 11229 2008-11-01 15:36:42Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -44,8 +44,8 @@ class HasRelType(Rule):
     """Rule that checks for a person with a particular personal attribute"""
 
     labels      = [ _('Relationship type:') ]
-    name        = _('Family with the relationship type')
-    description = _("Matches family with the relationship type "
+    name        = _('Families with the relationship type')
+    description = _("Matches families with the relationship type "
                     "of a particular value")
     category    = _('General filters')
 
