@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasRelationship.py 7794 2006-12-13 09:21:53Z LosHawlos $
+# $Id: _HasRelationship.py 9912 2008-01-22 09:17:46Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -33,7 +33,7 @@ from gettext import gettext as _
 #
 #-------------------------------------------------------------------------
 from Filters.Rules._Rule import Rule
-from RelLib import FamilyRelType
+from gen.lib import FamilyRelType
 
 #-------------------------------------------------------------------------
 #
