@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _IsDescendantOf.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _IsDescendantOf.py 10874 2008-07-17 18:10:32Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -68,7 +68,7 @@ class IsDescendantOf(Rule):
         self.map = {}
 
     def apply(self,db,person):
-        return self.map.has_key(person.handle)
+        return person.handle in self.map
 
     def init_list(self,person,first):
         if not person:
