@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _IsDescendantOfFilterMatch.py 8559 2007-06-16 19:52:58Z rshura $
+# $Id: _IsDescendantOfFilterMatch.py 10874 2008-07-17 18:10:32Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -77,4 +77,4 @@ class IsDescendantOfFilterMatch(IsDescendantOf,MatchesFilter):
         self.map = {}
 
     def apply(self,db,person):
-        return self.map.has_key(person.handle)
+        return person.handle in self.map
