@@ -1,7 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2002-2006  Donald N. Allingham
+# Copyright (C) 2002-2007  Donald N. Allingham
+# Copyright (C) 2007-2008   Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,6 +28,8 @@ Package providing filter rules for GRAMPS.
 from _Disconnected import Disconnected
 from _Everyone import Everyone
 from _FamilyWithIncompleteEvent import FamilyWithIncompleteEvent
+from _HasAddress import HasAddress
+from _HasAssociation import HasAssociation
 from _HasAttribute import HasAttribute
 from _HasBirth import HasBirth
 from _HasCommonAncestorWith import HasCommonAncestorWith
@@ -36,12 +39,15 @@ from _HasDeath import HasDeath
 from _HasEvent import HasEvent
 from _HasFamilyAttribute import HasFamilyAttribute
 from _HasFamilyEvent import HasFamilyEvent
+from _HasGallery import HavePhotos
 from _HasIdOf import HasIdOf
+from _HasLDS import HasLDS
 from _HasNameOf import HasNameOf
 from _HasNote import HasNote
 from _HasNoteMatchingSubstringOf import HasNoteMatchingSubstringOf
 from _HasNoteRegexp import HasNoteRegexp
 from _HasRelationship import HasRelationship
+from _HasSource import HasSource
 from _HasSourceOf import HasSourceOf
 from _HasTextMatchingRegexpOf import HasTextMatchingRegexpOf
 from _HasTextMatchingSubstringOf import HasTextMatchingSubstringOf
@@ -49,7 +55,6 @@ from _HasUnknownGender import HasUnknownGender
 from _HasMarkerOf import HasMarkerOf
 from _HaveAltFamilies import HaveAltFamilies
 from _HaveChildren import HaveChildren
-from _HavePhotos import HavePhotos
 from _IncompleteNames import IncompleteNames
 from _IsAncestorOf import IsAncestorOf
 from _IsAncestorOfFilterMatch import IsAncestorOfFilterMatch
@@ -93,7 +98,7 @@ from _SearchName import SearchName
 from _RegExpName import RegExpName
 from _MatchIdOf import MatchIdOf
 from _RegExpIdOf import RegExpIdOf
-
+from _ChangedSince import ChangedSince
 
 #-------------------------------------------------------------------------
 #
@@ -107,7 +112,10 @@ editor_rule_list = [
     IsMale,
     IsDefaultPerson,
     IsBookmarked,
+    HasAddress,
+    HasAssociation,
     HasIdOf,
+    HasLDS,
     HasNameOf,
     HasRelationship,
     HasDeath,
@@ -117,6 +125,7 @@ editor_rule_list = [
     HasFamilyEvent,
     HasAttribute,
     HasFamilyAttribute,
+    HasSource,
     HasSourceOf,
     HasMarkerOf,
     HaveAltFamilies,
@@ -156,7 +165,9 @@ editor_rule_list = [
     HasTextMatchingSubstringOf,
     HasNote,
     HasNoteRegexp,
+    HasNoteMatchingSubstringOf,
     RegExpIdOf,
     Disconnected,
+    ChangedSince,
 ]
 
