@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Rule.py 10094 2008-02-22 10:50:06Z acraphae $
+# $Id: _Rule.py 12560 2009-05-21 17:58:31Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -32,7 +32,7 @@ from gettext import gettext as _
 # Rule
 #
 #-------------------------------------------------------------------------
-class Rule:
+class Rule(object):
     """Base rule class."""
 
     labels      = []
@@ -40,8 +40,8 @@ class Rule:
     category    = _('Miscellaneous filters')
     description = _('No description')
 
-    def __init__(self, list):
-        self.set_list(list)
+    def __init__(self, arg):
+        self.set_list(arg)
 
     def is_empty(self):
         return False
@@ -51,13 +51,14 @@ class Rule:
 
     def reset(self):
         pass
-
-    def set_list(self, list):
-        assert type(list) == type([]) or list == None, "Argument is not a list"
-        assert len(list) == len(self.labels), \
-               "Number of arguments does not match number of labels.\n"\
-               "list: %s\nlabels: %s" % (list,self.labels)
-        self.list = list
+ 
+    def set_list(self, arg):
+        assert isinstance(arg, list) or arg is None, "Argument is not a list"
+        assert len(arg) == len(self.labels), \
+               "ERROR: Number of arguments does not match number of labels.\n"\
+               "       list:   %s\n"\
+               "       labels: %s" % (arg,self.labels)
+        self.list = arg
 
     def values(self):
         return self.list
