@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EventSidebarFilter.py 7233 2006-08-22 16:49:21Z rshura $
+# $Id:_EventSidebarFilter.py 9912 2008-01-22 09:17:46Z acraphae $
 
 #-------------------------------------------------------------------------
 #
@@ -39,12 +39,14 @@ import gtk
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import GrampsWidgets
-import RelLib
+import widgets
+import gen.lib
 
-from _SidebarFilter import SidebarFilter
+from Filters.SideBar import SidebarFilter
 from Filters import GenericFilterFactory, build_filter_model, Rules
-from Filters.Rules.Event import *
+from Filters.Rules.Event import (RegExpIdOf, HasIdOf, HasNoteRegexp, 
+                                 HasNoteMatchingSubstringOf, MatchesFilter, 
+                                 HasEvent)
 
 GenericEventFilter = GenericFilterFactory('Event')
 #-------------------------------------------------------------------------
@@ -54,32 +56,35 @@ GenericEventFilter = GenericFilterFactory('Event')
 #-------------------------------------------------------------------------
 class EventSidebarFilter(SidebarFilter):
 
-    def __init__(self,uistate, clicked):
-        SidebarFilter.__init__(self,uistate)
+    def __init__(self, dbstate, uistate, clicked):
         self.clicked_func = clicked
-
-    def create_widget(self):
         self.filter_id = gtk.Entry()
         self.filter_desc = gtk.Entry()       
-        self.filter_event = RelLib.Event()
-        self.filter_event.set_type((RelLib.EventType.CUSTOM,''))
+        self.filter_event = gen.lib.Event()
+        self.filter_event.set_type((gen.lib.EventType.CUSTOM, u''))
         self.etype = gtk.ComboBoxEntry()
        
-        self.event_menu = GrampsWidgets.MonitoredDataType(
+        self.event_menu = widgets.MonitoredDataType(
             self.etype,
             self.filter_event.set_type,
             self.filter_event.get_type)
-
+        
         self.filter_date = gtk.Entry()
         self.filter_place = gtk.Entry()
         self.filter_note = gtk.Entry()
 
         self.filter_regex = gtk.CheckButton(_('Use regular expressions'))
 
-	self.generic = gtk.ComboBox()
-	cell = gtk.CellRendererText()
-	self.generic.pack_start(cell, True)
-	self.generic.add_attribute(cell, 'text', 0)
+        self.generic = gtk.ComboBox()
+
+        SidebarFilter.__init__(self, dbstate, uistate)
+
+    def create_widget(self):
+        cell = gtk.CellRendererText()
+        cell.set_property('width', self._FILTER_WIDTH)
+        cell.set_property('ellipsize', self._FILTER_ELLIPSIZE)
+        self.generic.pack_start(cell, True)
+        self.generic.add_attribute(cell, 'text', 0)
         self.on_filters_changed('Event')
 
         self.add_text_entry(_('ID'), self.filter_id)
@@ -92,17 +97,14 @@ class EventSidebarFilter(SidebarFilter):
         self.add_entry(None, self.filter_regex)
 
     def clear(self, obj):
-        self.filter_id.set_text('')
-        self.filter_desc.set_text('')
-        self.filter_date.set_text('')
-        self.filter_place.set_text('')
-        self.filter_note.set_text('')
-        self.etype.child.set_text('')
+        self.filter_id.set_text(u'')
+        self.filter_desc.set_text(u'')
+        self.filter_date.set_text(u'')
+        self.filter_place.set_text(u'')
+        self.filter_note.set_text(u'')
+        self.etype.child.set_text(u'')
         self.generic.set_active(0)
 
-    def clicked(self, obj):
-        self.clicked_func()
-
     def get_filter(self):
         gid = unicode(self.filter_id.get_text()).strip()
         desc = unicode(self.filter_desc.get_text()).strip()
@@ -110,11 +112,11 @@ class EventSidebarFilter(SidebarFilter):
         place = unicode(self.filter_place.get_text()).strip()
         note = unicode(self.filter_note.get_text()).strip()
         regex = self.filter_regex.get_active()
-	gen = self.generic.get_active() > 0
+        generic = self.generic.get_active() > 0
         etype = self.filter_event.get_type().xml_str()
 
         empty = not (gid or desc or date or place or note
-                     or etype or regex or gen)
+                     or etype or regex or generic)
         if empty:
             generic_filter = None
         else:
@@ -126,7 +128,7 @@ class EventSidebarFilter(SidebarFilter):
                     rule = HasIdOf([gid])
                 generic_filter.add_rule(rule)
 
-            rule = HasEvent([etype,date,place,desc])
+            rule = HasEvent([etype, date, place, desc])
             generic_filter.add_rule(rule)
                 
             if note:
@@ -136,19 +138,19 @@ class EventSidebarFilter(SidebarFilter):
                     rule = HasNoteMatchingSubstringOf([note])
                 generic_filter.add_rule(rule)
 
-	    if self.generic.get_active() != 0:
-		model = self.generic.get_model()
-		iter = self.generic.get_active_iter()
-		obj = model.get_value(iter, 0)
-		rule = MatchesFilter([obj])
-		generic_filter.add_rule(rule)
+        if self.generic.get_active() != 0:
+            model = self.generic.get_model()
+            node = self.generic.get_active_iter()
+            obj = model.get_value(node, 0)
+            rule = MatchesFilter([obj])
+            generic_filter.add_rule(rule)
 
         return generic_filter
 
-    def on_filters_changed(self,name_space):
+    def on_filters_changed(self, name_space):
         if name_space == 'Event':
-            all = GenericEventFilter()
-            all.set_name(_("None"))
-            all.add_rule(Rules.Event.AllEvents([]))
-            self.generic.set_model(build_filter_model('Event', [all]))
+            all_filter = GenericEventFilter()
+            all_filter.set_name(_("None"))
+            all_filter.add_rule(Rules.Event.AllEvents([]))
+            self.generic.set_model(build_filter_model('Event', [all_filter]))
             self.generic.set_active(0)
