@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _MediaSidebarFilter.py 7866 2007-01-04 05:09:41Z dallingham $
+# $Id: _MediaSidebarFilter.py 10339 2008-03-19 11:32:18Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -39,12 +39,11 @@ import gtk
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import GrampsWidgets
-import RelLib
-
-from _SidebarFilter import SidebarFilter
+from Filters.SideBar import SidebarFilter
 from Filters import GenericFilterFactory, build_filter_model, Rules
-from Filters.Rules.MediaObject import *
+from Filters.Rules.MediaObject import (RegExpIdOf, HasIdOf, HasMedia, 
+                                       HasNoteRegexp, MatchesFilter, 
+                                       HasNoteMatchingSubstringOf)
 
 GenericMediaFilter = GenericFilterFactory('MediaObject')
 #-------------------------------------------------------------------------
@@ -54,11 +53,8 @@ GenericMediaFilter = GenericFilterFactory('MediaObject')
 #-------------------------------------------------------------------------
 class MediaSidebarFilter(SidebarFilter):
 
-    def __init__(self,uistate, clicked):
-        SidebarFilter.__init__(self,uistate)
+    def __init__(self, dbstate, uistate, clicked):
         self.clicked_func = clicked
-
-    def create_widget(self):
         self.filter_id = gtk.Entry()
         self.filter_title = gtk.Entry()       
         self.filter_type = gtk.Entry()
@@ -69,10 +65,16 @@ class MediaSidebarFilter(SidebarFilter):
 
         self.filter_regex = gtk.CheckButton(_('Use regular expressions'))
 
-	self.generic = gtk.ComboBox()
-	cell = gtk.CellRendererText()
-	self.generic.pack_start(cell, True)
-	self.generic.add_attribute(cell, 'text', 0)
+        self.generic = gtk.ComboBox()
+
+        SidebarFilter.__init__(self, dbstate, uistate)
+
+    def create_widget(self):
+        cell = gtk.CellRendererText()
+        cell.set_property('width', self._FILTER_WIDTH)
+        cell.set_property('ellipsize', self._FILTER_ELLIPSIZE)
+        self.generic.pack_start(cell, True)
+        self.generic.add_attribute(cell, 'text', 0)
         self.on_filters_changed('MediaObject')
 
         self.add_text_entry(_('ID'), self.filter_id)
@@ -101,7 +103,7 @@ class MediaSidebarFilter(SidebarFilter):
         date = unicode(self.filter_date.get_text()).strip()
         note = unicode(self.filter_note.get_text()).strip()
         regex = self.filter_regex.get_active()
-	gen = self.generic.get_active() > 0
+        gen = self.generic.get_active() > 0
 
         empty = not (gid or title or mime or path or date
                      or note or regex or gen)
@@ -116,7 +118,7 @@ class MediaSidebarFilter(SidebarFilter):
                     rule = HasIdOf([gid])
                 generic_filter.add_rule(rule)
 
-            rule = HasMedia([title,mime,path,date])
+            rule = HasMedia([title, mime, path, date])
             generic_filter.add_rule(rule)
                 
             if note:
@@ -126,19 +128,20 @@ class MediaSidebarFilter(SidebarFilter):
                     rule = HasNoteMatchingSubstringOf([note])
                 generic_filter.add_rule(rule)
 
-	    if self.generic.get_active() != 0:
-		model = self.generic.get_model()
-		node = self.generic.get_active_iter()
-		obj = model.get_value(node, 0)
-		rule = MatchesFilter([obj])
-		generic_filter.add_rule(rule)
+        if self.generic.get_active() != 0:
+            model = self.generic.get_model()
+            node = self.generic.get_active_iter()
+            obj = model.get_value(node, 0)
+            rule = MatchesFilter([obj])
+            generic_filter.add_rule(rule)
 
         return generic_filter
 
-    def on_filters_changed(self,name_space):
+    def on_filters_changed(self, name_space):
         if name_space == 'MediaObject':
-            all = GenericMediaFilter()
-            all.set_name(_("None"))
-            all.add_rule(Rules.MediaObject.AllMedia([]))
-            self.generic.set_model(build_filter_model('MediaObject', [all]))
+            all_filter = GenericMediaFilter()
+            all_filter.set_name(_("None"))
+            all_filter.add_rule(Rules.MediaObject.AllMedia([]))
+            self.generic.set_model(build_filter_model('MediaObject', 
+                                                      [all_filter]))
             self.generic.set_active(0)
