@@ -18,19 +18,19 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _SidebarFilter.py 10338 2008-03-19 11:26:08Z bmcage $
+# $Id: _SidebarFilter.py 12560 2009-05-21 17:58:31Z gbritton $
 
 from gettext import gettext as _
 import gtk
 import pango
 
-import GrampsWidgets
+import widgets
 import Config
 
 _RETURN = gtk.gdk.keyval_from_name("Return")
 _KP_ENTER = gtk.gdk.keyval_from_name("KP_Enter")
 
-class SidebarFilter:
+class SidebarFilter(object):
     _FILTER_WIDTH = 200
     _FILTER_ELLIPSIZE = pango.ELLIPSIZE_END
 
@@ -51,7 +51,7 @@ class SidebarFilter:
         self.dbstate = dbstate
 
     def _init_interface(self):
-        self.table.attach(GrampsWidgets.MarkupLabel(_('<b>Filter</b>')),
+        self.table.attach(widgets.MarkupLabel(_('<b>Filter</b>')),
                           0, 2, 0, 1, xoptions=gtk.FILL|gtk.EXPAND, yoptions=0)
         btn = gtk.Button()
         img = gtk.image_new_from_stock(gtk.STOCK_CLOSE, gtk.ICON_SIZE_MENU)
@@ -129,7 +129,7 @@ class SidebarFilter:
 
     def add_entry(self, name, widget):
         if name:
-            self.table.attach(GrampsWidgets.BasicLabel(name),
+            self.table.attach(widgets.BasicLabel(name),
                               1, 2, self.position, self.position+1,
                               xoptions=gtk.FILL, yoptions=0)
         self.table.attach(widget, 2, 4, self.position, self.position+1,
