@@ -49,7 +49,7 @@ NOSORT = -1
 # ListModel
 #
 #-------------------------------------------------------------------------
-class ListModel:
+class ListModel(object):
     """
     Simple model for lists in smaller dialogs (not DataViews).
     """
@@ -160,7 +160,7 @@ class ListModel:
         Callback executed when the text of the cell renderer has changed
         """
         self.model[path][col] = new_text
-        if self.function.has_key(col):
+        if col in self.function:
             self.function[col](int(path), new_text)
 
     def unselect(self):
@@ -231,7 +231,7 @@ class ListModel:
         Return the row at the specified (x,y) coordinates
         """
         path = self.tree.get_path_at_pos(xpos, ypos)
-        if path == None:
+        if path is None:
             return self.count -1
         else:
             return path[0][0]-1
