@@ -51,7 +51,10 @@ import Errors
 from Filters import SearchBar
 import Utils
 import const
+from widgets.menutoolbuttonaction import MenuToolButtonAction
+
 from TransUtils import sgettext as _
+from QuestionDialog import QuestionDialog, QuestionDialog2
 
 NAVIGATION_NONE   = -1
 NAVIGATION_PERSON = 0
@@ -61,7 +64,7 @@ NAVIGATION_PERSON = 0
 # PageView
 #
 #------------------------------------------------------------------------------
-class PageView:
+class PageView(object):
     """
     The PageView class is the base class for all Data Views in GRAMPS.  All 
     Views should derive from this class. The ViewManager understands the public
@@ -74,6 +77,8 @@ class PageView:
         self.uistate = uistate
         self.action_list = []
         self.action_toggle_list = []
+        self.action_toolmenu_list = []
+        self.action_toolmenu = {} #easy access to toolmenuaction and proxies
         self.action_group = None
         self.additional_action_groups = []
         self.additional_uis = []
@@ -205,13 +210,24 @@ class PageView:
             self.action_group.add_actions(self.action_list)
         if len(self.action_toggle_list) > 0:
             self.action_group.add_toggle_actions(self.action_toggle_list)
+        for action_toolmenu in self.action_toolmenu_list:
+            self.action_toolmenu[action_toolmenu[0]] = \
+                    MenuToolButtonAction(action_toolmenu[0], #unique name
+                                         action_toolmenu[1], #label
+                                         action_toolmenu[2], #tooltip
+                                         action_toolmenu[3], #callback
+                                         action_toolmenu[4]  #arrow tooltip
+                                        )
+            self.action_group.add_action(
+                                    self.action_toolmenu[action_toolmenu[0]])
 
     def _add_action(self, name, stock_icon, label, accel=None, tip=None, 
                    callback=None):
         """
         Add an action to the action list for the current view. 
         """
-        self.action_list.append((name, stock_icon, label, accel, tip, callback))
+        self.action_list.append((name, stock_icon, label, accel, tip, 
+                                 callback))
 
     def _add_toggle_action(self, name, stock_icon, label, accel=None, 
                            tip=None, callback=None, value=False):
@@ -220,6 +236,11 @@ class PageView:
         """
         self.action_toggle_list.append((name, stock_icon, label, accel, 
                                         tip, callback, value))
+    
+    def _add_toolmenu_action(self, name, label, tooltip, callback, 
+                             arrowtooltip):
+        self.action_toolmenu_list.append((name, label, tooltip, callback,
+                                          arrowtooltip))
 
     def get_actions(self):
         """
@@ -255,9 +276,56 @@ class PageView:
         """
         raise NotImplementedError
 
-    def remove(self, obj):
+    def remove(self, handle):
         """
-        Template function to allow the removal of the selected object
+        Template function to allow the removal of an object by its handle
+        """
+        raise NotImplementedError
+
+    def remove_selected_objects(self):
+        """
+        Function to remove selected objects
+        """
+        prompt = True
+        if len(self.selected_handles()) > 1:
+            q = QuestionDialog2(
+                _("Remove selected items?"),
+                _("More than one item has been selected for deletion. "
+                  "Ask before deleting each one?"),
+                _("Yes"),
+                _("No"))
+            prompt = q.run()
+            
+        if not prompt:
+            self.uistate.set_busy_cursor(1)
+
+        for handle in self.selected_handles():
+            (query, is_used, object) = self.remove_object_from_handle(handle)
+            if prompt:
+                if is_used:
+                    msg = _('This item is currently being used. '
+                            'Deleting it will remove it from the database and '
+                            'from all other items that reference it.')
+                else:
+                    msg = _('Deleting item will remove it from the database.')
+                
+                msg = "%s %s" % (msg, Utils.data_recover_msg)
+                #descr = object.get_description()
+                #if descr == "":
+                descr = object.get_gramps_id()
+                self.uistate.set_busy_cursor(1)
+                QuestionDialog(_('Delete %s?') % descr, msg,
+                               _('_Delete Item'), query.query_response)
+                self.uistate.set_busy_cursor(0)
+            else:
+                query.query_response()
+
+        if not prompt:
+            self.uistate.set_busy_cursor(0)
+
+    def remove_object_from_handle(self, handle):
+        """
+        Template function to allow the removal of an object by its handle
         """
         raise NotImplementedError
 
@@ -812,7 +880,7 @@ class ListView(BookMarkView):
         for pair in [pair for pair in self.column_order() if pair[0]]:
             name = self.colinfo[pair[1]]
 
-            if self.model and self.model.__dict__.has_key('marker_color_column'):
+            if self.model and 'marker_color_column' in self.model.__dict__:
                 mcol = self.model.marker_color_column
                 column = gtk.TreeViewColumn(name, self.renderer, text=pair[1], 
                                             foreground=mcol)
@@ -840,7 +908,7 @@ class ListView(BookMarkView):
             self.list.set_model(self.model)
             self.build_columns()
 
-            if const.USE_TIPS and self.model.tooltip_column != None:
+            if const.USE_TIPS and self.model.tooltip_column is not None:
                 self.tooltips = TreeTips.TreeTips(
                     self.list, self.model.tooltip_column, True)
             self.dirty = False
