@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2007-2008  Brian G. Matherly
+# Copyright (C) 2008       Gary Burton
 # Copyright (C) 2008       Craig J. Anderson
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _GuiOptions.py 11339 2008-11-24 03:02:42Z pez4brian $
+# $Id: _GuiOptions.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 Specific option handling for a GUI.
@@ -46,13 +47,13 @@ import gobject
 #
 #-------------------------------------------------------------------------
 import Utils
-import GrampsWidgets
+import widgets
 import ManagedWindow
 from QuestionDialog import OptionDialog
 from Selectors import selector_factory
 from BasicUtils import name_displayer as _nd
 from Filters import GenericFilter, Rules
-import _MenuOptions
+import gen
 
 #------------------------------------------------------------------------
 #
@@ -160,7 +161,7 @@ class GuiStringOption(gtk.Entry):
     def __init__(self, option, dbstate, uistate, track, tooltip):
         """
         @param option: The option to display.
-        @type option: MenuOption.StringOption
+        @type option: gen.plug.menu.StringOption
         @return: nothing
         """
         gtk.Entry.__init__(self)
@@ -187,10 +188,10 @@ class GuiStringOption(gtk.Entry):
 
 #-------------------------------------------------------------------------
 #
-# GuiColourOption class
+# GuiColorOption class
 #
 #-------------------------------------------------------------------------
-class GuiColourOption(gtk.ColorButton):
+class GuiColorOption(gtk.ColorButton):
     """
     This class displays an option that allows the selection of a colour.
     """
@@ -337,16 +338,18 @@ class GuiBooleanOption(gtk.CheckButton):
 # GuiEnumeratedListOption class
 #
 #-------------------------------------------------------------------------
-class GuiEnumeratedListOption(gtk.EventBox):
+class GuiEnumeratedListOption(gtk.HBox):
     """
     This class displays an option that provides a finite number of values.
     Each possible value is assigned a value and a description.
     """
     def __init__(self, option, dbstate, uistate, track, tooltip):
-        gtk.EventBox.__init__(self)
+        gtk.HBox.__init__(self)
+        evtBox = gtk.EventBox()
         self.__option = option
         self.__combo = gtk.combo_box_new_text()
-        self.add(self.__combo)
+        evtBox.add(self.__combo)
+        self.pack_start(evtBox, True, True)
         
         self.__update_options()
 
@@ -367,6 +370,10 @@ class GuiEnumeratedListOption(gtk.EventBox):
         items = self.__option.get_items()
         value, description = items[index] # IGNORE:W0612 - description is unused
         self.__option.set_value( value )
+        self.value_changed()
+
+    def value_changed(self):
+        pass
         
     def __update_options(self):
         """
@@ -403,7 +410,7 @@ class GuiPersonOption(gtk.HBox):
     def __init__(self, option, dbstate, uistate, track, tooltip):
         """
         @param option: The option to display.
-        @type option: MenuOption.PersonOption
+        @type option: gen.plug.menu.PersonOption
         @return: nothing
         """
         gtk.HBox.__init__(self)
@@ -417,8 +424,8 @@ class GuiPersonOption(gtk.HBox):
         
         pevt = gtk.EventBox()
         pevt.add(self.__person_label)
-        person_button = GrampsWidgets.SimpleButton(gtk.STOCK_INDEX, 
-                                                   self.__get_person_clicked)
+        person_button = widgets.SimpleButton(gtk.STOCK_INDEX, 
+                                             self.__get_person_clicked)
         person_button.set_relief(gtk.RELIEF_NORMAL)
 
         self.pack_start(pevt, False)
@@ -494,7 +501,7 @@ class GuiFamilyOption(gtk.HBox):
     def __init__(self, option, dbstate, uistate, track, tooltip):
         """
         @param option: The option to display.
-        @type option: MenuOption.FamilyOption
+        @type option: gen.plug.menu.FamilyOption
         @return: nothing
         """
         gtk.HBox.__init__(self)
@@ -508,8 +515,8 @@ class GuiFamilyOption(gtk.HBox):
         
         pevt = gtk.EventBox()
         pevt.add(self.__family_label)
-        family_button = GrampsWidgets.SimpleButton(gtk.STOCK_INDEX, 
-                                                   self.__get_family_clicked)
+        family_button = widgets.SimpleButton(gtk.STOCK_INDEX, 
+                                             self.__get_family_clicked)
         family_button.set_relief(gtk.RELIEF_NORMAL)
 
         self.pack_start(pevt, False)
@@ -633,7 +640,7 @@ class GuiNoteOption(gtk.HBox):
     def __init__(self, option, dbstate, uistate, track, tooltip):
         """
         @param option: The option to display.
-        @type option: MenuOption.NoteOption
+        @type option: gen.plug.menu.NoteOption
         @return: nothing
         """
         gtk.HBox.__init__(self)
@@ -647,8 +654,8 @@ class GuiNoteOption(gtk.HBox):
         
         pevt = gtk.EventBox()
         pevt.add(self.__note_label)
-        note_button = GrampsWidgets.SimpleButton(gtk.STOCK_INDEX, 
-                                                   self.__get_note_clicked)
+        note_button = widgets.SimpleButton(gtk.STOCK_INDEX, 
+                                           self.__get_note_clicked)
         note_button.set_relief(gtk.RELIEF_NORMAL)
 
         self.pack_start(pevt, False)
@@ -680,7 +687,7 @@ class GuiNoteOption(gtk.HBox):
         """
         if note:
             note_id = note.get_gramps_id()
-            txt = " ".join(note.get(markup=False).split())
+            txt = " ".join(note.get().split())
             if len(txt) > 35:
                 txt = txt[:35]+"..."
             else:
@@ -715,7 +722,7 @@ class GuiMediaOption(gtk.HBox):
     def __init__(self, option, dbstate, uistate, track, tooltip):
         """
         @param option: The option to display.
-        @type option: MenuOption.MediaOption
+        @type option: gen.plug.menu.MediaOption
         @return: nothing
         """
         gtk.HBox.__init__(self)
@@ -729,8 +736,8 @@ class GuiMediaOption(gtk.HBox):
         
         pevt = gtk.EventBox()
         pevt.add(self.__media_label)
-        media_button = GrampsWidgets.SimpleButton(gtk.STOCK_INDEX, 
-                                                   self.__get_media_clicked)
+        media_button = widgets.SimpleButton(gtk.STOCK_INDEX, 
+                                            self.__get_media_clicked)
         media_button.set_relief(gtk.RELIEF_NORMAL)
 
         self.pack_start(pevt, False)
@@ -792,7 +799,7 @@ class GuiPersonListOption(gtk.HBox):
     def __init__(self, option, dbstate, uistate, track, tooltip):
         """
         @param option: The option to display.
-        @type option: MenuOption.PersonListOption
+        @type option: gen.plug.menu.PersonListOption
         @return: nothing
         """
         gtk.HBox.__init__(self)
@@ -832,9 +839,9 @@ class GuiPersonListOption(gtk.HBox):
 
         # now setup the '+' and '-' pushbutton for adding/removing people from 
         # the container
-        self.__add_person = GrampsWidgets.SimpleButton(gtk.STOCK_ADD, 
+        self.__add_person = widgets.SimpleButton(gtk.STOCK_ADD, 
                                                  self.__add_person_clicked)
-        self.__del_person = GrampsWidgets.SimpleButton(gtk.STOCK_REMOVE, 
+        self.__del_person = widgets.SimpleButton(gtk.STOCK_REMOVE, 
                                                  self.__del_person_clicked)
         self.__vbbox = gtk.VButtonBox()
         self.__vbbox.add(self.__add_person)
@@ -921,10 +928,121 @@ class GuiPersonListOption(gtk.HBox):
 
 #-------------------------------------------------------------------------
 #
-# GuiSurnameColourOption class
+# GuiPlaceListOption class
 #
 #-------------------------------------------------------------------------
-class GuiSurnameColourOption(gtk.HBox):
+class GuiPlaceListOption(gtk.HBox):
+    """
+    This class displays a widget that allows multiple places from the 
+    database to be selected.
+    """
+    def __init__(self, option, dbstate, uistate, track, tooltip):
+        """
+        @param option: The option to display.
+        @type option: gen.plug.menu.PlaceListOption
+        @return: nothing
+        """
+        gtk.HBox.__init__(self)
+        self.__option = option
+        self.__dbstate = dbstate
+        self.__db = dbstate.get_database()
+        self.__uistate = uistate
+        self.__track = track
+
+        self.__model = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
+        self.__tree_view = gtk.TreeView(self.__model)
+        self.__tree_view.set_size_request(150, 150)
+        col1 = gtk.TreeViewColumn(_('Place'  ), gtk.CellRendererText(), text=0)
+        col2 = gtk.TreeViewColumn(_('ID'    ), gtk.CellRendererText(), text=1)
+        col1.set_resizable(True)
+        col2.set_resizable(True)
+        col1.set_sizing(gtk.TREE_VIEW_COLUMN_AUTOSIZE)
+        col2.set_sizing(gtk.TREE_VIEW_COLUMN_AUTOSIZE)
+        col1.set_sort_column_id(0)
+        col2.set_sort_column_id(1)
+        self.__tree_view.append_column(col1)
+        self.__tree_view.append_column(col2)
+        self.__scrolled_window = gtk.ScrolledWindow()
+        self.__scrolled_window.add(self.__tree_view)
+        self.__scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, 
+                                          gtk.POLICY_AUTOMATIC)
+        self.__scrolled_window.set_shadow_type(gtk.SHADOW_OUT)
+
+        self.pack_start(self.__scrolled_window, expand=True, fill=True)
+
+        value = self.__option.get_value()
+        for gid in value.split():
+            place = self.__db.get_place_from_gramps_id(gid)
+            if place:
+                place_name = place.get_title()
+                self.__model.append([place_name, gid])
+
+        # now setup the '+' and '-' pushbutton for adding/removing places from 
+        # the container
+        self.__add_place = widgets.SimpleButton(gtk.STOCK_ADD, 
+                                                self.__add_place_clicked)
+        self.__del_place = widgets.SimpleButton(gtk.STOCK_REMOVE, 
+                                                self.__del_place_clicked)
+        self.__vbbox = gtk.VButtonBox()
+        self.__vbbox.add(self.__add_place)
+        self.__vbbox.add(self.__del_place)
+        self.__vbbox.set_layout(gtk.BUTTONBOX_SPREAD)
+        self.pack_end(self.__vbbox, expand=False)
+        
+        tooltip.set_tip(self.__tree_view, self.__option.get_help())
+
+    def __update_value(self):
+        """
+        Parse the object and return.
+        """
+        gidlist = ''
+        i = self.__model.get_iter_first()
+        while (i):
+            gid = self.__model.get_value(i, 1)
+            gidlist = gidlist + gid + ' '
+            i = self.__model.iter_next(i)
+        self.__option.set_value(gidlist)
+
+    def __add_place_clicked(self, obj): # IGNORE:W0613 - obj is unused
+        """
+        Handle the add place button.
+        """
+        # places we already have must be excluded
+        # so we don't list them multiple times
+        skip_list = set()
+        i = self.__model.get_iter_first()
+        while (i):
+            gid = self.__model.get_value(i, 1) # get the GID stored in column #1
+            place = self.__db.get_place_from_gramps_id(gid)
+            skip_list.add(place.get_handle())
+            i = self.__model.iter_next(i)
+
+        select_class = selector_factory('Place')
+        sel = select_class(self.__dbstate, self.__uistate, 
+                           self.__track, skip=skip_list)
+        place = sel.run()
+        if place:
+            place_name = place.get_title()
+            gid = place.get_gramps_id()
+            self.__model.append([place_name, gid])
+            self.__update_value()
+            
+    def __del_place_clicked(self, obj): # IGNORE:W0613 - obj is unused
+        """
+        Handle the delete place button.
+        """
+        (path, column) = self.__tree_view.get_cursor()
+        if (path):
+            i = self.__model.get_iter(path)
+            self.__model.remove(i)
+            self.__update_value()
+
+#-------------------------------------------------------------------------
+#
+# GuiSurnameColorOption class
+#
+#-------------------------------------------------------------------------
+class GuiSurnameColorOption(gtk.HBox):
     """
     This class displays a widget that allows multiple surnames to be
     selected from the database, and to assign a colour (not necessarily
@@ -933,7 +1051,7 @@ class GuiSurnameColourOption(gtk.HBox):
     def __init__(self, option, dbstate, uistate, track, tooltip):
         """
         @param option: The option to display.
-        @type option: MenuOption.SurnameColourOption
+        @type option: gen.plug.menu.SurnameColorOption
         @return: nothing
         """
         gtk.HBox.__init__(self)
@@ -967,10 +1085,10 @@ class GuiSurnameColourOption(gtk.HBox):
         self.scrolled_window.set_shadow_type(gtk.SHADOW_OUT)
         self.pack_start(self.scrolled_window, expand=True, fill=True)
 
-        self.add_surname = GrampsWidgets.SimpleButton(gtk.STOCK_ADD, 
-                                                     self.__add_clicked)
-        self.del_surname = GrampsWidgets.SimpleButton(gtk.STOCK_REMOVE, 
-                                                     self.__del_clicked)
+        self.add_surname = widgets.SimpleButton(gtk.STOCK_ADD, 
+                                                self.__add_clicked)
+        self.del_surname = widgets.SimpleButton(gtk.STOCK_REMOVE, 
+                                                self.__del_clicked)
         self.vbbox = gtk.VButtonBox()
         self.vbbox.add(self.add_surname)
         self.vbbox.add(self.del_surname)
@@ -1080,12 +1198,13 @@ class GuiSurnameColourOption(gtk.HBox):
 #-------------------------------------------------------------------------
 class GuiDestinationOption(gtk.HBox):
     """
-    This class displays an option that is a simple one-line string.
+    This class displays an option that allows the user to select a 
+    DestinationOption.
     """
     def __init__(self, option, dbstate, uistate, track, tooltip):
         """
         @param option: The option to display.
-        @type option: MenuOption.StringOption
+        @type option: gen.plug.menu.DestinationOption
         @return: nothing
         """
         gtk.HBox.__init__(self)
@@ -1142,7 +1261,7 @@ class GuiDestinationOption(gtk.HBox):
 
         status = fcd.run()
         if status == gtk.RESPONSE_OK:
-            path = unicode(fcd.get_filename(), sys.getfilesystemencoding())
+            path = Utils.get_unicode_path(fcd.get_filename())
             if path:
                 if not self.__option.get_directory_entry() and \
                    not path.endswith(self.__option.get_extension()):
@@ -1167,13 +1286,52 @@ class GuiDestinationOption(gtk.HBox):
             self.__option.set_value(value)
         
         self.__entry.set_text( self.__option.get_value() )
+        
+#-------------------------------------------------------------------------
+#
+# GuiStyleOption class
+#
+#-------------------------------------------------------------------------
+class GuiStyleOption(GuiEnumeratedListOption):
+    """
+    This class displays a StyleOption.
+    """
+    def __init__(self, option, dbstate, uistate, track, tooltip):
+        """
+        @param option: The option to display.
+        @type option: gen.plug.menu.StyleOption
+        @return: nothing
+        """
+        GuiEnumeratedListOption.__init__(self, option, dbstate, 
+                                         uistate, track, tooltip)
+        self.__option = option
+        
+        self.__button = gtk.Button("%s..." % _("Style Editor"))
+        self.__button.connect('clicked', self.__on_style_edit_clicked)
+        
+        self.pack_end(self.__button, False, False)
+
+    def __on_style_edit_clicked(self, *obj):
+        """The user has clicked on the 'Edit Styles' button.  Create a
+        style sheet editor object and let them play.  When they are
+        done, update the displayed styles."""
+        import BaseDoc
+        from ReportBase._StyleEditor import StyleListDisplay
+        style_list = BaseDoc.StyleSheetList(self.__option.get_style_file(), 
+                                            self.__option.get_default_style())
+        StyleListDisplay(style_list, None, None)
+
+        new_items = []
+        for style_name in style_list.get_style_names():
+            new_items.append( (style_name, style_name) )
+        self.__option.set_items(new_items)
 
 #------------------------------------------------------------------------
 #
 # GuiMenuOptions class
 #
 #------------------------------------------------------------------------
-class GuiMenuOptions:
+class GuiMenuOptions(object):
     """
     Introduction
     ============
@@ -1181,7 +1339,7 @@ class GuiMenuOptions:
     options to a GTK dialog.
     """
     def __init__(self):
-        self.menu = _MenuOptions.Menu()
+        self.menu = gen.plug.menu.Menu()
         
         # Fill options_dict with report/tool defaults:
         self.options_dict = {}
@@ -1229,10 +1387,10 @@ class GuiMenuOptions:
                 if name in self.options_dict:
                     option.set_value(self.options_dict[name])
                     
-                widget, label = make_gui_option(option, dialog, 
-                                                self.__tooltips)
+                widget, label = make_gui_option(option, self.__tooltips, 
+                                                dialog.dbstate, dialog.uistate, dialog.track)
 
-                if widget == None:
+                if widget is None:
                     print "UNKNOWN OPTION: ", option
                 else:
                     if label:
@@ -1250,65 +1408,60 @@ class GuiMenuOptions:
             option = self.menu.get_option_by_name(name)
             self.options_dict[name] = option.get_value()
 
-def make_gui_option(option, dialog, tooltips):
+def make_gui_option(option, tooltips, dbstate, uistate, track):
     """
     Stand-alone function so that Options can be used in other
     ways, too. Takes an Option and returns a GuiOption.
     """
     widget = None
     label = True
-    if isinstance(option, _MenuOptions.PersonOption):
-        widget = GuiPersonOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.FamilyOption):
-        widget = GuiFamilyOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.NoteOption):
-        widget = GuiNoteOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.MediaOption):
-        widget = GuiMediaOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.PersonListOption):
-        widget = GuiPersonListOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.NumberOption):
-        widget = GuiNumberOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.BooleanOption):
-        widget = GuiBooleanOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
+    pmgr = gen.plug.PluginManager.get_instance()
+    external_options = pmgr.get_external_opt_dict()
+    if tooltips == None:
+        tooltips = gtk.Tooltips()
+    elif type(tooltips) == type(""):
+        msg = tooltips
+        tooltips = gtk.Tooltips()
+        # FIXME: what widget?
+        #tooltips.set_tip(gui.scrolledwindow, msg)
+    if isinstance(option, gen.plug.menu.PersonOption):
+        widget = GuiPersonOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.FamilyOption):
+        widget = GuiFamilyOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.NoteOption):
+        widget = GuiNoteOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.MediaOption):
+        widget = GuiMediaOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.PersonListOption):
+        widget = GuiPersonListOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.NumberOption):
+        widget = GuiNumberOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.BooleanOption):
+        widget = GuiBooleanOption(option, dbstate, uistate, track, tooltips)
         label = False
-    elif isinstance(option, _MenuOptions.DestinationOption):
-        widget = GuiDestinationOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.StringOption):
-        widget = GuiStringOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.EnumeratedListOption):
-        widget = GuiEnumeratedListOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.TextOption):
-        widget = GuiTextOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.ColourOption):
-        widget = GuiColourOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
-    elif isinstance(option, _MenuOptions.SurnameColourOption):
-        widget = GuiSurnameColourOption(option, dialog.dbstate, 
-                                 dialog.uistate, dialog.track, 
-                                 tooltips)
+    elif isinstance(option, gen.plug.menu.DestinationOption):
+        widget = GuiDestinationOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.StringOption):
+        widget = GuiStringOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.StyleOption):
+        widget = GuiStyleOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.EnumeratedListOption):
+        widget = GuiEnumeratedListOption(option, dbstate, uistate, track, 
+                                         tooltips)
+    elif isinstance(option, gen.plug.menu.TextOption):
+        widget = GuiTextOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.ColorOption):
+        widget = GuiColorOption(option, dbstate, uistate, track, tooltips)
+    elif isinstance(option, gen.plug.menu.SurnameColorOption):
+        widget = GuiSurnameColorOption(option, dbstate, uistate, track, 
+                                       tooltips)
+    elif isinstance(option, gen.plug.menu.PlaceListOption):
+        widget = GuiPlaceListOption(option, dbstate, uistate, track, tooltips)
+    elif option.__class__ in external_options:
+        widget = external_options[option.__class__](option, dbstate, uistate,
+                                                    track, tooltips)
+    else:
+        raise AttributeError(
+                     "can't make GuiOption: unknown option type: '%s'" % option)
     return widget, label
 
