@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2004-2007  Donald N. Allingham
+# Copyright (C) 2008       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _ReportOptions.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _ReportOptions.py 12560 2009-05-21 17:58:31Z gbritton $
 
 # Written by Alex Roitman
 
@@ -541,7 +542,7 @@ class OptionParser(_Options.OptionParser):
 # we don't have to handle them for reports that don't use documents (web)
 #
 #------------------------------------------------------------------------
-class EmptyDoc:
+class EmptyDoc(object):
     def init(self):
         pass
 
@@ -747,6 +748,7 @@ class ReportOptions(_Options.Options):
                     FTD-    FTM Style Descendant report
                     IDS-    Individual Complete Report
                     IVS-    Individual Summary Report
+                    PLC-    Place Report
                     SBT-    Simple Boot Title
                     TLG-    Timeline Graph
         """
