@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ScratchPad.py 11143 2008-10-14 07:05:06Z erikdrgm $
+# $Id: ScratchPad.py 12560 2009-05-21 17:58:31Z gbritton $
 
 #------------------------------------------------------------------------
 #
@@ -51,6 +51,7 @@ from gtk import glade
 #
 #-------------------------------------------------------------------------
 import const
+import Config
 import gen.lib
 import TreeTips
 import DateHandler
@@ -59,15 +60,15 @@ import ManagedWindow
 from TransUtils import sgettext as _
 
 from DdTargets import DdTargets
+
 #-------------------------------------------------------------------------
 #
 # Constants
 #
 #-------------------------------------------------------------------------
-WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_Navigation'
+WIKI_HELP_PAGE = '%s_-_Navigation' % const.URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|Using_the_Clipboard')
 
-
 #-------------------------------------------------------------------------
 #
 # icons used in the object listing
@@ -589,7 +590,7 @@ class ScratchPadName(ScratchPadGrampsTypeWrapper):
             _("Family"),escape(self._obj.get_surname()),
             _("Patronymic"),escape(self._obj.get_patronymic()),
             _("Prefix"),escape(self._obj.get_surname_prefix()),
-            _("Title"),escape(self._obj.get_title()),
+            _("Person|Title"),escape(self._obj.get_title()),
             _("Suffix"),escape(self._obj.get_suffix()),
             _("Type"),escape(self._obj.get_type().__str__()),
             )
@@ -887,7 +888,7 @@ class ScratchPadListModel(gtk.ListStore):
 # ScratchPadListView class
 # Now shown as 'Clipboard'
 #-------------------------------------------------------------------------
-class ScratchPadListView:
+class ScratchPadListView(object):
 
     LOCAL_DRAG_TARGET = ('MY_TREE_MODEL_ROW', gtk.TARGET_SAME_WIDGET, 0)
     LOCAL_DRAG_TYPE   = 'MY_TREE_MODEL_ROW'
@@ -951,6 +952,7 @@ class ScratchPadListView:
         self._widget.connect('drag_begin', self.object_drag_begin)
         self._widget.connect('drag_data_received',
                              self.object_drag_data_received)
+        self._widget.connect('drag_end', self.object_drag_end)
 
         self.register_wrapper_classes()
 
@@ -1060,7 +1062,7 @@ class ScratchPadListView:
 
         self._widget.unset_rows_drag_source()
 
-        if node != None:
+        if node is not None:
             o = model.get_value(node,1)
 
             targets = [ScratchPadListView.LOCAL_DRAG_TARGET] + \
@@ -1069,7 +1071,12 @@ class ScratchPadListView:
             self._widget.enable_model_drag_source(BUTTON1_MASK, targets, ACTION_COPY | ACTION_MOVE)
 
     def object_drag_begin(self, context, a):
-        return
+        """ Handle the beginning of a drag operation. """
+        self.treetips.disable()
+    
+    def object_drag_end(self, widget, drag_context):
+        """ Handle the end of a drag operation. """
+        self.treetips.enable()
 
     def object_drag_data_get(self, widget, context, sel_data, info, time):
         tree_selection = widget.get_selection()
@@ -1192,11 +1199,14 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         self.database_changed(self.dbstate.db)
         self.dbstate.connect('database-changed', self.database_changed)
 
+        self.width_key = Config.CLIPBOARD_WIDTH
+        self.height_key = Config.CLIPBOARD_HEIGHT
         self.glade_file = os.path.join(const.GLADE_DIR, "scratchpad.glade")
 
         self.top = glade.XML(self.glade_file,"scratch_pad","gramps")
         self.set_window(self.top.get_widget("scratch_pad"),
                         None, None, msg=_("Clipboard"))
+        self._set_size()
 
         self.clear_all_btn = self.top.get_widget("btn_clear_all")
         self.clear_btn = self.top.get_widget("btn_clear")
