@@ -33,7 +33,7 @@ from ReportBase import ReportUtils
 from gen.lib import EventType
 import Config
 
-class SimpleAccess:
+class SimpleAccess(object):
     """
     Provide a simplified database access system. This system has been designed to
     ease the development of reports. 
@@ -361,7 +361,7 @@ class SimpleAccess:
                         elist = [ self.dbase.get_event_from_handle(ref.ref) 
                                   for ref in reflist ]
                         events = [ evnt for evnt in elist 
-                                   if int(evnt.get_type()) == EventType.MARRIAGE ]
+                                   if event.type == EventType.MARRIAGE ]
                         if events:
                             place_handle = events[0].get_place_handle()
                             return ReportUtils.place_name(self.dbase, place_handle)
@@ -391,7 +391,7 @@ class SimpleAccess:
                         elist = [ self.dbase.get_event_from_handle(ref.ref) 
                                   for ref in reflist ]
                         events = [ evnt for evnt in elist 
-                                   if int(evnt.get_type()) == EventType.MARRIAGE ]
+                                   if event.type == EventType.MARRIAGE ]
                         if events:
                             date_obj = events[0].get_date_object()
                             if date_obj:
@@ -571,6 +571,18 @@ class SimpleAccess:
         else:
             return u''
 
+    def event_date_obj(self, event):
+        """
+        Return a string indicating the date of the event
+
+        @param event: Event object
+        @type event: L{gen.lib.Event}
+        @return: Returns a string indicating the date of the event
+        @rtype: unicode
+        """
+        assert(isinstance(event, (gen.lib.Event, NoneType)))
+        return event.get_date_object()
+
     def event_type(self, event):
         """
         Return a string indicating the type of the event
@@ -600,7 +612,7 @@ class SimpleAccess:
         @rtype: list
         """
         assert(isinstance(obj, (gen.lib.Person, gen.lib.Family, NoneType)))
-        assert(type(restrict) == type([]) or restrict == None)
+        assert(isinstance(restrict, list) or restrict is None)
 
         if obj:
             event_handles = [ ref.ref for ref in obj.get_event_ref_list() ]
