@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Utils.py 11120 2008-10-06 12:34:19Z romjerome $
+# $Id: Utils.py 12560 2009-05-21 17:58:31Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -31,7 +31,7 @@ import locale
 import random
 import time
 
-from gettext import gettext as _
+from TransUtils import sgettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -45,11 +45,10 @@ import gtk
 # Gramps modules
 #
 #-------------------------------------------------------------------------
-import Mime
 from BasicUtils import name_displayer
 import gen.lib
 import Errors
-from QuestionDialog import WarningDialog
+from QuestionDialog import WarningDialog, ErrorDialog
 
 from const import TEMP_DIR, USER_HOME
 import shutil
@@ -124,7 +123,7 @@ data_recover_msg = _('The data can only be recovered by Undo operation '
             'or by quitting with abandoning changes.')
 
 def fix_encoding(value):
-    if type(value) != unicode:
+    if not isinstance(value, unicode):
         try:
             return unicode(value)
         except:
@@ -138,7 +137,7 @@ def fix_encoding(value):
 
 def xml_lang():
     loc = locale.getlocale()
-    if loc[0] == None:
+    if loc[0] is None:
         return ""
     else:
         return loc[0].replace('_', '-')
@@ -150,7 +149,7 @@ def xml_lang():
 #-------------------------------------------------------------------------
 
 def force_unicode(n):
-    if type(n) != unicode:
+    if not isinstance(n, unicode):
         return (unicode(n).lower(), unicode(n))
     else:
         return (n.lower(), n)
@@ -262,18 +261,6 @@ def add_menuitem(menu, msg, obj, func):
 #
 #
 #-------------------------------------------------------------------------
-def view_photo(photo, db):
-    """
-    photo is a mediaobject, this utility launches a viewing application
-    """
-    mime_type = photo.get_mime_type()
-    try:
-        data = Mime.get_application(mime_type)
-        prog = data[0]
-    except:
-        return
-    launch(prog, media_path_full(db, photo.get_path()))
-
 def find_file( filename):
     # try the filename we got
     try:
@@ -578,7 +565,7 @@ def probably_alive(person, db, current_date=None, limit=0):
                    (defaults to today)
     limit        - number of years to check beyond death_date
     """
-    if not current_date:
+    if current_date is None:
         current_date = gen.lib.Date()
         # yr, mon, day:
         current_date.set_yr_mon_day(*time.localtime(time.time())[0:3])
@@ -598,9 +585,9 @@ def probably_alive(person, db, current_date=None, limit=0):
     # These are fairly good indications that someone's not alive.
     for ev_ref in person.get_primary_event_ref_list():
         ev = db.get_event_from_handle(ev_ref.ref)
-        if ev and int(ev.get_type()) in [gen.lib.EventType.CAUSE_DEATH, 
-                                         gen.lib.EventType.BURIAL, 
-                                         gen.lib.EventType.CREMATION]:
+        if ev and ev.type in [gen.lib.EventType.CAUSE_DEATH, 
+                              gen.lib.EventType.BURIAL, 
+                              gen.lib.EventType.CREMATION]:
             if not death_date:
                 death_date = ev.get_date_object()
             if ev.get_date_object().get_start_date() != gen.lib.Date.EMPTY:
@@ -617,15 +604,18 @@ def probably_alive(person, db, current_date=None, limit=0):
     birth_ref = person.get_birth_ref()
     if birth_ref and birth_ref.get_role() == gen.lib.EventRoleType.PRIMARY:
         birth = db.get_event_from_handle(birth_ref.ref)
-        if birth.get_date_object().get_start_date() != gen.lib.Date.EMPTY:
+        if (birth.get_date_object().get_start_date() != gen.lib.Date.EMPTY):
             if not birth_date:
                 birth_date = birth.get_date_object()
             # Check whether the birth event is too old because the
             # code above did not look at birth, only at other events
-            if too_old(birth.get_date_object(), current_date.get_year()):
-                return False
-            if not_too_old(birth.get_date_object(), current_date.get_year()):
-                return True
+            birth_obj = birth.get_date_object()
+            if birth_obj.get_valid():
+                # only if this is a valid birth:
+                if too_old(birth_obj, current_date.get_year()):
+                    return False
+                if not_too_old(birth_obj, current_date.get_year()):
+                    return True
     
     if not birth_date and death_date:
         if death_date.match(current_date.copy_offset_ymd(year=_MAX_AGE_PROB_ALIVE), ">>"):
@@ -1004,7 +994,7 @@ def media_path_full(db, filename):
     return os.path.join(mpath, filename)
     
 
-class ProgressMeter:
+class ProgressMeter(object):
     """
     Progress meter class for GRAMPS.
     
@@ -1119,53 +1109,36 @@ class ProgressMeter:
         Close the progress meter
         """
         self.__dialog.destroy()
-
-def launch(prog_str, path):
-    
-    if sys.platform == "win32":
         
-        import subprocess
-        if prog_str.find("%1") != -1:
-            prog_str = prog_str.replace("%1", path)
-        else:
-            prog_str = '%s "%s"' % (prog_str, path)
-
-        # The string must be encoded using the filesystem encoding on Windows.
-        # Otherwise, files with non-ascii characters in their names will not 
-        # open.
-        prog_str = prog_str.encode(sys.getfilesystemencoding())
-        subprocess.Popen(prog_str)
-
+def open_file_with_default_application( file_path ):
+    """
+    Launch a program to open an arbitrary file. The file will be opened using 
+    whatever program is configured on the host as the default program for that 
+    type of file.
+    
+    @param file_path: The path to the file to be opened.
+        Example: "c:\foo.txt"
+    @type file_path: string
+    @return: nothing
+    """
+    norm_path = os.path.normpath( file_path )
+    
+    if not os.path.exists(norm_path):
+        ErrorDialog(_("Error Opening File"), _("File does not exist"))
+        return
+        
+    if os.sys.platform == 'win32':
+        try:
+            os.startfile(norm_path)
+        except WindowsError, msg:
+            ErrorDialog(_("Error Opening File"), str(msg))
     else:
-        subval = {
-            '%F'   : path, 
-            '%f'   : path, 
-            '%u'   : path, 
-            '%U'   : path, 
-            '%n'   : path, 
-            '%N'   : path, 
-            }
-        
-        prog_data = prog_str.split()
-        prog = prog_data[0]
-        prog_list = []
-        need_path = True
-    
-        if len(prog_data) > 1:
-            for item in prog_data:
-                if subval.has_key(item):
-                    need_path = False
-                    value = subval[item]
-                else:
-                    value = item
-                prog_list.append(value)
-        else:
-            prog_list = [prog_data[0]]
-    
-        if need_path:
-            prog_list.append(path)
-    
-        os.spawnvpe(os.P_NOWAIT, prog, prog_list, os.environ)
+        search = os.environ['PATH'].split(':')
+        for lpath in search:
+            prog = os.path.join(lpath, 'xdg-open')
+            if os.path.isfile(prog):
+                os.spawnvpe(os.P_NOWAIT, prog, [prog, norm_path], os.environ)
+                return
 
 def profile(func, *args):
     import hotshot.stats
@@ -1190,7 +1163,7 @@ def profile(func, *args):
 #-------------------------------------------------------------------------
 
 # keyword, code, translated standard, translated upper
-KEYWORDS = [("title",     "t", _("Title"),     _("TITLE")),
+KEYWORDS = [("title",     "t", _("Person|Title"),     _("Person|TITLE")),
             ("given",     "f", _("Given"),     _("GIVEN")),
             ("prefix",    "p", _("Prefix"),    _("PREFIX")),
             ("surname",   "l", _("Surname"),   _("SURNAME")),
