@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: const.py.in 10692 2008-05-08 12:06:39Z pez4brian $
+# $Id: const.py.in 12316 2009-03-11 11:41:12Z bmcage $
 
 """
 Provides constants for other modules
@@ -43,10 +43,10 @@ URL_HOMEPAGE    = "http://gramps-project.org/"
 URL_MAILINGLIST = "http://sourceforge.net/mail/?group_id=25770"
 URL_BUGTRACKER  = "http://bugs.gramps-project.org/bug_report_advanced_page.php"
 URL_WIKISTRING  = "http://gramps-project.org/wiki/index.php?title="
-URL_MANUAL_PAGE = "Gramps_3.0_Wiki_Manual"
+URL_MANUAL_PAGE = "Gramps_3.1_Wiki_Manual"
 WIKI_FAQ = "FAQ"
-WIKI_KEYBINDINGS = "Gramps_3.0_Wiki_Manual_-_Keybindings"
-WIKI_EXTRAPLUGINS= "3.0.x_Third-party_Plugins"
+WIKI_KEYBINDINGS = "Gramps_3.1_Wiki_Manual_-_Keybindings"
+WIKI_EXTRAPLUGINS= "3.1.x_Third-party_Plugins"
 
 #-------------------------------------------------------------------------
 #
@@ -111,13 +111,12 @@ TOOL_OPTIONS   = os.path.join(HOME_DIR, "tool_options.xml")
 
 ENV_DIR        = os.path.join(HOME_DIR, "env")
 TEMP_DIR       = os.path.join(HOME_DIR, "temp")
-THUMB_DIR      = os.path.join(HOME_DIR, "thumb")
-USER_DOCGEN    = os.path.join(HOME_DIR, "docgen")    
+THUMB_DIR      = os.path.join(HOME_DIR, "thumb")  
 USER_PLUGINS   = os.path.join(HOME_DIR, "plugins")    
 USER_TEMPLATES = os.path.join(HOME_DIR, "templates")    
 # dirs checked/made for each Gramps session
 USER_DIRLIST = (HOME_DIR, ENV_DIR, TEMP_DIR, THUMB_DIR,
-                USER_DOCGEN, USER_PLUGINS, USER_TEMPLATES)
+                USER_PLUGINS, USER_TEMPLATES)
 
 ICON           = os.path.join(ROOT_DIR, "images", "gramps.png")
 LOGO           = os.path.join(ROOT_DIR, "images", "logo.png")
@@ -137,7 +136,6 @@ RULE_GLADE     = os.path.join(GLADE_DIR, "rule.glade")
 
 
 PLUGINS_DIR    = os.path.join(ROOT_DIR, "plugins")
-DOCGEN_DIR     = os.path.join(ROOT_DIR, "docgen")
 DATA_DIR       = os.path.join(ROOT_DIR, "data")
 SYSTEM_FILTERS = os.path.join(DATA_DIR, "system_filters.xml")
 TEMPLATE_DIR   = os.path.join(DATA_DIR, "templates")
@@ -158,21 +156,22 @@ else:
 #
 #-------------------------------------------------------------------------
 PROGRAM_NAME   = "GRAMPS"
-VERSION        = "3.0.4-1"
+VERSION        = "3.1.2-1"
 COPYRIGHT_MSG  = u"\u00A9 2001-2006 Donald N. Allingham\n" \
-                 u"\u00A9 2007-2008 The GRAMPS Developers"
+                 u"\u00A9 2007-2009 The GRAMPS Developers"
 COMMENTS       = _("GRAMPS (Genealogical Research and Analysis "
                    "Management Programming System) is a personal "
                    "genealogy program.")
 AUTHORS        = [
-    "Donald N. Allingham", 
-    "Alexander Roitman", 
-    "Richard Taylor", 
-    "Martin Hawlisch", 
-    "Brian Matherly", 
-    "Tim Waugh", 
+    "Alexander Roitman",
+    "Benny Malengier", 
+    "Brian Matherly",
     "Donald A. Peterson", 
-    "David Hampton", 
+    "Donald N. Allingham", 
+    "David Hampton",  
+    "Martin Hawlisch", 
+    "Richard Taylor", 
+    "Tim Waugh", 
     ]
     
 AUTHORS_FILE = os.path.join(DATA_DIR, "authors.xml")
@@ -200,16 +199,18 @@ NO_GIVEN     = "(%s)" % _("none")
 #
 #-------------------------------------------------------------------------
 
+# Note: Make sure to edit ArgHandler.py _help string too!
 # (longName, shortName, type , default, flags, descrip , argDescrip)
 POPT_TABLE = [
     ("open",    'O', str, None, 0, "Open family tree",  "FAMILY_TREE"), 
     ("import",  'i', str, None, 0, "Import file",       "FILENAME"), 
-    ("output",  'o', str, None, 0, "Write file",        "FILENAME"), 
+    ("export",  'e', str, None, 0, "Export file",       "FILENAME"),
     ("format",  'f', str, None, 0, 'Specify format',    "FORMAT"), 
     ("action",  'a', str, None, 0, 'Specify action',    "ACTION"), 
     ("options", 'p', str, None, 0, 'Specify options',   "OPTIONS_STRING"), 
     ("debug",   'd', str, None, 0, 'Enable debug logs', "LOGGER_NAME"), 
     ("",        'l', None, None, 0, 'List Family Trees', ""),
+    ("",        'L', None, None, 0, 'List Family Tree Details', ""),
     ("force-unlock", 'u', None, None, 0, 'Force unlock of family tree', ""),
 ]
 
@@ -222,6 +223,7 @@ LONGOPTS = [
     "disable-crash-dialog", 
     "enable-sound",
     "espeaker=",
+    "export=",
     "force-unlock",
     "format=",
     "gdk-debug=", 
@@ -240,7 +242,6 @@ LONGOPTS = [
     "oaf-private",
     "open=",
     "options=",
-    "output=",
     "screen=", 
     "sm-client-id=", 
     "sm-config-prefix=", 
@@ -250,6 +251,6 @@ LONGOPTS = [
     "version", 
 ]
 
-SHORTOPTS = "O:i:o:f:a:p:d:lhu?"
+SHORTOPTS = "O:i:e:f:a:p:d:lLhu?"
 
 
