@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: dbdir.py 11390 2008-12-02 12:20:40Z dsblank $
+# $Id: dbdir.py 12620 2009-06-03 18:30:42Z ldnp $
 
 """
 Provide the Berkeley DB (DBDir) database backend for GRAMPS.
@@ -32,6 +32,7 @@ This is used since GRAMPS version 3.0
 #-------------------------------------------------------------------------
 import cPickle as pickle
 import os
+import sys
 import time
 from types import InstanceType
 
@@ -50,13 +51,14 @@ from gen.lib import (GenderStats, Person, Family, Event, Place, Source,
                      MediaObject, Repository, Note)
 from gen.db import (GrampsDbBase, KEY_TO_CLASS_MAP, CLASS_TO_KEY_MAP, 
                     REFERENCE_KEY, Transaction)
-from gen.db.exceptions import FileVersionError
 from BasicUtils import UpdateCallback
 from gen.db.cursor import GrampsCursor
+from gen.db.exceptions import FileVersionError, FileVersionDeclineToUpgrade
 import Errors
+from QuestionDialog import QuestionDialog2
 
 _MINVERSION = 9
-_DBVERSION = 13
+_DBVERSION = 14
 
 IDTRANS     = "person_id"
 FIDTRANS    = "family_id"
@@ -261,7 +263,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
 
     def __has_handle(self, table, handle):
         try:
-            return table.get(str(handle), txn=self.txn) != None
+            return table.get(str(handle), txn=self.txn) is not None
         except DBERRS, msg:
             self.__log_error()
             raise Errors.DbError(msg)
@@ -391,6 +393,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
             the_txn = self.env.txn_begin()
             self.metadata.put('default', str(handle), txn=the_txn)
             the_txn.commit()
+            self.emit('home-person-changed')
 
     def get_default_person(self):
         try:
@@ -480,7 +483,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         # These env settings are only needed for Txn environment
         self.env.set_lk_max_locks(25000)
         self.env.set_lk_max_objects(25000)
-
+        
         self.set_auto_remove()
 
         # The DB_PRIVATE flag must go if we ever move to multi-user setup
@@ -489,7 +492,6 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
                     db.DB_INIT_LOG | db.DB_INIT_TXN | db.DB_THREAD
 
         # As opposed to before, we always try recovery on databases
-        #  in _GrampsBSDDB.py we only do that on existing filenames
         env_flags = env_flags | db.DB_RECOVER
 
         # Environment name is now based on the filename
@@ -500,7 +502,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
 
         if callback:
             callback(25)
-        self.metadata  = self.__open_table(self.full_name, META)
+        self.metadata = self.__open_table(self.full_name, META)
 
         # If we cannot work with this DB version,
         # it makes no sense to go further
@@ -537,10 +539,10 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
             # Start transaction
             the_txn = self.env.txn_begin()
 
-            if gstats == None:
+            if gstats is None:
                 # New database. Set up the current version.
                 self.metadata.put('version', _DBVERSION, txn=the_txn)
-            elif not self.metadata.has_key('version'):
+            elif 'version' not in self.metadata:
                 # Not new database, but the version is missing.
                 # Use 0, but it is likely to fail anyway.
                 self.metadata.put('version', 0, txn=the_txn)
@@ -555,7 +557,18 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         # self.secondary_connected flag should be set accordingly.
         
         if self.need_upgrade():
-            self.gramps_upgrade(callback)
+            if QuestionDialog2(_("Need to upgrade database!"), 
+                               _("You cannot open this database "
+                                 "without upgrading it.\n"
+                                 "If you upgrade then you won't be able "
+                                 "to use previous versions of GRAMPS.\n" 
+                                 "You might want to make a backup copy "
+                                 "first."), 
+                               _("Upgrade now"), 
+                               _("Cancel")).run():
+                self.gramps_upgrade(callback)
+            else:
+                raise FileVersionDeclineToUpgrade()
 
         if callback:
             callback(50)
@@ -865,7 +878,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
                 data = self.reference_map.get(data)
             else:
                 data = pickle.loads(data)
-            if include_classes == None or \
+            if include_classes is None or \
                    KEY_TO_CLASS_MAP[data[0][0]] in include_classes:
                 yield (KEY_TO_CLASS_MAP[data[0][0]], data[0][1])
                 
@@ -1096,7 +1109,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
             class_func = primary_tables[primary_table_name]['class_func']
             while data:
                 found_handle, val = data
-                obj = InstanceType(class_func)
+                obj = class_func()
                 obj.unserialize(val)
 
                 the_txn = self.env.txn_begin()
@@ -1199,10 +1212,10 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         self.env        = None
         self.db_is_open = False
         raise FileVersionError(
-            "The database version is not supported by this "
-            "version of GRAMPS.\nPlease upgrade to the "
-            "corresponding version or use XML for porting "
-            "data between different database versions.")
+            _("The database version is not supported by this "
+              "version of GRAMPS.\nPlease upgrade to the "
+              "corresponding version or use XML for porting "
+              "data between different database versions."))
 
     def close(self):
         try:
@@ -1503,7 +1516,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
             if data_map:
                 _LOG.error("Failed to get from handle", exc_info=True)
         if data:
-            newobj = InstanceType(class_type)
+            newobj = class_type()
             newobj.unserialize(data)
             return newobj
         return None
@@ -1521,7 +1534,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         obj = class_type()
         handle = str(handle)
         new = True
-        if dmap.has_key(handle):
+        if handle in dmap:
             data = dmap.get(handle, txn=self.txn)
             obj.unserialize(data)
             #references create object with id None before object is really made
@@ -1655,7 +1668,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
 
     def undo_reference(self, data, handle):
         try:
-            if data == None:
+            if data is None:
                 self.reference_map.delete(handle, txn=self.txn)
             else:
                 self.reference_map.put(handle, data, txn=self.txn)
@@ -1665,7 +1678,7 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
 
     def undo_data(self, data, handle, db_map, signal_root):
         try:
-            if data == None:
+            if data is None:
                 self.emit(signal_root + '-delete', ([handle],))
                 db_map.delete(handle, txn=self.txn)
             else:
@@ -1683,13 +1696,328 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
     def gramps_upgrade(self, callback=None):
         UpdateCallback.__init__(self, callback)
         
-#        version = self.metadata.get('version', default=_MINVERSION)
+        version = self.metadata.get('version', default=_MINVERSION)
 
         t = time.time()
-#        if version < 13:
-#            self.gramps_upgrade_13()
+
+        if version < 14:
+            self.gramps_upgrade_14()
+
         print "Upgrade time:", int(time.time()-t), "seconds"
+
+    def gramps_upgrade_14(self):
+        """Upgrade database from version 13 to 14."""
+        # This upgrade modifies notes and dates
+        length = (len(self.note_map) + len(self.person_map) +
+                  len(self.event_map) + len(self.family_map) +
+                  len(self.repository_map) + len(self.media_map) +
+                  len(self.place_map) + len(self.source_map))
+        self.set_total(length)
+
+        # ---------------------------------
+        # Modify Notes
+        # ---------------------------------
+        # replace clear text with StyledText in Notes
+        for handle in self.note_map.keys():
+            note = self.note_map[handle]
+            (junk_handle, gramps_id, text, format, note_type,
+             change, marker, private) = note
+            styled_text = (text, [])
+            new_note = (handle, gramps_id, styled_text, format, note_type,
+                        change, marker, private)
+            the_txn = self.env.txn_begin()
+            self.note_map.put(str(handle), new_note, txn=the_txn)
+            the_txn.commit()
+            self.update()
+
+        # ---------------------------------
+        # Modify Event
+        # ---------------------------------
+        # update dates with newyear
+        for handle in self.event_map.keys():
+            event = self.event_map[handle]
+            (junk_handle, gramps_id, the_type, date, description, place, 
+             source_list, note_list, media_list, attribute_list,
+             change, marker, private) = event
+            new_date = self.convert_date_14(date)
+            new_source_list = self.new_source_list_14(source_list)
+            new_media_list = self.new_media_list_14(media_list)
+            new_attribute_list = self.new_attribute_list_14(attribute_list)
+            new_event = (junk_handle, gramps_id, the_type, new_date,
+                         description, place, new_source_list, note_list, 
+                         new_media_list, new_attribute_list, change,marker,private)
+            the_txn = self.env.txn_begin()
+            self.event_map.put(str(handle), new_event, txn=the_txn)
+            the_txn.commit()
+            self.update()
+
+        # ---------------------------------
+        # Modify Person
+        # ---------------------------------
+        # update dates with newyear
+        for handle in self.person_map.keys():
+            person = self.person_map[handle]
+            (junk_handle,        #  0
+             gramps_id,          #  1
+             gender,             #  2
+             primary_name,       #  3
+             alternate_names,    #  4
+             death_ref_index,    #  5
+             birth_ref_index,    #  6
+             event_ref_list,     #  7
+             family_list,        #  8
+             parent_family_list, #  9
+             media_list,         # 10
+             address_list,       # 11
+             attribute_list,     # 12
+             urls,               # 13
+             lds_ord_list,       # 14
+             psource_list,       # 15
+             pnote_list,         # 16
+             change,             # 17
+             marker,             # 18
+             pprivate,           # 19
+             person_ref_list,    # 20
+             ) = person
+
+            new_address_list = []
+            for address in address_list:
+                (privacy, asource_list, anote_list, date, location) = address
+                new_date = self.convert_date_14(date)
+                new_asource_list = self.new_source_list_14(asource_list)
+                new_address_list.append((privacy, new_asource_list, anote_list, 
+                                         new_date, location))
+            new_ord_list = []
+            for ldsord in lds_ord_list:
+                (lsource_list, lnote_list, date, type, place,
+                 famc, temple, status, lprivate) = ldsord
+                new_date = self.convert_date_14(date)
+                new_lsource_list = self.new_source_list_14(lsource_list)
+                new_ord_list.append( (new_lsource_list, lnote_list, new_date, type, 
+                                      place, famc, temple, status, lprivate))
+
+            new_primary_name = self.convert_name_14(primary_name)
+
+            new_alternate_names = [self.convert_name_14(name) for name 
+                                   in alternate_names]
             
+            new_media_list = self.new_media_list_14(media_list)
+            new_psource_list = self.new_source_list_14(psource_list)
+            new_attribute_list = self.new_attribute_list_14(attribute_list)
+            new_person_ref_list = self.new_person_ref_list_14(person_ref_list)
+
+            new_person = (junk_handle,        #  0
+                          gramps_id,          #  1
+                          gender,             #  2
+                          new_primary_name,       #  3
+                          new_alternate_names,    #  4
+                          death_ref_index,    #  5
+                          birth_ref_index,    #  6
+                          event_ref_list,     #  7
+                          family_list,        #  8
+                          parent_family_list, #  9
+                          new_media_list,         # 10
+                          new_address_list,       # 11
+                          new_attribute_list,     # 12
+                          urls,               # 13
+                          new_ord_list,          # 14
+                          new_psource_list,       # 15
+                          pnote_list,         # 16
+                          change,             # 17
+                          marker,             # 18
+                          pprivate,           # 19
+                          new_person_ref_list,    # 20
+                          )
+
+            the_txn = self.env.txn_begin()
+            self.person_map.put(str(handle), new_person, txn=the_txn)
+            the_txn.commit()
+            self.update()
+
+        # ---------------------------------
+        # Modify Family
+        # ---------------------------------
+        # update dates with newyear
+        for handle in self.family_map.keys():
+            family = self.family_map[handle]
+            (junk_handle, gramps_id, father_handle, mother_handle,
+             child_ref_list, the_type, event_ref_list, media_list,
+             attribute_list, lds_seal_list, source_list, note_list,
+             change, marker, private) = family
+            new_child_ref_list = self.new_child_ref_list_14(child_ref_list)
+            new_media_list = self.new_media_list_14(media_list)
+            new_source_list = self.new_source_list_14(source_list)
+            new_attribute_list = self.new_attribute_list_14(attribute_list)
+            new_seal_list = []
+            for ldsord in lds_seal_list:
+                (lsource_list, lnote_list, date, type, place,
+                 famc, temple, status, lprivate) = ldsord
+                new_date = self.convert_date_14(date)
+                new_lsource_list = self.new_source_list_14(lsource_list)
+                new_seal_list.append( (new_lsource_list, lnote_list, new_date, type, 
+                                       place, famc, temple, status, lprivate))
+
+            new_family = (junk_handle, gramps_id, father_handle, mother_handle,
+                          new_child_ref_list, the_type, event_ref_list, new_media_list,
+                          new_attribute_list, new_seal_list, new_source_list, note_list,
+                          change, marker, private)
+            the_txn = self.env.txn_begin()
+            self.family_map.put(str(handle), new_family, txn=the_txn)
+            the_txn.commit()
+            self.update()
+
+        # ---------------------------------
+        # Modify Repository
+        # ---------------------------------
+        # update dates with newyear
+        for handle in self.repository_map.keys():
+            repository = self.repository_map[handle]
+            # address
+            (junk_handle, gramps_id, the_type, name, note_list,
+             address_list, urls, change, marker, private) = repository
+
+            new_address_list = []
+            for address in address_list:
+                (privacy, asource_list, anote_list, date, location) = address
+                new_date = self.convert_date_14(date)
+                new_asource_list = self.new_source_list_14(asource_list)
+                new_address_list.append((privacy, new_asource_list, anote_list, 
+                                         new_date, location))
+
+            new_repository = (junk_handle, gramps_id, the_type, name, note_list,
+                              new_address_list, urls, change, marker, private)
+
+            the_txn = self.env.txn_begin()
+            self.repository_map.put(str(handle), new_repository, txn=the_txn)
+            the_txn.commit()
+            self.update()
+
+        # ---------------------------------
+        # Modify Media
+        # ---------------------------------
+        for media_handle in self.media_map.keys():
+            media = self.media_map[media_handle]
+            (handle, gramps_id, path, mime, desc,
+             attribute_list, source_list, note_list, change,
+             date, marker, private) = media
+            new_source_list = self.new_source_list_14(source_list)
+            new_date = self.convert_date_14(date)
+            new_media = (handle, gramps_id, path, mime, desc,
+                         attribute_list, new_source_list, note_list, change,
+                         new_date, marker, private)
+
+            the_txn = self.env.txn_begin()
+            self.media_map.put(str(handle), new_media, txn=the_txn)
+            the_txn.commit()
+            self.update()
+
+        # ---------------------------------
+        # Modify Place
+        # ---------------------------------
+        for place_handle in self.place_map.keys():
+            place = self.place_map[place_handle]
+            (handle, gramps_id, title, long, lat,
+             main_loc, alt_loc, urls, media_list, source_list, note_list,
+             change, marker, private) = place
+            new_media_list = self.new_media_list_14(media_list)
+            new_source_list = self.new_source_list_14(source_list)
+            new_place = (handle, gramps_id, title, long, lat,
+                         main_loc, alt_loc, urls, new_media_list, 
+                         new_source_list, note_list, change, marker, private) 
+
+            the_txn = self.env.txn_begin()
+            self.place_map.put(str(handle), new_place, txn=the_txn)
+            the_txn.commit()
+            self.update()
+
+        # ---------------------------------
+        # Modify Source
+        # ---------------------------------
+        for source_handle in self.source_map.keys():
+            source = self.source_map[source_handle]
+            (handle, gramps_id, title, author,
+             pubinfo, note_list, media_list,
+             abbrev, change, datamap, reporef_list,
+             marker, private) = source
+            new_media_list = self.new_media_list_14(media_list)
+            new_source = (handle, gramps_id, title, author,
+                          pubinfo, note_list, new_media_list,
+                          abbrev, change, datamap, reporef_list,
+                          marker, private)
+
+            the_txn = self.env.txn_begin()
+            self.source_map.put(str(handle), new_source, txn=the_txn)
+            the_txn.commit()
+            self.update()
+
+        # Bump up database version. Separate transaction to save metadata.
+        the_txn = self.env.txn_begin()
+        self.metadata.put('version', 14, txn=the_txn)
+        the_txn.commit()
+
+    def new_source_list_14(self, source_list):
+        new_source_list = []
+        for source in source_list:
+            (date, private, note_list, confidence, ref, page) = source
+            new_date = self.convert_date_14(date)
+            new_source_list.append((new_date, private, note_list, confidence, ref, page))
+        return new_source_list
+
+    def new_attribute_list_14(self, attribute_list):
+        new_attribute_list = []
+        for attribute in attribute_list:
+            (private, asource_list, note_list, the_type, value) = attribute
+            new_asource_list = self.new_source_list_14(asource_list)
+            new_attribute_list.append((private, new_asource_list, note_list, the_type, value))
+        return new_attribute_list
+
+    def new_media_list_14(self, media_list):
+        # ---------------------------------
+        # Event Media list
+        # ---------------------------------
+        new_media_list = []
+        for media in media_list:
+            (private, source_list, note_list,attribute_list,ref,role) = media
+            new_source_list = self.new_source_list_14(source_list)
+            new_attribute_list = self.new_attribute_list_14(attribute_list)
+            new_media_list.append((private, new_source_list, note_list, new_attribute_list, ref, role))
+        return new_media_list
+
+    def new_person_ref_list_14(self, person_ref_list):
+        new_person_ref_list = []
+        for person_ref in person_ref_list:
+            (private, source_list, note_list, ref, rel) = person_ref
+            new_source_list = self.new_source_list_14(source_list)
+            new_person_ref_list.append((private, new_source_list, note_list, ref, rel))
+        return new_person_ref_list
+
+    def new_child_ref_list_14(self, child_ref_list):
+        new_child_ref_list = []
+        for data in child_ref_list:
+            (private, source_list, note_list, ref, frel, mrel) = data
+            new_source_list = self.new_source_list_14(source_list)
+            new_child_ref_list.append((private, new_source_list, note_list, ref, frel, mrel))
+        return new_child_ref_list
+
+    def convert_date_14(self, date):
+        if date:
+            (calendar, modifier, quality, dateval, text, sortval) = date
+            return (calendar, modifier, quality, dateval, text, sortval, 0)
+        else:
+            return None
+
+    def convert_name_14(self, name):
+        (privacy, source_list, note_list, date, 
+         first_name, surname, suffix, title,
+         name_type, prefix, patronymic,
+         group_as, sort_as, display_as, call) = name
+        new_date = self.convert_date_14(date)
+        new_source_list = self.new_source_list_14(source_list)
+        return (privacy, new_source_list, note_list, new_date, 
+                first_name, surname, suffix, title,
+                name_type, prefix, patronymic,
+                group_as, sort_as, display_as, call)
+
     def set_auto_remove(self):
         """
         BSDDB change log settings using new method with renamed attributes
@@ -1734,7 +2062,6 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
                     db.DB_INIT_LOG | db.DB_INIT_TXN | db.DB_THREAD
 
         # As opposed to before, we always try recovery on databases
-        #  in _GrampsBSDDB.py we only do that on existing filenames
         env_flags = env_flags | db.DB_RECOVER
 
         # Environment name is now based on the filename
@@ -1752,7 +2079,6 @@ class GrampsDBDir(GrampsDbBase, UpdateCallback):
         self.metadata.close()
         self.env.close()
         
-
 #-------------------------------------------------------------------------
 #
 # BdbTransaction
@@ -1787,7 +2113,9 @@ def write_lock_file(name):
         except:
             user = os.environ.get('USER')
         text = "%s@%s" % (user, host)
-    f.write(_("Locked by %s") % text)
+    # Save only the username and host, so the massage can be
+    # printed with correct locale in DbManager.py when a lock is found
+    f.write(text)
     f.close()
 
 if __name__ == "__main__":
