@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: dbbase.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: dbbase.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 Proxy class for the GRAMPS databases. Filter out all data marked private.
@@ -34,10 +34,14 @@ from gettext import gettext as _
 #-------------------------------------------------------------------------
 from gen.lib import *
 
-class DbBase:
+class DbBase(object):
     """
-    A proxy to a Gramps database. This proxy will act like a Gramps database,
-    but all data marked private will be hidden from the user.
+    DbBase is intended to be an abstract base class for building classes that 
+    implement the Gramps database. All functions raise a NotImplementedError to 
+    remind the developer to implement those functions.
+
+    Real database classes can inherit from this class to make sure the
+    database interface is properly implemented.
     """
 
     def set_prefixes(self, person, media, family, source, place, event,
