@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: BookReport.py 10600 2008-04-20 03:05:02Z pez4brian $
+# $Id: BookReport.py 12560 2009-05-21 17:58:31Z gbritton $
 
 # Written by Alex Roitman, 
 # largely based on the BaseDoc classes by Don Allingham
@@ -72,12 +72,12 @@ import ListModel
 import Errors
 import BaseDoc
 from QuestionDialog import WarningDialog, ErrorDialog
-from PluginUtils import bkitems_list, register_report, Plugins
-from PluginUtils import PersonOption, FilterOption, FamilyOption
+from gen.plug import PluginManager
+from gen.plug.menu import PersonOption, FilterOption, FamilyOption
 import ManagedWindow
 
 # Import from specific modules in ReportBase
-from ReportBase._Constants import CATEGORY_BOOK, MODE_GUI, MODE_CLI
+from ReportBase import CATEGORY_BOOK, book_categories
 from ReportBase._BookFormatComboBox import BookFormatComboBox
 from ReportBase._ReportDialog import ReportDialog
 from ReportBase._DocReportDialog import DocReportDialog
@@ -86,6 +86,13 @@ from ReportBase._ReportOptions import ReportOptions
 
 from BasicUtils import name_displayer as _nd
 
+#------------------------------------------------------------------------
+#
+# Private Constants
+#
+#------------------------------------------------------------------------
+_UNSUPPORTED = _("Unsupported")
+
 #------------------------------------------------------------------------
 #
 # Private Functions
@@ -175,54 +182,29 @@ def _get_subject(options, dbase):
 # Book Item class
 #
 #------------------------------------------------------------------------
-class BookItem:
+class BookItem(object):
     """
     Interface into the book item -- a smallest element of the book.
     """
 
-    def __init__(self, dbase, name=None):
+    def __init__(self, dbase, name):
         """
         Create a new empty BookItem.
         
-        name:   if not None then the book item is retreived 
+        name:   the book item is retreived 
                 from the book item registry using name for lookup
         """
         self.dbase = dbase
-        if name:
-            self.get_registered_item(name)
-        else:
-            self.clear()
-        
-    def clear(self):
-        """
-        Clear the contents of the book item.
-        
-        Everything gets set to empty values except for the style_name"""
-
-        self.translated_name = ""
-        self.category = ""
-        self.write_item = None
-        self.option_class = None
-        self.style_file = ""
         self.style_name = "default"
-        self.make_default_style = None
-        self.name = ""
+        pmgr = PluginManager.get_instance()
 
-    def get_registered_item(self, name):
-        """ 
-        Retrieve the item from the book item registry.
-        
-        name:   a name used for lookup.
-        """
-
-        self.clear()
-        for item in bkitems_list:
+        for item in pmgr.get_book_item_list():
             if item[4] == name:
                 self.translated_name = item[0]
                 if item[5]:
-                    self.category = Plugins.UNSUPPORTED
+                    self.category = _UNSUPPORTED
                 else:
-                    self.category = item[1]
+                    self.category = book_categories[item[1]]
                 self.write_item = item[2]
                 self.name = item[4]
                 self.option_class = item[3](self.name, self.dbase)
@@ -266,24 +248,12 @@ class BookItem:
         """
         return self.style_name
 
-    def get_style_file(self):
-        """
-        Return the style file name for the item.
-        """
-        return self.style_file
-
-    def get_make_default_style(self):
-        """
-        Return the function to make default style for the item.
-        """
-        return self.make_default_style
-
 #------------------------------------------------------------------------
 #
 # Book class
 #
 #------------------------------------------------------------------------
-class Book:
+class Book(object):
     """
     Interface into the user-defined book -- a collection of book items.
     """
@@ -390,7 +360,7 @@ class Book:
 # BookList class
 #
 #------------------------------------------------------------------------
-class BookList:
+class BookList(object):
     """
     Interface into the user-defined list of books.  
 
@@ -463,7 +433,7 @@ class BookList:
                 options = item.option_class.handler.options_dict
                 for option_name in options.keys():
                     option_value = options[option_name]
-                    if type(option_value) in (type(list()), type(tuple())):
+                    if isinstance(option_value, (list, tuple)):
                         f.write('  <option name="%s" value="" '
                                 'length="%d">\n' % (
                                     escape(option_name),
@@ -583,7 +553,7 @@ class BookParser(handler.ContentHandler):
 # BookList Display class
 #
 #------------------------------------------------------------------------
-class BookListDisplay:
+class BookListDisplay(object):
     """
     Interface into a dialog with the list of available books. 
 
@@ -779,15 +749,15 @@ class BookReportSelector(ManagedWindow.ManagedWindow):
         
         The selections are read from the book item registry.
         """
-
-        if not bkitems_list:
+        pmgr = PluginManager.get_instance()
+        if not pmgr.get_book_item_list():
             return
 
-        for book_item in bkitems_list:
+        for book_item in pmgr.get_book_item_list():
             if book_item[5]:
-                category = Plugins.UNSUPPORTED
+                category = _UNSUPPORTED
             else:
-                category = book_item[1]
+                category = book_categories[book_item[1]]
             
             data = [ book_item[0], category, book_item[4] ] 
             new_iter = self.av_model.add(data)
@@ -1133,9 +1103,6 @@ class BookReportDialog(DocReportDialog):
     def setup_other_frames(self): pass
     def parse_style_frame(self): pass
 
-    def doc_uses_tables(self):
-        return 1
-
     def get_title(self):
         return _("Book Report")
 
@@ -1151,8 +1118,7 @@ class BookReportDialog(DocReportDialog):
         this text report.  This menu will be generated based upon
         whether the document requires table support, etc."""
         self.format_menu = BookFormatComboBox()
-        self.format_menu.set(self.doc_uses_tables(),
-                             self.doc_type_changed, None, active)
+        self.format_menu.set(self.doc_type_changed, None, active)
 
     def make_document(self):
         """Create a document of the type requested by the user."""
@@ -1169,7 +1135,7 @@ class BookReportDialog(DocReportDialog):
         self.doc.open(self.target_path)
         
         if self.print_report.get_active():
-            self.doc.print_requested ()
+            self.doc.open_requested ()
 
     def make_report(self):
         """The actual book report. Start it out, then go through the item list 
@@ -1199,7 +1165,7 @@ def cl_report(database, name, category, options_str_dict):
     if clr.show:
         return
     
-    if not clr.options_dict.has_key('bookname'):
+    if 'bookname' not in clr.options_dict:
         print "Please Specify a book name"
         return
 
@@ -1273,12 +1239,13 @@ def write_book_item(database, report_class, options_class):
 # 
 #
 #------------------------------------------------------------------------
-register_report(
+pmgr = PluginManager.get_instance()
+pmgr.register_report(
     name = 'book',
     category = CATEGORY_BOOK,
     report_class = BookReportSelector,
     options_class = cl_report,
-    modes = MODE_GUI | MODE_CLI,
+    modes = PluginManager.REPORT_MODE_GUI | PluginManager.REPORT_MODE_CLI,
     translated_name = _("Book Report"),
     status = _("Stable"),
     description = _("Produces a book containing several reports."),
